Class AccountLimit
java.lang.Object
software.amazon.awssdk.services.lambda.model.AccountLimit
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AccountLimit.Builder,AccountLimit>
@Generated("software.amazon.awssdk:codegen")
public final class AccountLimit
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AccountLimit.Builder,AccountLimit>
Limits that are related to concurrency and storage. All file and storage sizes are in bytes.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic AccountLimit.Builderbuilder()final LongThe maximum size of a function's deployment package and layers when they're extracted.final LongThe maximum size of a deployment package when it's uploaded directly to Lambda.final IntegerThe maximum number of simultaneous function executions.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AccountLimit.Builder>final StringtoString()Returns a string representation of this object.final LongThe amount of storage space that you can use for all deployment packages and layer archives.final IntegerThe maximum number of simultaneous function executions, minus the capacity that's reserved for individual functions with PutFunctionConcurrency.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
totalCodeSize
The amount of storage space that you can use for all deployment packages and layer archives.
- Returns:
- The amount of storage space that you can use for all deployment packages and layer archives.
-
codeSizeUnzipped
The maximum size of a function's deployment package and layers when they're extracted.
- Returns:
- The maximum size of a function's deployment package and layers when they're extracted.
-
codeSizeZipped
The maximum size of a deployment package when it's uploaded directly to Lambda. Use Amazon S3 for larger files.
- Returns:
- The maximum size of a deployment package when it's uploaded directly to Lambda. Use Amazon S3 for larger files.
-
concurrentExecutions
The maximum number of simultaneous function executions.
- Returns:
- The maximum number of simultaneous function executions.
-
unreservedConcurrentExecutions
The maximum number of simultaneous function executions, minus the capacity that's reserved for individual functions with PutFunctionConcurrency.
- Returns:
- The maximum number of simultaneous function executions, minus the capacity that's reserved for individual functions with PutFunctionConcurrency.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AccountLimit.Builder,AccountLimit>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-