Class AccountUsage
java.lang.Object
software.amazon.awssdk.services.lambda.model.AccountUsage
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AccountUsage.Builder,AccountUsage>
@Generated("software.amazon.awssdk:codegen")
public final class AccountUsage
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AccountUsage.Builder,AccountUsage>
The number of functions and amount of storage in use.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic AccountUsage.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final LongThe number of Lambda functions.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends AccountUsage.Builder>final StringtoString()Returns a string representation of this object.final LongThe amount of storage space, in bytes, that's being used by deployment packages and layer archives.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
totalCodeSize
The amount of storage space, in bytes, that's being used by deployment packages and layer archives.
- Returns:
- The amount of storage space, in bytes, that's being used by deployment packages and layer archives.
-
functionCount
The number of Lambda functions.
- Returns:
- The number of Lambda functions.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AccountUsage.Builder,AccountUsage>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-