Class AddLayerVersionPermissionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<AddLayerVersionPermissionRequest.Builder,AddLayerVersionPermissionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringaction()The API action that grants access to the layer.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name or Amazon Resource Name (ARN) of the layer.final StringWith the principal set to*, grant permission to all accounts in the specified organization.final StringAn account ID, or*to grant layer usage permission to all accounts in an organization, or all Amazon Web Services accounts (iforganizationIdis not specified).final StringOnly update the policy if the revision ID matches the ID specified.static Class<? extends AddLayerVersionPermissionRequest.Builder>final StringAn identifier that distinguishes the policy from others on the same layer version.final StringtoString()Returns a string representation of this object.final LongThe version number.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
layerName
The name or Amazon Resource Name (ARN) of the layer.
- Returns:
- The name or Amazon Resource Name (ARN) of the layer.
-
versionNumber
The version number.
- Returns:
- The version number.
-
statementId
An identifier that distinguishes the policy from others on the same layer version.
- Returns:
- An identifier that distinguishes the policy from others on the same layer version.
-
action
The API action that grants access to the layer. For example,
lambda:GetLayerVersion.- Returns:
- The API action that grants access to the layer. For example,
lambda:GetLayerVersion.
-
principal
An account ID, or
*to grant layer usage permission to all accounts in an organization, or all Amazon Web Services accounts (iforganizationIdis not specified). For the last case, make sure that you really do want all Amazon Web Services accounts to have usage permission to this layer.- Returns:
- An account ID, or
*to grant layer usage permission to all accounts in an organization, or all Amazon Web Services accounts (iforganizationIdis not specified). For the last case, make sure that you really do want all Amazon Web Services accounts to have usage permission to this layer.
-
organizationId
With the principal set to
*, grant permission to all accounts in the specified organization.- Returns:
- With the principal set to
*, grant permission to all accounts in the specified organization.
-
revisionId
Only update the policy if the revision ID matches the ID specified. Use this option to avoid modifying a policy that has changed since you last read it.
- Returns:
- Only update the policy if the revision ID matches the ID specified. Use this option to avoid modifying a policy that has changed since you last read it.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AddLayerVersionPermissionRequest.Builder,AddLayerVersionPermissionRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-