Class AliasConfiguration
java.lang.Object
software.amazon.awssdk.services.lambda.model.AliasConfiguration
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AliasConfiguration.Builder,AliasConfiguration>
@Generated("software.amazon.awssdk:codegen")
public final class AliasConfiguration
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AliasConfiguration.Builder,AliasConfiguration>
Provides configuration information about a Lambda function alias.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringaliasArn()The Amazon Resource Name (ARN) of the alias.static AliasConfiguration.Builderbuilder()final StringA description of the alias.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe function version that the alias invokes.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the alias.final StringA unique identifier that changes when you update the alias.The routing configuration of the alias.static Class<? extends AliasConfiguration.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
aliasArn
The Amazon Resource Name (ARN) of the alias.
- Returns:
- The Amazon Resource Name (ARN) of the alias.
-
name
The name of the alias.
- Returns:
- The name of the alias.
-
functionVersion
The function version that the alias invokes.
- Returns:
- The function version that the alias invokes.
-
description
A description of the alias.
- Returns:
- A description of the alias.
-
routingConfig
The routing configuration of the alias.
- Returns:
- The routing configuration of the alias.
-
revisionId
A unique identifier that changes when you update the alias.
- Returns:
- A unique identifier that changes when you update the alias.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AliasConfiguration.Builder,AliasConfiguration>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-