Class AliasLimitExceededException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
software.amazon.awssdk.core.exception.SdkException
software.amazon.awssdk.core.exception.SdkServiceException
software.amazon.awssdk.awscore.exception.AwsServiceException
software.amazon.awssdk.services.lambda.model.LambdaException
software.amazon.awssdk.services.lambda.model.AliasLimitExceededException
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AliasLimitExceededException.Builder,AliasLimitExceededException>
@Generated("software.amazon.awssdk:codegen")
public final class AliasLimitExceededException
extends LambdaException
implements ToCopyableBuilder<AliasLimitExceededException.Builder,AliasLimitExceededException>
Lambda couldn't create the alias because your Amazon Web Services account has exceeded the maximum number of aliases allowed per Lambda function. For more information, see Lambda quotas.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()static Class<? extends AliasLimitExceededException.Builder>type()The exception type.Methods inherited from class software.amazon.awssdk.awscore.exception.AwsServiceException
awsErrorDetails, getMessage, isClockSkewException, isThrottlingExceptionMethods inherited from class software.amazon.awssdk.core.exception.SdkServiceException
extendedRequestId, isRetryableException, requestId, statusCodeMethods inherited from class software.amazon.awssdk.core.exception.SdkException
create, numAttempts, rawMessage, retryableMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFieldsMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AliasLimitExceededException.Builder,AliasLimitExceededException> - Overrides:
toBuilderin classLambdaException
-
builder
-
serializableBuilderClass
-
type
The exception type.
- Returns:
- The exception type.
-
sdkFields
- Specified by:
sdkFieldsin interfaceSdkPojo- Overrides:
sdkFieldsin classSdkServiceException
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-