Class AmazonManagedKafkaEventSourceConfig
java.lang.Object
software.amazon.awssdk.services.lambda.model.AmazonManagedKafkaEventSourceConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<AmazonManagedKafkaEventSourceConfig.Builder,AmazonManagedKafkaEventSourceConfig>
@Generated("software.amazon.awssdk:codegen")
public final class AmazonManagedKafkaEventSourceConfig
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<AmazonManagedKafkaEventSourceConfig.Builder,AmazonManagedKafkaEventSourceConfig>
Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe identifier for the Kafka consumer group to join.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()Specific configuration settings for a Kafka schema registry.static Class<? extends AmazonManagedKafkaEventSourceConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
consumerGroupId
The identifier for the Kafka consumer group to join. The consumer group ID must be unique among all your Kafka event sources. After creating a Kafka event source mapping with the consumer group ID specified, you cannot update this value. For more information, see Customizable consumer group ID.
- Returns:
- The identifier for the Kafka consumer group to join. The consumer group ID must be unique among all your Kafka event sources. After creating a Kafka event source mapping with the consumer group ID specified, you cannot update this value. For more information, see Customizable consumer group ID.
-
schemaRegistryConfig
Specific configuration settings for a Kafka schema registry.
- Returns:
- Specific configuration settings for a Kafka schema registry.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AmazonManagedKafkaEventSourceConfig.Builder,AmazonManagedKafkaEventSourceConfig>
-
builder
-
serializableBuilderClass
public static Class<? extends AmazonManagedKafkaEventSourceConfig.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-