Class CallbackDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.CallbackDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CallbackDetails.Builder,CallbackDetails>
@Generated("software.amazon.awssdk:codegen")
public final class CallbackDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<CallbackDetails.Builder,CallbackDetails>
Contains details about a callback operation in a durable execution, including the callback token and timeout configuration.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CallbackDetails.Builderbuilder()final StringThe callback ID.final booleanfinal booleanequalsBySdkFields(Object obj) final ErrorObjecterror()An error object that contains details about the failure.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringresult()The response payload from the callback operation as a string.static Class<? extends CallbackDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
callbackId
The callback ID. Callback IDs are generated by the
DurableContextwhen a durable function callsctx.waitForCallback.- Returns:
- The callback ID. Callback IDs are generated by the
DurableContextwhen a durable function callsctx.waitForCallback.
-
result
The response payload from the callback operation as a string.
- Returns:
- The response payload from the callback operation as a string.
-
error
An error object that contains details about the failure.
- Returns:
- An error object that contains details about the failure.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CallbackDetails.Builder,CallbackDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-