Class CallbackFailedDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.CallbackFailedDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CallbackFailedDetails.Builder,CallbackFailedDetails>
@Generated("software.amazon.awssdk:codegen")
public final class CallbackFailedDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<CallbackFailedDetails.Builder,CallbackFailedDetails>
Contains details about a failed callback operation, including error information and the reason for failure.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final EventErrorerror()An error object that contains details about the failure.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends CallbackFailedDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
error
An error object that contains details about the failure.
- Returns:
- An error object that contains details about the failure.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CallbackFailedDetails.Builder,CallbackFailedDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-