Class CallbackOptions

java.lang.Object
software.amazon.awssdk.services.lambda.model.CallbackOptions
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<CallbackOptions.Builder,CallbackOptions>

@Generated("software.amazon.awssdk:codegen") public final class CallbackOptions extends Object implements SdkPojo, Serializable, ToCopyableBuilder<CallbackOptions.Builder,CallbackOptions>

Configuration options for callback operations in durable executions, including timeout settings and retry behavior.

See Also:
  • Method Details

    • timeoutSeconds

      public final Integer timeoutSeconds()

      The timeout for the callback operation in seconds. If not specified or set to 0, the callback has no timeout.

      Returns:
      The timeout for the callback operation in seconds. If not specified or set to 0, the callback has no timeout.
    • heartbeatTimeoutSeconds

      public final Integer heartbeatTimeoutSeconds()

      The heartbeat timeout for the callback operation, in seconds. If not specified or set to 0, heartbeat timeout is disabled.

      Returns:
      The heartbeat timeout for the callback operation, in seconds. If not specified or set to 0, heartbeat timeout is disabled.
    • toBuilder

      public CallbackOptions.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<CallbackOptions.Builder,CallbackOptions>
    • builder

      public static CallbackOptions.Builder builder()
    • serializableBuilderClass

      public static Class<? extends CallbackOptions.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo