Interface CallbackOptions.Builder

All Superinterfaces:
Buildable, CopyableBuilder<CallbackOptions.Builder,CallbackOptions>, SdkBuilder<CallbackOptions.Builder,CallbackOptions>, SdkPojo
Enclosing class:
CallbackOptions

@Mutable @NotThreadSafe public static interface CallbackOptions.Builder extends SdkPojo, CopyableBuilder<CallbackOptions.Builder,CallbackOptions>
  • Method Details

    • timeoutSeconds

      CallbackOptions.Builder timeoutSeconds(Integer timeoutSeconds)

      The timeout for the callback operation in seconds. If not specified or set to 0, the callback has no timeout.

      Parameters:
      timeoutSeconds - The timeout for the callback operation in seconds. If not specified or set to 0, the callback has no timeout.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • heartbeatTimeoutSeconds

      CallbackOptions.Builder heartbeatTimeoutSeconds(Integer heartbeatTimeoutSeconds)

      The heartbeat timeout for the callback operation, in seconds. If not specified or set to 0, heartbeat timeout is disabled.

      Parameters:
      heartbeatTimeoutSeconds - The heartbeat timeout for the callback operation, in seconds. If not specified or set to 0, heartbeat timeout is disabled.
      Returns:
      Returns a reference to this object so that method calls can be chained together.