Class CallbackStartedDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.CallbackStartedDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CallbackStartedDetails.Builder,CallbackStartedDetails>
@Generated("software.amazon.awssdk:codegen")
public final class CallbackStartedDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<CallbackStartedDetails.Builder,CallbackStartedDetails>
Contains details about a callback operation that has started, including timing information and callback metadata.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe callback ID.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe heartbeat timeout value, in seconds.static Class<? extends CallbackStartedDetails.Builder>final Integertimeout()The timeout value, in seconds.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
callbackId
The callback ID. Callback IDs are generated by the
DurableContextwhen a durable function callsctx.waitForCallback.- Returns:
- The callback ID. Callback IDs are generated by the
DurableContextwhen a durable function callsctx.waitForCallback.
-
heartbeatTimeout
The heartbeat timeout value, in seconds.
- Returns:
- The heartbeat timeout value, in seconds.
-
timeout
The timeout value, in seconds.
- Returns:
- The timeout value, in seconds.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CallbackStartedDetails.Builder,CallbackStartedDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-