Class CapacityProvider
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CapacityProvider.Builder,CapacityProvider>
A capacity provider manages compute resources for Lambda functions.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CapacityProvider.Builderbuilder()final StringThe Amazon Resource Name (ARN) of the capacity provider.The scaling configuration for the capacity provider.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InstanceRequirementsThe instance requirements for compute resources managed by the capacity provider.final StringThe ARN of the KMS key used to encrypt the capacity provider's resources.final StringThe date and time when the capacity provider was last modified.The permissions configuration for the capacity provider.static Class<? extends CapacityProvider.Builder>final CapacityProviderStatestate()The current state of the capacity provider.final StringThe current state of the capacity provider.final StringtoString()Returns a string representation of this object.The VPC configuration for the capacity provider.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
capacityProviderArn
The Amazon Resource Name (ARN) of the capacity provider.
- Returns:
- The Amazon Resource Name (ARN) of the capacity provider.
-
state
The current state of the capacity provider.
If the service returns an enum value that is not available in the current SDK version,
statewill returnCapacityProviderState.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstateAsString().- Returns:
- The current state of the capacity provider.
- See Also:
-
stateAsString
The current state of the capacity provider.
If the service returns an enum value that is not available in the current SDK version,
statewill returnCapacityProviderState.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstateAsString().- Returns:
- The current state of the capacity provider.
- See Also:
-
vpcConfig
The VPC configuration for the capacity provider.
- Returns:
- The VPC configuration for the capacity provider.
-
permissionsConfig
The permissions configuration for the capacity provider.
- Returns:
- The permissions configuration for the capacity provider.
-
instanceRequirements
The instance requirements for compute resources managed by the capacity provider.
- Returns:
- The instance requirements for compute resources managed by the capacity provider.
-
capacityProviderScalingConfig
The scaling configuration for the capacity provider.
- Returns:
- The scaling configuration for the capacity provider.
-
kmsKeyArn
The ARN of the KMS key used to encrypt the capacity provider's resources.
- Returns:
- The ARN of the KMS key used to encrypt the capacity provider's resources.
-
lastModified
The date and time when the capacity provider was last modified.
- Returns:
- The date and time when the capacity provider was last modified.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CapacityProvider.Builder,CapacityProvider>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-