Class CapacityProviderScalingConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CapacityProviderScalingConfig.Builder,CapacityProviderScalingConfig>
Configuration that defines how the capacity provider scales compute instances based on demand and policies.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the ScalingPolicies property.final IntegerThe maximum number of vCPUs that the capacity provider can provision across all compute instances.The scaling mode that determines how the capacity provider responds to changes in demand.final StringThe scaling mode that determines how the capacity provider responds to changes in demand.final List<TargetTrackingScalingPolicy>A list of scaling policies that define how the capacity provider scales compute instances based on metrics and thresholds.static Class<? extends CapacityProviderScalingConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
maxVCpuCount
The maximum number of vCPUs that the capacity provider can provision across all compute instances.
- Returns:
- The maximum number of vCPUs that the capacity provider can provision across all compute instances.
-
scalingMode
The scaling mode that determines how the capacity provider responds to changes in demand.
If the service returns an enum value that is not available in the current SDK version,
scalingModewill returnCapacityProviderScalingMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromscalingModeAsString().- Returns:
- The scaling mode that determines how the capacity provider responds to changes in demand.
- See Also:
-
scalingModeAsString
The scaling mode that determines how the capacity provider responds to changes in demand.
If the service returns an enum value that is not available in the current SDK version,
scalingModewill returnCapacityProviderScalingMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromscalingModeAsString().- Returns:
- The scaling mode that determines how the capacity provider responds to changes in demand.
- See Also:
-
hasScalingPolicies
public final boolean hasScalingPolicies()For responses, this returns true if the service returned a value for the ScalingPolicies property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
scalingPolicies
A list of scaling policies that define how the capacity provider scales compute instances based on metrics and thresholds.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasScalingPolicies()method.- Returns:
- A list of scaling policies that define how the capacity provider scales compute instances based on metrics and thresholds.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CapacityProviderScalingConfig.Builder,CapacityProviderScalingConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-