Interface CapacityProviderVpcConfig.Builder

All Superinterfaces:
Buildable, CopyableBuilder<CapacityProviderVpcConfig.Builder,CapacityProviderVpcConfig>, SdkBuilder<CapacityProviderVpcConfig.Builder,CapacityProviderVpcConfig>, SdkPojo
Enclosing class:
CapacityProviderVpcConfig

@Mutable @NotThreadSafe public static interface CapacityProviderVpcConfig.Builder extends SdkPojo, CopyableBuilder<CapacityProviderVpcConfig.Builder,CapacityProviderVpcConfig>
  • Method Details

    • subnetIds

      A list of subnet IDs where the capacity provider launches compute instances.

      Parameters:
      subnetIds - A list of subnet IDs where the capacity provider launches compute instances.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • subnetIds

      CapacityProviderVpcConfig.Builder subnetIds(String... subnetIds)

      A list of subnet IDs where the capacity provider launches compute instances.

      Parameters:
      subnetIds - A list of subnet IDs where the capacity provider launches compute instances.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • securityGroupIds

      CapacityProviderVpcConfig.Builder securityGroupIds(Collection<String> securityGroupIds)

      A list of security group IDs that control network access for compute instances managed by the capacity provider.

      Parameters:
      securityGroupIds - A list of security group IDs that control network access for compute instances managed by the capacity provider.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • securityGroupIds

      CapacityProviderVpcConfig.Builder securityGroupIds(String... securityGroupIds)

      A list of security group IDs that control network access for compute instances managed by the capacity provider.

      Parameters:
      securityGroupIds - A list of security group IDs that control network access for compute instances managed by the capacity provider.
      Returns:
      Returns a reference to this object so that method calls can be chained together.