Class ChainedInvokeOptions
java.lang.Object
software.amazon.awssdk.services.lambda.model.ChainedInvokeOptions
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ChainedInvokeOptions.Builder,ChainedInvokeOptions>
@Generated("software.amazon.awssdk:codegen")
public final class ChainedInvokeOptions
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ChainedInvokeOptions.Builder,ChainedInvokeOptions>
Configuration options for chained function invocations in durable executions, including retry settings and timeout configuration.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ChainedInvokeOptions.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function to invoke.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends ChainedInvokeOptions.Builder>final StringtenantId()The tenant identifier for the chained invocation.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function to invoke.
- Returns:
- The name or ARN of the Lambda function to invoke.
-
tenantId
The tenant identifier for the chained invocation.
- Returns:
- The tenant identifier for the chained invocation.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ChainedInvokeOptions.Builder,ChainedInvokeOptions>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-