Interface ChainedInvokeOptions.Builder

All Superinterfaces:
Buildable, CopyableBuilder<ChainedInvokeOptions.Builder,ChainedInvokeOptions>, SdkBuilder<ChainedInvokeOptions.Builder,ChainedInvokeOptions>, SdkPojo
Enclosing class:
ChainedInvokeOptions

@Mutable @NotThreadSafe public static interface ChainedInvokeOptions.Builder extends SdkPojo, CopyableBuilder<ChainedInvokeOptions.Builder,ChainedInvokeOptions>
  • Method Details

    • functionName

      ChainedInvokeOptions.Builder functionName(String functionName)

      The name or ARN of the Lambda function to invoke.

      Parameters:
      functionName - The name or ARN of the Lambda function to invoke.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • tenantId

      The tenant identifier for the chained invocation.

      Parameters:
      tenantId - The tenant identifier for the chained invocation.
      Returns:
      Returns a reference to this object so that method calls can be chained together.