Class ChainedInvokeStartedDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.ChainedInvokeStartedDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ChainedInvokeStartedDetails.Builder,ChainedInvokeStartedDetails>
@Generated("software.amazon.awssdk:codegen")
public final class ChainedInvokeStartedDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ChainedInvokeStartedDetails.Builder,ChainedInvokeStartedDetails>
Contains details about a chained function invocation that has started execution, including start time and execution context.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe Amazon Resource Name (ARN) that identifies the durable execution.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe version of the function that was executed.final StringThe name or ARN of the Lambda function being invoked.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final EventInputinput()The JSON input payload provided to the chained invocation.static Class<? extends ChainedInvokeStartedDetails.Builder>final StringtenantId()The tenant identifier for the chained invocation.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function being invoked.
- Returns:
- The name or ARN of the Lambda function being invoked.
-
tenantId
The tenant identifier for the chained invocation.
- Returns:
- The tenant identifier for the chained invocation.
-
input
The JSON input payload provided to the chained invocation.
- Returns:
- The JSON input payload provided to the chained invocation.
-
executedVersion
The version of the function that was executed.
- Returns:
- The version of the function that was executed.
-
durableExecutionArn
The Amazon Resource Name (ARN) that identifies the durable execution.
- Returns:
- The Amazon Resource Name (ARN) that identifies the durable execution.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ChainedInvokeStartedDetails.Builder,ChainedInvokeStartedDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-