Class CheckpointDurableExecutionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CheckpointDurableExecutionRequest.Builder,CheckpointDurableExecutionRequest>

@Generated("software.amazon.awssdk:codegen") public final class CheckpointDurableExecutionRequest extends LambdaRequest implements ToCopyableBuilder<CheckpointDurableExecutionRequest.Builder,CheckpointDurableExecutionRequest>
  • Method Details

    • durableExecutionArn

      public final String durableExecutionArn()

      The Amazon Resource Name (ARN) of the durable execution.

      Returns:
      The Amazon Resource Name (ARN) of the durable execution.
    • checkpointToken

      public final String checkpointToken()

      A unique token that identifies the current checkpoint state. This token is provided by the Lambda runtime and must be used to ensure checkpoints are applied in the correct order. Each checkpoint operation consumes this token and returns a new one.

      Returns:
      A unique token that identifies the current checkpoint state. This token is provided by the Lambda runtime and must be used to ensure checkpoints are applied in the correct order. Each checkpoint operation consumes this token and returns a new one.
    • hasUpdates

      public final boolean hasUpdates()
      For responses, this returns true if the service returned a value for the Updates property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • updates

      public final List<OperationUpdate> updates()

      An array of state updates to apply during this checkpoint. Each update represents a change to the execution state, such as completing a step, starting a callback, or scheduling a timer. Updates are applied atomically as part of the checkpoint operation.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasUpdates() method.

      Returns:
      An array of state updates to apply during this checkpoint. Each update represents a change to the execution state, such as completing a step, starting a callback, or scheduling a timer. Updates are applied atomically as part of the checkpoint operation.
    • clientToken

      public final String clientToken()

      An optional idempotency token to ensure that duplicate checkpoint requests are handled correctly. If provided, Lambda uses this token to detect and handle duplicate requests within a 15-minute window.

      Returns:
      An optional idempotency token to ensure that duplicate checkpoint requests are handled correctly. If provided, Lambda uses this token to detect and handle duplicate requests within a 15-minute window.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<CheckpointDurableExecutionRequest.Builder,CheckpointDurableExecutionRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends CheckpointDurableExecutionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo