Class CheckpointDurableExecutionResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.lambda.model.LambdaResponse
software.amazon.awssdk.services.lambda.model.CheckpointDurableExecutionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CheckpointDurableExecutionResponse.Builder,CheckpointDurableExecutionResponse>
@Generated("software.amazon.awssdk:codegen")
public final class CheckpointDurableExecutionResponse
extends LambdaResponse
implements ToCopyableBuilder<CheckpointDurableExecutionResponse.Builder,CheckpointDurableExecutionResponse>
The response from the CheckpointDurableExecution operation.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringA new checkpoint token to use for the next checkpoint operation.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers.static Class<? extends CheckpointDurableExecutionResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
checkpointToken
A new checkpoint token to use for the next checkpoint operation. This token replaces the one provided in the request and must be used for subsequent checkpoints to maintain proper ordering.
- Returns:
- A new checkpoint token to use for the next checkpoint operation. This token replaces the one provided in the request and must be used for subsequent checkpoints to maintain proper ordering.
-
newExecutionState
Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers. This allows the SDK to update its internal state during replay.
- Returns:
- Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers. This allows the SDK to update its internal state during replay.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CheckpointDurableExecutionResponse.Builder,CheckpointDurableExecutionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends CheckpointDurableExecutionResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-