Class CheckpointUpdatedExecutionState
java.lang.Object
software.amazon.awssdk.services.lambda.model.CheckpointUpdatedExecutionState
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CheckpointUpdatedExecutionState.Builder,CheckpointUpdatedExecutionState>
@Generated("software.amazon.awssdk:codegen")
public final class CheckpointUpdatedExecutionState
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<CheckpointUpdatedExecutionState.Builder,CheckpointUpdatedExecutionState>
Contains operations that have been updated since the last checkpoint, such as completed asynchronous work like timers or callbacks.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Operations property.final StringIndicates that more results are available.A list of operations that have been updated since the last checkpoint.static Class<? extends CheckpointUpdatedExecutionState.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasOperations
public final boolean hasOperations()For responses, this returns true if the service returned a value for the Operations property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
operations
A list of operations that have been updated since the last checkpoint.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasOperations()method.- Returns:
- A list of operations that have been updated since the last checkpoint.
-
nextMarker
Indicates that more results are available. Use this value in a subsequent call to retrieve the next page of results.
- Returns:
- Indicates that more results are available. Use this value in a subsequent call to retrieve the next page of results.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CheckpointUpdatedExecutionState.Builder,CheckpointUpdatedExecutionState>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-