Class CodeSigningPolicies
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CodeSigningPolicies.Builder,CodeSigningPolicies>
Code signing configuration policies specify the validation failure action for signature mismatch or expiry.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CodeSigningPolicies.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends CodeSigningPolicies.Builder>final StringtoString()Returns a string representation of this object.final CodeSigningPolicyCode signing configuration policy for deployment validation failure.final StringCode signing configuration policy for deployment validation failure.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
untrustedArtifactOnDeployment
Code signing configuration policy for deployment validation failure. If you set the policy to
Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy toWarn, Lambda allows the deployment and issues a new Amazon CloudWatch metric (SignatureValidationErrors) and also stores the warning in the CloudTrail log.Default value:
WarnIf the service returns an enum value that is not available in the current SDK version,
untrustedArtifactOnDeploymentwill returnCodeSigningPolicy.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromuntrustedArtifactOnDeploymentAsString().- Returns:
- Code signing configuration policy for deployment validation failure. If you set the policy to
Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy toWarn, Lambda allows the deployment and issues a new Amazon CloudWatch metric (SignatureValidationErrors) and also stores the warning in the CloudTrail log.Default value:
Warn - See Also:
-
untrustedArtifactOnDeploymentAsString
Code signing configuration policy for deployment validation failure. If you set the policy to
Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy toWarn, Lambda allows the deployment and issues a new Amazon CloudWatch metric (SignatureValidationErrors) and also stores the warning in the CloudTrail log.Default value:
WarnIf the service returns an enum value that is not available in the current SDK version,
untrustedArtifactOnDeploymentwill returnCodeSigningPolicy.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromuntrustedArtifactOnDeploymentAsString().- Returns:
- Code signing configuration policy for deployment validation failure. If you set the policy to
Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy toWarn, Lambda allows the deployment and issues a new Amazon CloudWatch metric (SignatureValidationErrors) and also stores the warning in the CloudTrail log.Default value:
Warn - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CodeSigningPolicies.Builder,CodeSigningPolicies>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-