Class ContextDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.ContextDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ContextDetails.Builder,ContextDetails>
@Generated("software.amazon.awssdk:codegen")
public final class ContextDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ContextDetails.Builder,ContextDetails>
Details about a durable execution context.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ContextDetails.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final ErrorObjecterror()Details about the context failure.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanWhether the state data of child operations of this completed context should be included in the invoke payload andGetDurableExecutionStateresponse.final Stringresult()The response payload from the context.static Class<? extends ContextDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
replayChildren
Whether the state data of child operations of this completed context should be included in the invoke payload and
GetDurableExecutionStateresponse.- Returns:
- Whether the state data of child operations of this completed context should be included in the invoke
payload and
GetDurableExecutionStateresponse.
-
result
The response payload from the context.
- Returns:
- The response payload from the context.
-
error
Details about the context failure.
- Returns:
- Details about the context failure.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ContextDetails.Builder,ContextDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-