Interface ContextOptions.Builder

All Superinterfaces:
Buildable, CopyableBuilder<ContextOptions.Builder,ContextOptions>, SdkBuilder<ContextOptions.Builder,ContextOptions>, SdkPojo
Enclosing class:
ContextOptions

@Mutable @NotThreadSafe public static interface ContextOptions.Builder extends SdkPojo, CopyableBuilder<ContextOptions.Builder,ContextOptions>
  • Method Details

    • replayChildren

      ContextOptions.Builder replayChildren(Boolean replayChildren)

      Whether the state data of children of the completed context should be included in the invoke payload and GetDurableExecutionState response.

      Parameters:
      replayChildren - Whether the state data of children of the completed context should be included in the invoke payload and GetDurableExecutionState response.
      Returns:
      Returns a reference to this object so that method calls can be chained together.