Class CreateCapacityProviderRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateCapacityProviderRequest.Builder,CreateCapacityProviderRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe name of the capacity provider.The scaling configuration that defines how the capacity provider scales compute instances, including maximum vCPU count and scaling policies.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.final InstanceRequirementsThe instance requirements that specify the compute instance characteristics, including architectures and allowed or excluded instance types.final StringThe ARN of the KMS key used to encrypt data associated with the capacity provider.The permissions configuration that specifies the IAM role ARN used by the capacity provider to manage compute resources.static Class<? extends CreateCapacityProviderRequest.Builder>tags()A list of tags to associate with the capacity provider.final StringtoString()Returns a string representation of this object.The VPC configuration for the capacity provider, including subnet IDs and security group IDs where compute instances will be launched.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
capacityProviderName
The name of the capacity provider.
- Returns:
- The name of the capacity provider.
-
vpcConfig
The VPC configuration for the capacity provider, including subnet IDs and security group IDs where compute instances will be launched.
- Returns:
- The VPC configuration for the capacity provider, including subnet IDs and security group IDs where compute instances will be launched.
-
permissionsConfig
The permissions configuration that specifies the IAM role ARN used by the capacity provider to manage compute resources.
- Returns:
- The permissions configuration that specifies the IAM role ARN used by the capacity provider to manage compute resources.
-
instanceRequirements
The instance requirements that specify the compute instance characteristics, including architectures and allowed or excluded instance types.
- Returns:
- The instance requirements that specify the compute instance characteristics, including architectures and allowed or excluded instance types.
-
capacityProviderScalingConfig
The scaling configuration that defines how the capacity provider scales compute instances, including maximum vCPU count and scaling policies.
- Returns:
- The scaling configuration that defines how the capacity provider scales compute instances, including maximum vCPU count and scaling policies.
-
kmsKeyArn
The ARN of the KMS key used to encrypt data associated with the capacity provider.
- Returns:
- The ARN of the KMS key used to encrypt data associated with the capacity provider.
-
hasTags
public final boolean hasTags()For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tags
A list of tags to associate with the capacity provider.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- A list of tags to associate with the capacity provider.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateCapacityProviderRequest.Builder,CreateCapacityProviderRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-