Class CreateCodeSigningConfigRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.lambda.model.LambdaRequest
software.amazon.awssdk.services.lambda.model.CreateCodeSigningConfigRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateCodeSigningConfigRequest.Builder,CreateCodeSigningConfigRequest>
@Generated("software.amazon.awssdk:codegen")
public final class CreateCodeSigningConfigRequest
extends LambdaRequest
implements ToCopyableBuilder<CreateCodeSigningConfigRequest.Builder,CreateCodeSigningConfigRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal AllowedPublishersSigning profiles for this code signing configuration.builder()final CodeSigningPoliciesThe code signing policies define the actions to take if the validation checks fail.final StringDescriptive name for this code signing configuration.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.static Class<? extends CreateCodeSigningConfigRequest.Builder>tags()A list of tags to add to the code signing configuration.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
description
Descriptive name for this code signing configuration.
- Returns:
- Descriptive name for this code signing configuration.
-
allowedPublishers
Signing profiles for this code signing configuration.
- Returns:
- Signing profiles for this code signing configuration.
-
codeSigningPolicies
The code signing policies define the actions to take if the validation checks fail.
- Returns:
- The code signing policies define the actions to take if the validation checks fail.
-
hasTags
public final boolean hasTags()For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tags
A list of tags to add to the code signing configuration.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- A list of tags to add to the code signing configuration.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateCodeSigningConfigRequest.Builder,CreateCodeSigningConfigRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-