Class CreateFunctionUrlConfigResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CreateFunctionUrlConfigResponse.Builder,CreateFunctionUrlConfigResponse>

@Generated("software.amazon.awssdk:codegen") public final class CreateFunctionUrlConfigResponse extends LambdaResponse implements ToCopyableBuilder<CreateFunctionUrlConfigResponse.Builder,CreateFunctionUrlConfigResponse>
  • Method Details

    • functionUrl

      public final String functionUrl()

      The HTTP URL endpoint for your function.

      Returns:
      The HTTP URL endpoint for your function.
    • functionArn

      public final String functionArn()

      The Amazon Resource Name (ARN) of your function.

      Returns:
      The Amazon Resource Name (ARN) of your function.
    • authType

      public final FunctionUrlAuthType authType()

      The type of authentication that your function URL uses. Set to AWS_IAM if you want to restrict access to authenticated users only. Set to NONE if you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs.

      If the service returns an enum value that is not available in the current SDK version, authType will return FunctionUrlAuthType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from authTypeAsString().

      Returns:
      The type of authentication that your function URL uses. Set to AWS_IAM if you want to restrict access to authenticated users only. Set to NONE if you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs.
      See Also:
    • authTypeAsString

      public final String authTypeAsString()

      The type of authentication that your function URL uses. Set to AWS_IAM if you want to restrict access to authenticated users only. Set to NONE if you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs.

      If the service returns an enum value that is not available in the current SDK version, authType will return FunctionUrlAuthType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from authTypeAsString().

      Returns:
      The type of authentication that your function URL uses. Set to AWS_IAM if you want to restrict access to authenticated users only. Set to NONE if you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs.
      See Also:
    • cors

      public final Cors cors()

      The cross-origin resource sharing (CORS) settings for your function URL.

      Returns:
      The cross-origin resource sharing (CORS) settings for your function URL.
    • creationTime

      public final String creationTime()

      When the function URL was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

      Returns:
      When the function URL was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
    • invokeMode

      public final InvokeMode invokeMode()

      Use one of the following options:

      • BUFFERED – This is the default option. Lambda invokes your function using the Invoke API operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB.

      • RESPONSE_STREAM – Your function streams payload results as they become available. Lambda invokes your function using the InvokeWithResponseStream API operation. The maximum response payload size is 200 MB.

      If the service returns an enum value that is not available in the current SDK version, invokeMode will return InvokeMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from invokeModeAsString().

      Returns:
      Use one of the following options:

      • BUFFERED – This is the default option. Lambda invokes your function using the Invoke API operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB.

      • RESPONSE_STREAM – Your function streams payload results as they become available. Lambda invokes your function using the InvokeWithResponseStream API operation. The maximum response payload size is 200 MB.

      See Also:
    • invokeModeAsString

      public final String invokeModeAsString()

      Use one of the following options:

      • BUFFERED – This is the default option. Lambda invokes your function using the Invoke API operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB.

      • RESPONSE_STREAM – Your function streams payload results as they become available. Lambda invokes your function using the InvokeWithResponseStream API operation. The maximum response payload size is 200 MB.

      If the service returns an enum value that is not available in the current SDK version, invokeMode will return InvokeMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from invokeModeAsString().

      Returns:
      Use one of the following options:

      • BUFFERED – This is the default option. Lambda invokes your function using the Invoke API operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB.

      • RESPONSE_STREAM – Your function streams payload results as they become available. Lambda invokes your function using the InvokeWithResponseStream API operation. The maximum response payload size is 200 MB.

      See Also:
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<CreateFunctionUrlConfigResponse.Builder,CreateFunctionUrlConfigResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static CreateFunctionUrlConfigResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends CreateFunctionUrlConfigResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo