Interface DeleteAliasRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<DeleteAliasRequest.Builder,DeleteAliasRequest>, LambdaRequest.Builder, SdkBuilder<DeleteAliasRequest.Builder,DeleteAliasRequest>, SdkPojo, SdkRequest.Builder
Enclosing class:
DeleteAliasRequest

  • Method Details

    • functionName

      DeleteAliasRequest.Builder functionName(String functionName)

      The name or ARN of the Lambda function.

      Name formats

      • Function name - MyFunction.

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

      • Partial ARN - 123456789012:function:MyFunction.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Parameters:
      functionName - The name or ARN of the Lambda function.

      Name formats

      • Function name - MyFunction.

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

      • Partial ARN - 123456789012:function:MyFunction.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • name

      The name of the alias.

      Parameters:
      name - The name of the alias.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      DeleteAliasRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder