Class DeleteFunctionCodeSigningConfigRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.lambda.model.LambdaRequest
software.amazon.awssdk.services.lambda.model.DeleteFunctionCodeSigningConfigRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DeleteFunctionCodeSigningConfigRequest.Builder,DeleteFunctionCodeSigningConfigRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DeleteFunctionCodeSigningConfigRequest
extends LambdaRequest
implements ToCopyableBuilder<DeleteFunctionCodeSigningConfigRequest.Builder,DeleteFunctionCodeSigningConfigRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends DeleteFunctionCodeSigningConfigRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Returns:
- The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DeleteFunctionCodeSigningConfigRequest.Builder,DeleteFunctionCodeSigningConfigRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
public static Class<? extends DeleteFunctionCodeSigningConfigRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-