Interface DeleteFunctionEventInvokeConfigRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<DeleteFunctionEventInvokeConfigRequest.Builder,DeleteFunctionEventInvokeConfigRequest>, LambdaRequest.Builder, SdkBuilder<DeleteFunctionEventInvokeConfigRequest.Builder,DeleteFunctionEventInvokeConfigRequest>, SdkPojo, SdkRequest.Builder
Enclosing class:
DeleteFunctionEventInvokeConfigRequest

  • Method Details

    • functionName

      The name or ARN of the Lambda function, version, or alias.

      Name formats

      • Function name - my-function (name-only), my-function:v1 (with alias).

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN - 123456789012:function:my-function.

      You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Parameters:
      functionName - The name or ARN of the Lambda function, version, or alias.

      Name formats

      • Function name - my-function (name-only), my-function:v1 (with alias).

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN - 123456789012:function:my-function.

      You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • qualifier

      A version number or alias name.

      Parameters:
      qualifier - A version number or alias name.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder