Class DeleteFunctionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<DeleteFunctionRequest.Builder,DeleteFunctionRequest>

@Generated("software.amazon.awssdk:codegen") public final class DeleteFunctionRequest extends LambdaRequest implements ToCopyableBuilder<DeleteFunctionRequest.Builder,DeleteFunctionRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function or version.

      Name formats

      • Function namemy-function (name-only), my-function:1 (with version).

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      The name or ARN of the Lambda function or version.

      Name formats

      • Function namemy-function (name-only), my-function:1 (with version).

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    • qualifier

      public final String qualifier()

      Specify a version to delete. You can't delete a version that an alias references.

      Returns:
      Specify a version to delete. You can't delete a version that an alias references.
    • toBuilder

      public DeleteFunctionRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<DeleteFunctionRequest.Builder,DeleteFunctionRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static DeleteFunctionRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends DeleteFunctionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo