Interface DurableConfig.Builder

All Superinterfaces:
Buildable, CopyableBuilder<DurableConfig.Builder,DurableConfig>, SdkBuilder<DurableConfig.Builder,DurableConfig>, SdkPojo
Enclosing class:
DurableConfig

@Mutable @NotThreadSafe public static interface DurableConfig.Builder extends SdkPojo, CopyableBuilder<DurableConfig.Builder,DurableConfig>
  • Method Details

    • retentionPeriodInDays

      DurableConfig.Builder retentionPeriodInDays(Integer retentionPeriodInDays)

      The number of days to retain execution history after a durable execution completes. After this period, execution history is no longer available through the GetDurableExecutionHistory API.

      Parameters:
      retentionPeriodInDays - The number of days to retain execution history after a durable execution completes. After this period, execution history is no longer available through the GetDurableExecutionHistory API.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • executionTimeout

      DurableConfig.Builder executionTimeout(Integer executionTimeout)

      The maximum time (in seconds) that a durable execution can run before timing out. This timeout applies to the entire durable execution, not individual function invocations.

      Parameters:
      executionTimeout - The maximum time (in seconds) that a durable execution can run before timing out. This timeout applies to the entire durable execution, not individual function invocations.
      Returns:
      Returns a reference to this object so that method calls can be chained together.