Class DurableExecutionAlreadyStartedException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
software.amazon.awssdk.core.exception.SdkException
software.amazon.awssdk.core.exception.SdkServiceException
software.amazon.awssdk.awscore.exception.AwsServiceException
software.amazon.awssdk.services.lambda.model.LambdaException
software.amazon.awssdk.services.lambda.model.DurableExecutionAlreadyStartedException
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DurableExecutionAlreadyStartedException.Builder,DurableExecutionAlreadyStartedException>
@Generated("software.amazon.awssdk:codegen")
public final class DurableExecutionAlreadyStartedException
extends LambdaException
implements ToCopyableBuilder<DurableExecutionAlreadyStartedException.Builder,DurableExecutionAlreadyStartedException>
The durable execution with the specified name has already been started. Each durable execution name must be unique within the function. Use a different name or check the status of the existing execution.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()static Class<? extends DurableExecutionAlreadyStartedException.Builder>type()The exception type.Methods inherited from class software.amazon.awssdk.awscore.exception.AwsServiceException
awsErrorDetails, getMessage, isClockSkewException, isThrottlingExceptionMethods inherited from class software.amazon.awssdk.core.exception.SdkServiceException
extendedRequestId, isRetryableException, requestId, statusCodeMethods inherited from class software.amazon.awssdk.core.exception.SdkException
create, numAttempts, rawMessage, retryableMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFieldsMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DurableExecutionAlreadyStartedException.Builder,DurableExecutionAlreadyStartedException> - Overrides:
toBuilderin classLambdaException
-
builder
-
serializableBuilderClass
public static Class<? extends DurableExecutionAlreadyStartedException.Builder> serializableBuilderClass() -
type
The exception type.
- Returns:
- The exception type.
-
sdkFields
- Specified by:
sdkFieldsin interfaceSdkPojo- Overrides:
sdkFieldsin classSdkServiceException
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-