Class EniNotReadyException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
software.amazon.awssdk.core.exception.SdkException
software.amazon.awssdk.core.exception.SdkServiceException
software.amazon.awssdk.awscore.exception.AwsServiceException
software.amazon.awssdk.services.lambda.model.LambdaException
software.amazon.awssdk.services.lambda.model.EniNotReadyException
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<EniNotReadyException.Builder,EniNotReadyException>
@Generated("software.amazon.awssdk:codegen")
public final class EniNotReadyException
extends LambdaException
implements ToCopyableBuilder<EniNotReadyException.Builder,EniNotReadyException>
Lambda couldn't invoke the Lambda function because the elastic network interface (ENI) configured for its VPC connection isn't ready yet. Wait a few moments and try the request again. For more information about VPC configuration, see Configuring a Lambda function to access resources in a VPC.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic EniNotReadyException.Builderbuilder()static Class<? extends EniNotReadyException.Builder>type()The exception type.Methods inherited from class software.amazon.awssdk.awscore.exception.AwsServiceException
awsErrorDetails, getMessage, isClockSkewException, isThrottlingExceptionMethods inherited from class software.amazon.awssdk.core.exception.SdkServiceException
extendedRequestId, isRetryableException, requestId, statusCodeMethods inherited from class software.amazon.awssdk.core.exception.SdkException
create, numAttempts, rawMessage, retryableMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFieldsMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<EniNotReadyException.Builder,EniNotReadyException> - Overrides:
toBuilderin classLambdaException
-
builder
-
serializableBuilderClass
-
type
The exception type.
- Returns:
- The exception type.
-
sdkFields
- Specified by:
sdkFieldsin interfaceSdkPojo- Overrides:
sdkFieldsin classSdkServiceException
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-