Class ErrorObject
java.lang.Object
software.amazon.awssdk.services.lambda.model.ErrorObject
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ErrorObject.Builder,ErrorObject>
@Generated("software.amazon.awssdk:codegen")
public final class ErrorObject
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ErrorObject.Builder,ErrorObject>
An object that contains error information.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ErrorObject.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringMachine-readable error data.final StringA human-readable error message.final StringThe error type.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the StackTrace property.static Class<? extends ErrorObject.Builder>Stack trace information for the error.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
errorMessage
A human-readable error message.
- Returns:
- A human-readable error message.
-
errorType
The error type.
- Returns:
- The error type.
-
errorData
Machine-readable error data.
- Returns:
- Machine-readable error data.
-
hasStackTrace
public final boolean hasStackTrace()For responses, this returns true if the service returned a value for the StackTrace property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
stackTrace
Stack trace information for the error.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasStackTrace()method.- Returns:
- Stack trace information for the error.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ErrorObject.Builder,ErrorObject>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-