Class Event
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Event.Builder,Event>
An event that occurred during the execution of a durable function.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Event.Builderbuilder()final CallbackFailedDetailsReturns the value of the CallbackFailedDetails property for this object.final CallbackStartedDetailsReturns the value of the CallbackStartedDetails property for this object.final CallbackSucceededDetailsReturns the value of the CallbackSucceededDetails property for this object.final CallbackTimedOutDetailsReturns the value of the CallbackTimedOutDetails property for this object.Returns the value of the ChainedInvokeFailedDetails property for this object.Returns the value of the ChainedInvokeStartedDetails property for this object.Details about a chained invocation that was stopped.Details about a chained invocation that succeeded.Details about a chained invocation that timed out.final ContextFailedDetailsDetails about a context that failed.final ContextStartedDetailsDetails about a context that started.final ContextSucceededDetailsDetails about a context that succeeded.final booleanfinal booleanequalsBySdkFields(Object obj) final IntegereventId()The unique identifier for this event.final InstantThe date and time when this event occurred, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).final EventTypeThe type of event that occurred.final StringThe type of event that occurred.final ExecutionFailedDetailsDetails about an execution that failed.final ExecutionStartedDetailsDetails about an execution that started.final ExecutionStoppedDetailsDetails about an execution that was stopped.Details about an execution that succeeded.final ExecutionTimedOutDetailsDetails about an execution that timed out.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringid()The unique identifier for this operation.Details about a function invocation that completed.final Stringname()The customer-provided name for this operation.final StringparentId()The unique identifier of the parent operation, if this operation is running within a child context.static Class<? extends Event.Builder>final StepFailedDetailsDetails about a step that failed.final StepStartedDetailsDetails about a step that started.final StepSucceededDetailsDetails about a step that succeeded.final StringsubType()The subtype of the event, providing additional categorization.final StringtoString()Returns a string representation of this object.final WaitCancelledDetailsDetails about a wait operation that was cancelled.final WaitStartedDetailsDetails about a wait operation that started.final WaitSucceededDetailsDetails about a wait operation that succeeded.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
eventType
The type of event that occurred.
If the service returns an enum value that is not available in the current SDK version,
eventTypewill returnEventType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromeventTypeAsString().- Returns:
- The type of event that occurred.
- See Also:
-
eventTypeAsString
The type of event that occurred.
If the service returns an enum value that is not available in the current SDK version,
eventTypewill returnEventType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromeventTypeAsString().- Returns:
- The type of event that occurred.
- See Also:
-
subType
The subtype of the event, providing additional categorization.
- Returns:
- The subtype of the event, providing additional categorization.
-
eventId
The unique identifier for this event. Event IDs increment sequentially.
- Returns:
- The unique identifier for this event. Event IDs increment sequentially.
-
id
The unique identifier for this operation.
- Returns:
- The unique identifier for this operation.
-
name
The customer-provided name for this operation.
- Returns:
- The customer-provided name for this operation.
-
eventTimestamp
The date and time when this event occurred, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- The date and time when this event occurred, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
parentId
The unique identifier of the parent operation, if this operation is running within a child context.
- Returns:
- The unique identifier of the parent operation, if this operation is running within a child context.
-
executionStartedDetails
Details about an execution that started.
- Returns:
- Details about an execution that started.
-
executionSucceededDetails
Details about an execution that succeeded.
- Returns:
- Details about an execution that succeeded.
-
executionFailedDetails
Details about an execution that failed.
- Returns:
- Details about an execution that failed.
-
executionTimedOutDetails
Details about an execution that timed out.
- Returns:
- Details about an execution that timed out.
-
executionStoppedDetails
Details about an execution that was stopped.
- Returns:
- Details about an execution that was stopped.
-
contextStartedDetails
Details about a context that started.
- Returns:
- Details about a context that started.
-
contextSucceededDetails
Details about a context that succeeded.
- Returns:
- Details about a context that succeeded.
-
contextFailedDetails
Details about a context that failed.
- Returns:
- Details about a context that failed.
-
waitStartedDetails
Details about a wait operation that started.
- Returns:
- Details about a wait operation that started.
-
waitSucceededDetails
Details about a wait operation that succeeded.
- Returns:
- Details about a wait operation that succeeded.
-
waitCancelledDetails
Details about a wait operation that was cancelled.
- Returns:
- Details about a wait operation that was cancelled.
-
stepStartedDetails
Details about a step that started.
- Returns:
- Details about a step that started.
-
stepSucceededDetails
Details about a step that succeeded.
- Returns:
- Details about a step that succeeded.
-
stepFailedDetails
Details about a step that failed.
- Returns:
- Details about a step that failed.
-
chainedInvokeStartedDetails
Returns the value of the ChainedInvokeStartedDetails property for this object.- Returns:
- The value of the ChainedInvokeStartedDetails property for this object.
-
chainedInvokeSucceededDetails
Details about a chained invocation that succeeded.
- Returns:
- Details about a chained invocation that succeeded.
-
chainedInvokeFailedDetails
Returns the value of the ChainedInvokeFailedDetails property for this object.- Returns:
- The value of the ChainedInvokeFailedDetails property for this object.
-
chainedInvokeTimedOutDetails
Details about a chained invocation that timed out.
- Returns:
- Details about a chained invocation that timed out.
-
chainedInvokeStoppedDetails
Details about a chained invocation that was stopped.
- Returns:
- Details about a chained invocation that was stopped.
-
callbackStartedDetails
Returns the value of the CallbackStartedDetails property for this object.- Returns:
- The value of the CallbackStartedDetails property for this object.
-
callbackSucceededDetails
Returns the value of the CallbackSucceededDetails property for this object.- Returns:
- The value of the CallbackSucceededDetails property for this object.
-
callbackFailedDetails
Returns the value of the CallbackFailedDetails property for this object.- Returns:
- The value of the CallbackFailedDetails property for this object.
-
callbackTimedOutDetails
Returns the value of the CallbackTimedOutDetails property for this object.- Returns:
- The value of the CallbackTimedOutDetails property for this object.
-
invocationCompletedDetails
Details about a function invocation that completed.
- Returns:
- Details about a function invocation that completed.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Event.Builder,Event>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-