Class EventError
java.lang.Object
software.amazon.awssdk.services.lambda.model.EventError
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<EventError.Builder,EventError>
@Generated("software.amazon.awssdk:codegen")
public final class EventError
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<EventError.Builder,EventError>
Error information for an event.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic EventError.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final ErrorObjectpayload()The error payload.static Class<? extends EventError.Builder>final StringtoString()Returns a string representation of this object.final BooleanIndicates if the error payload was truncated due to size limits.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
payload
The error payload.
- Returns:
- The error payload.
-
truncated
Indicates if the error payload was truncated due to size limits.
- Returns:
- Indicates if the error payload was truncated due to size limits.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<EventError.Builder,EventError>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-