Class EventInput
java.lang.Object
software.amazon.awssdk.services.lambda.model.EventInput
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<EventInput.Builder,EventInput>
@Generated("software.amazon.awssdk:codegen")
public final class EventInput
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<EventInput.Builder,EventInput>
Input information for an event.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic EventInput.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringpayload()The input payload.static Class<? extends EventInput.Builder>final StringtoString()Returns a string representation of this object.final BooleanIndicates if the error payload was truncated due to size limits.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
payload
The input payload.
- Returns:
- The input payload.
-
truncated
Indicates if the error payload was truncated due to size limits.
- Returns:
- Indicates if the error payload was truncated due to size limits.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<EventInput.Builder,EventInput>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-