Class EventResult
java.lang.Object
software.amazon.awssdk.services.lambda.model.EventResult
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<EventResult.Builder,EventResult>
@Generated("software.amazon.awssdk:codegen")
public final class EventResult
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<EventResult.Builder,EventResult>
Result information for an event.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic EventResult.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringpayload()The result payload.static Class<? extends EventResult.Builder>final StringtoString()Returns a string representation of this object.final BooleanIndicates if the error payload was truncated due to size limits.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
payload
The result payload.
- Returns:
- The result payload.
-
truncated
Indicates if the error payload was truncated due to size limits.
- Returns:
- Indicates if the error payload was truncated due to size limits.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<EventResult.Builder,EventResult>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-