Interface EventResult.Builder

All Superinterfaces:
Buildable, CopyableBuilder<EventResult.Builder,EventResult>, SdkBuilder<EventResult.Builder,EventResult>, SdkPojo
Enclosing class:
EventResult

@Mutable @NotThreadSafe public static interface EventResult.Builder extends SdkPojo, CopyableBuilder<EventResult.Builder,EventResult>
  • Method Details

    • payload

      EventResult.Builder payload(String payload)

      The result payload.

      Parameters:
      payload - The result payload.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • truncated

      EventResult.Builder truncated(Boolean truncated)

      Indicates if the error payload was truncated due to size limits.

      Parameters:
      truncated - Indicates if the error payload was truncated due to size limits.
      Returns:
      Returns a reference to this object so that method calls can be chained together.