Class EventSourceMappingLoggingConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<EventSourceMappingLoggingConfig.Builder,EventSourceMappingLoggingConfig>
(Amazon MSK, and self-managed Apache Kafka only) The logging configuration for your event source. Use this configuration object to define the level of logs for your event source mapping.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends EventSourceMappingLoggingConfig.Builder>The log level you want your event source mapping to use.final StringThe log level you want your event source mapping to use.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
systemLogLevel
The log level you want your event source mapping to use. Lambda event poller only sends system logs at the selected level of detail and lower, where
DEBUGis the highest level andWARNis the lowest. For more information about these metrics, see Event source mapping logging.If the service returns an enum value that is not available in the current SDK version,
systemLogLevelwill returnEventSourceMappingSystemLogLevel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsystemLogLevelAsString().- Returns:
- The log level you want your event source mapping to use. Lambda event poller only sends system logs at
the selected level of detail and lower, where
DEBUGis the highest level andWARNis the lowest. For more information about these metrics, see Event source mapping logging. - See Also:
-
systemLogLevelAsString
The log level you want your event source mapping to use. Lambda event poller only sends system logs at the selected level of detail and lower, where
DEBUGis the highest level andWARNis the lowest. For more information about these metrics, see Event source mapping logging.If the service returns an enum value that is not available in the current SDK version,
systemLogLevelwill returnEventSourceMappingSystemLogLevel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsystemLogLevelAsString().- Returns:
- The log level you want your event source mapping to use. Lambda event poller only sends system logs at
the selected level of detail and lower, where
DEBUGis the highest level andWARNis the lowest. For more information about these metrics, see Event source mapping logging. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<EventSourceMappingLoggingConfig.Builder,EventSourceMappingLoggingConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-