Interface EventSourceMappingMetricsConfig.Builder

All Superinterfaces:
Buildable, CopyableBuilder<EventSourceMappingMetricsConfig.Builder,EventSourceMappingMetricsConfig>, SdkBuilder<EventSourceMappingMetricsConfig.Builder,EventSourceMappingMetricsConfig>, SdkPojo
Enclosing class:
EventSourceMappingMetricsConfig

@Mutable @NotThreadSafe public static interface EventSourceMappingMetricsConfig.Builder extends SdkPojo, CopyableBuilder<EventSourceMappingMetricsConfig.Builder,EventSourceMappingMetricsConfig>
  • Method Details

    • metricsWithStrings

      The metrics you want your event source mapping to produce, including EventCount, ErrorCount, KafkaMetrics.

      • EventCount to receive metrics related to the number of events processed by your event source mapping.

      • ErrorCount (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing.

      • KafkaMetrics (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.

      For more information about these metrics, see Event source mapping metrics.

      Parameters:
      metrics - The metrics you want your event source mapping to produce, including EventCount, ErrorCount, KafkaMetrics.

      • EventCount to receive metrics related to the number of events processed by your event source mapping.

      • ErrorCount (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing.

      • KafkaMetrics (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.

      For more information about these metrics, see Event source mapping metrics.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • metricsWithStrings

      EventSourceMappingMetricsConfig.Builder metricsWithStrings(String... metrics)

      The metrics you want your event source mapping to produce, including EventCount, ErrorCount, KafkaMetrics.

      • EventCount to receive metrics related to the number of events processed by your event source mapping.

      • ErrorCount (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing.

      • KafkaMetrics (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.

      For more information about these metrics, see Event source mapping metrics.

      Parameters:
      metrics - The metrics you want your event source mapping to produce, including EventCount, ErrorCount, KafkaMetrics.

      • EventCount to receive metrics related to the number of events processed by your event source mapping.

      • ErrorCount (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing.

      • KafkaMetrics (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.

      For more information about these metrics, see Event source mapping metrics.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • metrics

      The metrics you want your event source mapping to produce, including EventCount, ErrorCount, KafkaMetrics.

      • EventCount to receive metrics related to the number of events processed by your event source mapping.

      • ErrorCount (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing.

      • KafkaMetrics (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.

      For more information about these metrics, see Event source mapping metrics.

      Parameters:
      metrics - The metrics you want your event source mapping to produce, including EventCount, ErrorCount, KafkaMetrics.

      • EventCount to receive metrics related to the number of events processed by your event source mapping.

      • ErrorCount (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing.

      • KafkaMetrics (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.

      For more information about these metrics, see Event source mapping metrics.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • metrics

      The metrics you want your event source mapping to produce, including EventCount, ErrorCount, KafkaMetrics.

      • EventCount to receive metrics related to the number of events processed by your event source mapping.

      • ErrorCount (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing.

      • KafkaMetrics (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.

      For more information about these metrics, see Event source mapping metrics.

      Parameters:
      metrics - The metrics you want your event source mapping to produce, including EventCount, ErrorCount, KafkaMetrics.

      • EventCount to receive metrics related to the number of events processed by your event source mapping.

      • ErrorCount (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing.

      • KafkaMetrics (Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.

      For more information about these metrics, see Event source mapping metrics.

      Returns:
      Returns a reference to this object so that method calls can be chained together.