java.lang.Object
software.amazon.awssdk.services.lambda.model.Execution
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<Execution.Builder,Execution>

@Generated("software.amazon.awssdk:codegen") public final class Execution extends Object implements SdkPojo, Serializable, ToCopyableBuilder<Execution.Builder,Execution>

Information about a durable execution.

See Also:
  • Method Details

    • durableExecutionArn

      public final String durableExecutionArn()

      The Amazon Resource Name (ARN) of the durable execution, if this execution is a durable execution.

      Returns:
      The Amazon Resource Name (ARN) of the durable execution, if this execution is a durable execution.
    • durableExecutionName

      public final String durableExecutionName()

      The unique name of the durable execution, if one was provided when the execution was started.

      Returns:
      The unique name of the durable execution, if one was provided when the execution was started.
    • functionArn

      public final String functionArn()

      The Amazon Resource Name (ARN) of the Lambda function.

      Returns:
      The Amazon Resource Name (ARN) of the Lambda function.
    • status

      public final ExecutionStatus status()

      The current status of the durable execution.

      If the service returns an enum value that is not available in the current SDK version, status will return ExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from statusAsString().

      Returns:
      The current status of the durable execution.
      See Also:
    • statusAsString

      public final String statusAsString()

      The current status of the durable execution.

      If the service returns an enum value that is not available in the current SDK version, status will return ExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from statusAsString().

      Returns:
      The current status of the durable execution.
      See Also:
    • startTimestamp

      public final Instant startTimestamp()

      The date and time when the durable execution started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

      Returns:
      The date and time when the durable execution started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
    • endTimestamp

      public final Instant endTimestamp()

      The date and time when the durable execution ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

      Returns:
      The date and time when the durable execution ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
    • toBuilder

      public Execution.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<Execution.Builder,Execution>
    • builder

      public static Execution.Builder builder()
    • serializableBuilderClass

      public static Class<? extends Execution.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo