Class ExecutionStartedDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.ExecutionStartedDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ExecutionStartedDetails.Builder,ExecutionStartedDetails>
@Generated("software.amazon.awssdk:codegen")
public final class ExecutionStartedDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ExecutionStartedDetails.Builder,ExecutionStartedDetails>
Details about a durable execution that started.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final IntegerThe maximum amount of time that the durable execution is allowed to run, in seconds.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final EventInputinput()The input payload provided for the durable execution.static Class<? extends ExecutionStartedDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
input
The input payload provided for the durable execution.
- Returns:
- The input payload provided for the durable execution.
-
executionTimeout
The maximum amount of time that the durable execution is allowed to run, in seconds.
- Returns:
- The maximum amount of time that the durable execution is allowed to run, in seconds.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ExecutionStartedDetails.Builder,ExecutionStartedDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-