Class FileSystemConfig
java.lang.Object
software.amazon.awssdk.services.lambda.model.FileSystemConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FileSystemConfig.Builder,FileSystemConfig>
@Generated("software.amazon.awssdk:codegen")
public final class FileSystemConfig
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<FileSystemConfig.Builder,FileSystemConfig>
Details about the connection between a Lambda function and an Amazon EFS file system or an Amazon S3 Files file system.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The Amazon Resource Name (ARN) of the Amazon EFS or Amazon S3 Files access point that provides access to the file system.static FileSystemConfig.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe path where the function can access the file system, starting with/mnt/.static Class<? extends FileSystemConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
arn
The Amazon Resource Name (ARN) of the Amazon EFS or Amazon S3 Files access point that provides access to the file system.
- Returns:
- The Amazon Resource Name (ARN) of the Amazon EFS or Amazon S3 Files access point that provides access to the file system.
-
localMountPath
The path where the function can access the file system, starting with
/mnt/.- Returns:
- The path where the function can access the file system, starting with
/mnt/.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FileSystemConfig.Builder,FileSystemConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-