Class FunctionCodeLocation
java.lang.Object
software.amazon.awssdk.services.lambda.model.FunctionCodeLocation
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FunctionCodeLocation.Builder,FunctionCodeLocation>
@Generated("software.amazon.awssdk:codegen")
public final class FunctionCodeLocation
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<FunctionCodeLocation.Builder,FunctionCodeLocation>
Details about a function's deployment package.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic FunctionCodeLocation.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringimageUri()URI of a container image in the Amazon ECR registry.final Stringlocation()A presigned URL that you can use to download the deployment package.final StringThe service that's hosting the file.final StringThe resolved URI for the image.static Class<? extends FunctionCodeLocation.Builder>final StringThe ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
repositoryType
The service that's hosting the file.
- Returns:
- The service that's hosting the file.
-
location
A presigned URL that you can use to download the deployment package.
- Returns:
- A presigned URL that you can use to download the deployment package.
-
imageUri
URI of a container image in the Amazon ECR registry.
- Returns:
- URI of a container image in the Amazon ECR registry.
-
resolvedImageUri
The resolved URI for the image.
- Returns:
- The resolved URI for the image.
-
sourceKMSKeyArn
The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package. If you don't provide a customer managed key, Lambda uses an Amazon Web Services owned key.
- Returns:
- The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package. If you don't provide a customer managed key, Lambda uses an Amazon Web Services owned key.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FunctionCodeLocation.Builder,FunctionCodeLocation>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-