Interface FunctionScalingConfig.Builder

All Superinterfaces:
Buildable, CopyableBuilder<FunctionScalingConfig.Builder,FunctionScalingConfig>, SdkBuilder<FunctionScalingConfig.Builder,FunctionScalingConfig>, SdkPojo
Enclosing class:
FunctionScalingConfig

@Mutable @NotThreadSafe public static interface FunctionScalingConfig.Builder extends SdkPojo, CopyableBuilder<FunctionScalingConfig.Builder,FunctionScalingConfig>
  • Method Details

    • minExecutionEnvironments

      FunctionScalingConfig.Builder minExecutionEnvironments(Integer minExecutionEnvironments)

      The minimum number of execution environments to maintain for the function.

      Parameters:
      minExecutionEnvironments - The minimum number of execution environments to maintain for the function.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • maxExecutionEnvironments

      FunctionScalingConfig.Builder maxExecutionEnvironments(Integer maxExecutionEnvironments)

      The maximum number of execution environments that can be provisioned for the function.

      Parameters:
      maxExecutionEnvironments - The maximum number of execution environments that can be provisioned for the function.
      Returns:
      Returns a reference to this object so that method calls can be chained together.