Class GetAccountSettingsResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.lambda.model.LambdaResponse
software.amazon.awssdk.services.lambda.model.GetAccountSettingsResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetAccountSettingsResponse.Builder,GetAccountSettingsResponse>
@Generated("software.amazon.awssdk:codegen")
public final class GetAccountSettingsResponse
extends LambdaResponse
implements ToCopyableBuilder<GetAccountSettingsResponse.Builder,GetAccountSettingsResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal AccountLimitLimits that are related to concurrency and code storage.final AccountUsageThe number of functions and amount of storage in use.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends GetAccountSettingsResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
accountLimit
Limits that are related to concurrency and code storage.
- Returns:
- Limits that are related to concurrency and code storage.
-
accountUsage
The number of functions and amount of storage in use.
- Returns:
- The number of functions and amount of storage in use.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetAccountSettingsResponse.Builder,GetAccountSettingsResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-