Class GetDurableExecutionHistoryRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetDurableExecutionHistoryRequest.Builder,GetDurableExecutionHistoryRequest>

@Generated("software.amazon.awssdk:codegen") public final class GetDurableExecutionHistoryRequest extends LambdaRequest implements ToCopyableBuilder<GetDurableExecutionHistoryRequest.Builder,GetDurableExecutionHistoryRequest>
  • Method Details

    • durableExecutionArn

      public final String durableExecutionArn()

      The Amazon Resource Name (ARN) of the durable execution.

      Returns:
      The Amazon Resource Name (ARN) of the durable execution.
    • includeExecutionData

      public final Boolean includeExecutionData()

      Specifies whether to include execution data such as step results and callback payloads in the history events. Set to true to include data, or false to exclude it for a more compact response. The default is true.

      Returns:
      Specifies whether to include execution data such as step results and callback payloads in the history events. Set to true to include data, or false to exclude it for a more compact response. The default is true.
    • maxItems

      public final Integer maxItems()

      The maximum number of history events to return per call. You can use Marker to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.

      Returns:
      The maximum number of history events to return per call. You can use Marker to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.
    • marker

      public final String marker()

      If NextMarker was returned from a previous request, use this value to retrieve the next page of results. Each pagination token expires after 24 hours.

      Returns:
      If NextMarker was returned from a previous request, use this value to retrieve the next page of results. Each pagination token expires after 24 hours.
    • reverseOrder

      public final Boolean reverseOrder()

      When set to true, returns the history events in reverse chronological order (newest first). By default, events are returned in chronological order (oldest first).

      Returns:
      When set to true, returns the history events in reverse chronological order (newest first). By default, events are returned in chronological order (oldest first).
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetDurableExecutionHistoryRequest.Builder,GetDurableExecutionHistoryRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends GetDurableExecutionHistoryRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo