Class GetDurableExecutionHistoryResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetDurableExecutionHistoryResponse.Builder,GetDurableExecutionHistoryResponse>
The response from the GetDurableExecutionHistory operation, containing the execution history and events.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) events()An array of execution history events, ordered chronologically unlessReverseOrderis set totrue.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the Events property.final inthashCode()final StringIf present, indicates that more history events are available.static Class<? extends GetDurableExecutionHistoryResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasEvents
public final boolean hasEvents()For responses, this returns true if the service returned a value for the Events property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
events
An array of execution history events, ordered chronologically unless
ReverseOrderis set totrue. Each event represents a significant occurrence during the execution, such as step completion or callback resolution.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasEvents()method.- Returns:
- An array of execution history events, ordered chronologically unless
ReverseOrderis set totrue. Each event represents a significant occurrence during the execution, such as step completion or callback resolution.
-
nextMarker
If present, indicates that more history events are available. Use this value as the
Markerparameter in a subsequent request to retrieve the next page of results.- Returns:
- If present, indicates that more history events are available. Use this value as the
Markerparameter in a subsequent request to retrieve the next page of results.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetDurableExecutionHistoryResponse.Builder,GetDurableExecutionHistoryResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends GetDurableExecutionHistoryResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-