Class GetDurableExecutionResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetDurableExecutionResponse.Builder,GetDurableExecutionResponse>

@Generated("software.amazon.awssdk:codegen") public final class GetDurableExecutionResponse extends LambdaResponse implements ToCopyableBuilder<GetDurableExecutionResponse.Builder,GetDurableExecutionResponse>

The response from the GetDurableExecution operation, containing detailed information about the durable execution.

  • Method Details

    • durableExecutionArn

      public final String durableExecutionArn()

      The Amazon Resource Name (ARN) of the durable execution.

      Returns:
      The Amazon Resource Name (ARN) of the durable execution.
    • durableExecutionName

      public final String durableExecutionName()

      The name of the durable execution. This is either the name you provided when invoking the function, or a system-generated unique identifier if no name was provided.

      Returns:
      The name of the durable execution. This is either the name you provided when invoking the function, or a system-generated unique identifier if no name was provided.
    • functionArn

      public final String functionArn()

      The Amazon Resource Name (ARN) of the Lambda function that was invoked to start this durable execution.

      Returns:
      The Amazon Resource Name (ARN) of the Lambda function that was invoked to start this durable execution.
    • inputPayload

      public final String inputPayload()

      The JSON input payload that was provided when the durable execution was started. For asynchronous invocations, this is limited to 256 KB. For synchronous invocations, this can be up to 6 MB.

      Returns:
      The JSON input payload that was provided when the durable execution was started. For asynchronous invocations, this is limited to 256 KB. For synchronous invocations, this can be up to 6 MB.
    • result

      public final String result()

      The JSON result returned by the durable execution if it completed successfully. This field is only present when the execution status is SUCCEEDED. The result is limited to 256 KB.

      Returns:
      The JSON result returned by the durable execution if it completed successfully. This field is only present when the execution status is SUCCEEDED. The result is limited to 256 KB.
    • error

      public final ErrorObject error()

      Error information if the durable execution failed. This field is only present when the execution status is FAILED, TIMED_OUT, or STOPPED. The combined size of all error fields is limited to 256 KB.

      Returns:
      Error information if the durable execution failed. This field is only present when the execution status is FAILED, TIMED_OUT, or STOPPED. The combined size of all error fields is limited to 256 KB.
    • startTimestamp

      public final Instant startTimestamp()

      The date and time when the durable execution started, in Unix timestamp format.

      Returns:
      The date and time when the durable execution started, in Unix timestamp format.
    • status

      public final ExecutionStatus status()

      The current status of the durable execution. Valid values are RUNNING, SUCCEEDED, FAILED, TIMED_OUT, and STOPPED.

      If the service returns an enum value that is not available in the current SDK version, status will return ExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from statusAsString().

      Returns:
      The current status of the durable execution. Valid values are RUNNING, SUCCEEDED, FAILED, TIMED_OUT, and STOPPED.
      See Also:
    • statusAsString

      public final String statusAsString()

      The current status of the durable execution. Valid values are RUNNING, SUCCEEDED, FAILED, TIMED_OUT, and STOPPED.

      If the service returns an enum value that is not available in the current SDK version, status will return ExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from statusAsString().

      Returns:
      The current status of the durable execution. Valid values are RUNNING, SUCCEEDED, FAILED, TIMED_OUT, and STOPPED.
      See Also:
    • endTimestamp

      public final Instant endTimestamp()

      The date and time when the durable execution ended, in Unix timestamp format. This field is only present if the execution has completed (status is SUCCEEDED, FAILED, TIMED_OUT, or STOPPED).

      Returns:
      The date and time when the durable execution ended, in Unix timestamp format. This field is only present if the execution has completed (status is SUCCEEDED, FAILED, TIMED_OUT, or STOPPED).
    • version

      public final String version()

      The version of the Lambda function that was invoked for this durable execution. This ensures that all replays during the execution use the same function version.

      Returns:
      The version of the Lambda function that was invoked for this durable execution. This ensures that all replays during the execution use the same function version.
    • traceHeader

      public final TraceHeader traceHeader()

      The trace headers associated with the durable execution.

      Returns:
      The trace headers associated with the durable execution.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetDurableExecutionResponse.Builder,GetDurableExecutionResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static GetDurableExecutionResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetDurableExecutionResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo