Class GetDurableExecutionStateRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest>

@Generated("software.amazon.awssdk:codegen") public final class GetDurableExecutionStateRequest extends LambdaRequest implements ToCopyableBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest>
  • Method Details

    • durableExecutionArn

      public final String durableExecutionArn()

      The Amazon Resource Name (ARN) of the durable execution.

      Returns:
      The Amazon Resource Name (ARN) of the durable execution.
    • checkpointToken

      public final String checkpointToken()

      A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.

      Returns:
      A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.
    • marker

      public final String marker()

      If NextMarker was returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.

      Returns:
      If NextMarker was returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.
    • maxItems

      public final Integer maxItems()

      The maximum number of operations to return per call. You can use Marker to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.

      Returns:
      The maximum number of operations to return per call. You can use Marker to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static GetDurableExecutionStateRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetDurableExecutionStateRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo