Interface GetDurableExecutionStateRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest>, LambdaRequest.Builder, SdkBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest>, SdkPojo, SdkRequest.Builder
Enclosing class:
GetDurableExecutionStateRequest

  • Method Details

    • durableExecutionArn

      GetDurableExecutionStateRequest.Builder durableExecutionArn(String durableExecutionArn)

      The Amazon Resource Name (ARN) of the durable execution.

      Parameters:
      durableExecutionArn - The Amazon Resource Name (ARN) of the durable execution.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • checkpointToken

      GetDurableExecutionStateRequest.Builder checkpointToken(String checkpointToken)

      A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.

      Parameters:
      checkpointToken - A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • marker

      If NextMarker was returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.

      Parameters:
      marker - If NextMarker was returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • maxItems

      The maximum number of operations to return per call. You can use Marker to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.

      Parameters:
      maxItems - The maximum number of operations to return per call. You can use Marker to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      GetDurableExecutionStateRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder