Class GetFunctionRecursionConfigResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetFunctionRecursionConfigResponse.Builder,GetFunctionRecursionConfigResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final RecursiveLoopIf your function's recursive loop detection configuration isAllow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop.final StringIf your function's recursive loop detection configuration isAllow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop.static Class<? extends GetFunctionRecursionConfigResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
recursiveLoop
If your function's recursive loop detection configuration is
Allow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop.If your function's recursive loop detection configuration is
Terminate, Lambda stops your function being invoked and notifies you when it detects your function being invoked as part of a recursive loop.By default, Lambda sets your function's configuration to
Terminate. You can update this configuration using the PutFunctionRecursionConfig action.If the service returns an enum value that is not available in the current SDK version,
recursiveLoopwill returnRecursiveLoop.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromrecursiveLoopAsString().- Returns:
- If your function's recursive loop detection configuration is
Allow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop.If your function's recursive loop detection configuration is
Terminate, Lambda stops your function being invoked and notifies you when it detects your function being invoked as part of a recursive loop.By default, Lambda sets your function's configuration to
Terminate. You can update this configuration using the PutFunctionRecursionConfig action. - See Also:
-
recursiveLoopAsString
If your function's recursive loop detection configuration is
Allow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop.If your function's recursive loop detection configuration is
Terminate, Lambda stops your function being invoked and notifies you when it detects your function being invoked as part of a recursive loop.By default, Lambda sets your function's configuration to
Terminate. You can update this configuration using the PutFunctionRecursionConfig action.If the service returns an enum value that is not available in the current SDK version,
recursiveLoopwill returnRecursiveLoop.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromrecursiveLoopAsString().- Returns:
- If your function's recursive loop detection configuration is
Allow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop.If your function's recursive loop detection configuration is
Terminate, Lambda stops your function being invoked and notifies you when it detects your function being invoked as part of a recursive loop.By default, Lambda sets your function's configuration to
Terminate. You can update this configuration using the PutFunctionRecursionConfig action. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetFunctionRecursionConfigResponse.Builder,GetFunctionRecursionConfigResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends GetFunctionRecursionConfigResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-