Class GetFunctionResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.lambda.model.LambdaResponse
software.amazon.awssdk.services.lambda.model.GetFunctionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetFunctionResponse.Builder,GetFunctionResponse>
@Generated("software.amazon.awssdk:codegen")
public final class GetFunctionResponse
extends LambdaResponse
implements ToCopyableBuilder<GetFunctionResponse.Builder,GetFunctionResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic GetFunctionResponse.Builderbuilder()final FunctionCodeLocationcode()The deployment package of the function or version.final ConcurrencyThe function's reserved concurrency.final FunctionConfigurationThe configuration of the function or version.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.static Class<? extends GetFunctionResponse.Builder>tags()The function's tags.final TagsErrorAn object that contains details about an error related to retrieving tags.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
configuration
The configuration of the function or version.
- Returns:
- The configuration of the function or version.
-
code
The deployment package of the function or version.
- Returns:
- The deployment package of the function or version.
-
hasTags
public final boolean hasTags()For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tags
The function's tags. Lambda returns tag data only if you have explicit allow permissions for lambda:ListTags.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- The function's tags. Lambda returns tag data only if you have explicit allow permissions for lambda:ListTags.
-
tagsError
An object that contains details about an error related to retrieving tags.
- Returns:
- An object that contains details about an error related to retrieving tags.
-
concurrency
The function's reserved concurrency.
- Returns:
- The function's reserved concurrency.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetFunctionResponse.Builder,GetFunctionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-