Interface GetFunctionUrlConfigRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<GetFunctionUrlConfigRequest.Builder,GetFunctionUrlConfigRequest>, LambdaRequest.Builder, SdkBuilder<GetFunctionUrlConfigRequest.Builder,GetFunctionUrlConfigRequest>, SdkPojo, SdkRequest.Builder
Enclosing class:
GetFunctionUrlConfigRequest

  • Method Details

    • functionName

      GetFunctionUrlConfigRequest.Builder functionName(String functionName)

      The name or ARN of the Lambda function.

      Name formats

      • Function namemy-function.

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Parameters:
      functionName - The name or ARN of the Lambda function.

      Name formats

      • Function namemy-function.

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • qualifier

      The alias name.

      Parameters:
      qualifier - The alias name.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      GetFunctionUrlConfigRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder