Interface GetPolicyRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<GetPolicyRequest.Builder,,GetPolicyRequest> LambdaRequest.Builder,SdkBuilder<GetPolicyRequest.Builder,,GetPolicyRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- GetPolicyRequest
-
Method Summary
Modifier and TypeMethodDescriptionfunctionName(String functionName) The name or ARN of the Lambda function, version, or alias.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Specify a version or alias to get the policy for that resource.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.services.lambda.model.LambdaRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
functionName
The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name –
my-function(name-only),my-function:v1(with alias). -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Parameters:
functionName- The name or ARN of the Lambda function, version, or alias.Name formats
-
Function name –
my-function(name-only),my-function:v1(with alias). -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-
qualifier
Specify a version or alias to get the policy for that resource.
- Parameters:
qualifier- Specify a version or alias to get the policy for that resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetPolicyRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetPolicyRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-