Class GetRuntimeManagementConfigResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetRuntimeManagementConfigResponse.Builder,GetRuntimeManagementConfigResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe Amazon Resource Name (ARN) of your function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ARN of the runtime the function is configured to use.static Class<? extends GetRuntimeManagementConfigResponse.Builder>final StringtoString()Returns a string representation of this object.final UpdateRuntimeOnThe current runtime update mode of the function.final StringThe current runtime update mode of the function.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
updateRuntimeOn
The current runtime update mode of the function.
If the service returns an enum value that is not available in the current SDK version,
updateRuntimeOnwill returnUpdateRuntimeOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromupdateRuntimeOnAsString().- Returns:
- The current runtime update mode of the function.
- See Also:
-
updateRuntimeOnAsString
The current runtime update mode of the function.
If the service returns an enum value that is not available in the current SDK version,
updateRuntimeOnwill returnUpdateRuntimeOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromupdateRuntimeOnAsString().- Returns:
- The current runtime update mode of the function.
- See Also:
-
runtimeVersionArn
The ARN of the runtime the function is configured to use. If the runtime update mode is Manual, the ARN is returned, otherwise
nullis returned.- Returns:
- The ARN of the runtime the function is configured to use. If the runtime update mode is Manual,
the ARN is returned, otherwise
nullis returned.
-
functionArn
The Amazon Resource Name (ARN) of your function.
- Returns:
- The Amazon Resource Name (ARN) of your function.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetRuntimeManagementConfigResponse.Builder,GetRuntimeManagementConfigResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends GetRuntimeManagementConfigResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-