Class InvocationCompletedDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.InvocationCompletedDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<InvocationCompletedDetails.Builder,InvocationCompletedDetails>
@Generated("software.amazon.awssdk:codegen")
public final class InvocationCompletedDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<InvocationCompletedDetails.Builder,InvocationCompletedDetails>
Details about a function invocation that completed.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final InstantThe date and time when the invocation ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).final booleanfinal booleanequalsBySdkFields(Object obj) final EventErrorerror()Details about the invocation failure.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe request ID for the invocation.static Class<? extends InvocationCompletedDetails.Builder>final InstantThe date and time when the invocation started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
startTimestamp
The date and time when the invocation started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- The date and time when the invocation started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
endTimestamp
The date and time when the invocation ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- The date and time when the invocation ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
requestId
The request ID for the invocation.
- Returns:
- The request ID for the invocation.
-
error
Details about the invocation failure.
- Returns:
- Details about the invocation failure.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<InvocationCompletedDetails.Builder,InvocationCompletedDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-