Class InvokeRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<InvokeRequest.Builder,InvokeRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic InvokeRequest.Builderbuilder()final StringUp to 3,583 bytes of base64-encoded data about the invoking client to pass to the function in the context object.final StringOptional unique name for the durable execution.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function, version, or alias.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InvocationTypeChoose from the following options.final StringChoose from the following options.final LogTypelogType()Set toTailto include the execution log in the response.final StringSet toTailto include the execution log in the response.final SdkBytespayload()The JSON that you want to provide to your Lambda function as input.final StringSpecify a version or alias to invoke a published version of the function.static Class<? extends InvokeRequest.Builder>final StringtenantId()The identifier of the tenant in a multi-tenant Lambda function.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name –
my-function(name-only),my-function:v1(with alias). -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Returns:
- The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name –
my-function(name-only),my-function:v1(with alias). -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
-
-
invocationType
Choose from the following options.
-
RequestResponse(default) – Invoke the function synchronously. Keep the connection open until the function returns a response or times out. The API response includes the function response and additional data. -
Event– Invoke the function asynchronously. Send events that fail multiple times to the function's dead-letter queue (if one is configured). The API response only includes a status code. -
DryRun– Validate parameter values and verify that the user or role has permission to invoke the function.
If the service returns an enum value that is not available in the current SDK version,
invocationTypewill returnInvocationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frominvocationTypeAsString().- Returns:
- Choose from the following options.
-
RequestResponse(default) – Invoke the function synchronously. Keep the connection open until the function returns a response or times out. The API response includes the function response and additional data. -
Event– Invoke the function asynchronously. Send events that fail multiple times to the function's dead-letter queue (if one is configured). The API response only includes a status code. -
DryRun– Validate parameter values and verify that the user or role has permission to invoke the function.
-
- See Also:
-
-
invocationTypeAsString
Choose from the following options.
-
RequestResponse(default) – Invoke the function synchronously. Keep the connection open until the function returns a response or times out. The API response includes the function response and additional data. -
Event– Invoke the function asynchronously. Send events that fail multiple times to the function's dead-letter queue (if one is configured). The API response only includes a status code. -
DryRun– Validate parameter values and verify that the user or role has permission to invoke the function.
If the service returns an enum value that is not available in the current SDK version,
invocationTypewill returnInvocationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frominvocationTypeAsString().- Returns:
- Choose from the following options.
-
RequestResponse(default) – Invoke the function synchronously. Keep the connection open until the function returns a response or times out. The API response includes the function response and additional data. -
Event– Invoke the function asynchronously. Send events that fail multiple times to the function's dead-letter queue (if one is configured). The API response only includes a status code. -
DryRun– Validate parameter values and verify that the user or role has permission to invoke the function.
-
- See Also:
-
-
logType
Set to
Tailto include the execution log in the response. Applies to synchronously invoked functions only.If the service returns an enum value that is not available in the current SDK version,
logTypewill returnLogType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlogTypeAsString().- Returns:
- Set to
Tailto include the execution log in the response. Applies to synchronously invoked functions only. - See Also:
-
logTypeAsString
Set to
Tailto include the execution log in the response. Applies to synchronously invoked functions only.If the service returns an enum value that is not available in the current SDK version,
logTypewill returnLogType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlogTypeAsString().- Returns:
- Set to
Tailto include the execution log in the response. Applies to synchronously invoked functions only. - See Also:
-
clientContext
Up to 3,583 bytes of base64-encoded data about the invoking client to pass to the function in the context object. Lambda passes the
ClientContextobject to your function for synchronous invocations only.- Returns:
- Up to 3,583 bytes of base64-encoded data about the invoking client to pass to the function in the context
object. Lambda passes the
ClientContextobject to your function for synchronous invocations only.
-
durableExecutionName
Optional unique name for the durable execution. When you start your special function, you can give it a unique name to identify this specific execution. It's like giving a nickname to a task.
- Returns:
- Optional unique name for the durable execution. When you start your special function, you can give it a unique name to identify this specific execution. It's like giving a nickname to a task.
-
payload
The JSON that you want to provide to your Lambda function as input. The maximum payload size is 6 MB for synchronous invocations and 1 MB for asynchronous invocations.
You can enter the JSON directly. For example,
--payload '{ "key": "value" }'. You can also specify a file path. For example,--payload file://payload.json.- Returns:
- The JSON that you want to provide to your Lambda function as input. The maximum payload size is 6 MB for
synchronous invocations and 1 MB for asynchronous invocations.
You can enter the JSON directly. For example,
--payload '{ "key": "value" }'. You can also specify a file path. For example,--payload file://payload.json.
-
qualifier
Specify a version or alias to invoke a published version of the function.
- Returns:
- Specify a version or alias to invoke a published version of the function.
-
tenantId
The identifier of the tenant in a multi-tenant Lambda function.
- Returns:
- The identifier of the tenant in a multi-tenant Lambda function.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<InvokeRequest.Builder,InvokeRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-