Class InvokeResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<InvokeResponse.Builder,InvokeResponse>

@Generated("software.amazon.awssdk:codegen") public final class InvokeResponse extends LambdaResponse implements ToCopyableBuilder<InvokeResponse.Builder,InvokeResponse>
  • Method Details

    • statusCode

      public final Integer statusCode()

      The HTTP status code is in the 200 range for a successful request. For the RequestResponse invocation type, this status code is 200. For the Event invocation type, this status code is 202. For the DryRun invocation type, the status code is 204.

      Returns:
      The HTTP status code is in the 200 range for a successful request. For the RequestResponse invocation type, this status code is 200. For the Event invocation type, this status code is 202. For the DryRun invocation type, the status code is 204.
    • functionError

      public final String functionError()

      If present, indicates that an error occurred during function execution. Details about the error are included in the response payload.

      Returns:
      If present, indicates that an error occurred during function execution. Details about the error are included in the response payload.
    • logResult

      public final String logResult()

      The last 4 KB of the execution log, which is base64-encoded.

      Returns:
      The last 4 KB of the execution log, which is base64-encoded.
    • payload

      public final SdkBytes payload()

      The response from the function, or an error object.

      Returns:
      The response from the function, or an error object.
    • executedVersion

      public final String executedVersion()

      The version of the function that executed. When you invoke a function with an alias, this indicates which version the alias resolved to.

      Returns:
      The version of the function that executed. When you invoke a function with an alias, this indicates which version the alias resolved to.
    • durableExecutionArn

      public final String durableExecutionArn()

      The ARN of the durable execution that was started. This is returned when invoking a durable function and provides a unique identifier for tracking the execution.

      Returns:
      The ARN of the durable execution that was started. This is returned when invoking a durable function and provides a unique identifier for tracking the execution.
    • toBuilder

      public InvokeResponse.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<InvokeResponse.Builder,InvokeResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static InvokeResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends InvokeResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo