Class InvokeWithResponseStreamCompleteEvent.BuilderImpl
java.lang.Object
software.amazon.awssdk.services.lambda.model.InvokeWithResponseStreamCompleteEvent.BuilderImpl
- All Implemented Interfaces:
SdkPojo,InvokeWithResponseStreamCompleteEvent.Builder,Buildable,CopyableBuilder<InvokeWithResponseStreamCompleteEvent.Builder,,InvokeWithResponseStreamCompleteEvent> SdkBuilder<InvokeWithResponseStreamCompleteEvent.Builder,InvokeWithResponseStreamCompleteEvent>
- Enclosing class:
- InvokeWithResponseStreamCompleteEvent
protected static class InvokeWithResponseStreamCompleteEvent.BuilderImpl
extends Object
implements InvokeWithResponseStreamCompleteEvent.Builder
-
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedprotected -
Method Summary
Modifier and TypeMethodDescriptionbuild()An error code.errorDetails(String errorDetails) The details of any returned error.final Stringfinal Stringfinal StringThe last 4 KB of the execution log, which is base64-encoded.final voidsetErrorCode(String errorCode) final voidsetErrorDetails(String errorDetails) final voidsetLogResult(String logResult) Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutationMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields
-
Constructor Details
-
BuilderImpl
protected BuilderImpl() -
BuilderImpl
-
-
Method Details
-
getErrorCode
-
setErrorCode
-
errorCode
Description copied from interface:InvokeWithResponseStreamCompleteEvent.BuilderAn error code.
- Specified by:
errorCodein interfaceInvokeWithResponseStreamCompleteEvent.Builder- Parameters:
errorCode- An error code.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
getErrorDetails
-
setErrorDetails
-
errorDetails
Description copied from interface:InvokeWithResponseStreamCompleteEvent.BuilderThe details of any returned error.
- Specified by:
errorDetailsin interfaceInvokeWithResponseStreamCompleteEvent.Builder- Parameters:
errorDetails- The details of any returned error.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
getLogResult
-
setLogResult
-
logResult
Description copied from interface:InvokeWithResponseStreamCompleteEvent.BuilderThe last 4 KB of the execution log, which is base64-encoded.
- Specified by:
logResultin interfaceInvokeWithResponseStreamCompleteEvent.Builder- Parameters:
logResult- The last 4 KB of the execution log, which is base64-encoded.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
build
- Specified by:
buildin interfaceBuildable- Specified by:
buildin interfaceSdkBuilder<InvokeWithResponseStreamCompleteEvent.Builder,InvokeWithResponseStreamCompleteEvent>
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-