Class KafkaSchemaValidationConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<KafkaSchemaValidationConfig.Builder,KafkaSchemaValidationConfig>
Specific schema validation configuration settings that tell Lambda the message attributes you want to validate and filter using your schema registry.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionThe attributes you want your schema registry to validate and filter for.final StringThe attributes you want your schema registry to validate and filter for.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends KafkaSchemaValidationConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
attribute
The attributes you want your schema registry to validate and filter for. If you selected
JSONas theEventRecordFormat, Lambda also deserializes the selected message attributes.If the service returns an enum value that is not available in the current SDK version,
attributewill returnKafkaSchemaValidationAttribute.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromattributeAsString().- Returns:
- The attributes you want your schema registry to validate and filter for. If you selected
JSONas theEventRecordFormat, Lambda also deserializes the selected message attributes. - See Also:
-
attributeAsString
The attributes you want your schema registry to validate and filter for. If you selected
JSONas theEventRecordFormat, Lambda also deserializes the selected message attributes.If the service returns an enum value that is not available in the current SDK version,
attributewill returnKafkaSchemaValidationAttribute.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromattributeAsString().- Returns:
- The attributes you want your schema registry to validate and filter for. If you selected
JSONas theEventRecordFormat, Lambda also deserializes the selected message attributes. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<KafkaSchemaValidationConfig.Builder,KafkaSchemaValidationConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-