Interface KafkaSchemaValidationConfig.Builder

All Superinterfaces:
Buildable, CopyableBuilder<KafkaSchemaValidationConfig.Builder,KafkaSchemaValidationConfig>, SdkBuilder<KafkaSchemaValidationConfig.Builder,KafkaSchemaValidationConfig>, SdkPojo
Enclosing class:
KafkaSchemaValidationConfig

@Mutable @NotThreadSafe public static interface KafkaSchemaValidationConfig.Builder extends SdkPojo, CopyableBuilder<KafkaSchemaValidationConfig.Builder,KafkaSchemaValidationConfig>
  • Method Details

    • attribute

      The attributes you want your schema registry to validate and filter for. If you selected JSON as the EventRecordFormat, Lambda also deserializes the selected message attributes.

      Parameters:
      attribute - The attributes you want your schema registry to validate and filter for. If you selected JSON as the EventRecordFormat, Lambda also deserializes the selected message attributes.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • attribute

      The attributes you want your schema registry to validate and filter for. If you selected JSON as the EventRecordFormat, Lambda also deserializes the selected message attributes.

      Parameters:
      attribute - The attributes you want your schema registry to validate and filter for. If you selected JSON as the EventRecordFormat, Lambda also deserializes the selected message attributes.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also: