Class LambdaManagedInstancesCapacityProviderConfig
java.lang.Object
software.amazon.awssdk.services.lambda.model.LambdaManagedInstancesCapacityProviderConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<LambdaManagedInstancesCapacityProviderConfig.Builder,LambdaManagedInstancesCapacityProviderConfig>
@Generated("software.amazon.awssdk:codegen")
public final class LambdaManagedInstancesCapacityProviderConfig
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<LambdaManagedInstancesCapacityProviderConfig.Builder,LambdaManagedInstancesCapacityProviderConfig>
Configuration for Lambda-managed instances used by the capacity provider.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe Amazon Resource Name (ARN) of the capacity provider.final booleanfinal booleanequalsBySdkFields(Object obj) final DoubleThe amount of memory in GiB allocated per vCPU for execution environments.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of concurrent execution environments that can run on each compute instance.static Class<? extends LambdaManagedInstancesCapacityProviderConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
capacityProviderArn
The Amazon Resource Name (ARN) of the capacity provider.
- Returns:
- The Amazon Resource Name (ARN) of the capacity provider.
-
perExecutionEnvironmentMaxConcurrency
The maximum number of concurrent execution environments that can run on each compute instance.
- Returns:
- The maximum number of concurrent execution environments that can run on each compute instance.
-
executionEnvironmentMemoryGiBPerVCpu
The amount of memory in GiB allocated per vCPU for execution environments.
- Returns:
- The amount of memory in GiB allocated per vCPU for execution environments.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<LambdaManagedInstancesCapacityProviderConfig.Builder,LambdaManagedInstancesCapacityProviderConfig>
-
builder
-
serializableBuilderClass
public static Class<? extends LambdaManagedInstancesCapacityProviderConfig.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-