Class LayerVersionContentInput
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<LayerVersionContentInput.Builder,LayerVersionContentInput>
A ZIP archive that contains the contents of an Lambda layer. You can specify either an Amazon S3 location, or upload a layer archive directly.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Strings3Bucket()The Amazon S3 bucket of the layer archive.final Strings3Key()The Amazon S3 key of the layer archive.final S3ObjectStorageModeReturns the value of the S3ObjectStorageMode property for this object.final StringReturns the value of the S3ObjectStorageMode property for this object.final StringFor versioned objects, the version of the layer archive object to use.static Class<? extends LayerVersionContentInput.Builder>final StringtoString()Returns a string representation of this object.final SdkByteszipFile()The base64-encoded contents of the layer archive.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
s3Bucket
The Amazon S3 bucket of the layer archive.
- Returns:
- The Amazon S3 bucket of the layer archive.
-
s3Key
The Amazon S3 key of the layer archive.
- Returns:
- The Amazon S3 key of the layer archive.
-
s3ObjectVersion
For versioned objects, the version of the layer archive object to use.
- Returns:
- For versioned objects, the version of the layer archive object to use.
-
s3ObjectStorageMode
Returns the value of the S3ObjectStorageMode property for this object.If the service returns an enum value that is not available in the current SDK version,
s3ObjectStorageModewill returnS3ObjectStorageMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available froms3ObjectStorageModeAsString().- Returns:
- The value of the S3ObjectStorageMode property for this object.
- See Also:
-
s3ObjectStorageModeAsString
Returns the value of the S3ObjectStorageMode property for this object.If the service returns an enum value that is not available in the current SDK version,
s3ObjectStorageModewill returnS3ObjectStorageMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available froms3ObjectStorageModeAsString().- Returns:
- The value of the S3ObjectStorageMode property for this object.
- See Also:
-
zipFile
The base64-encoded contents of the layer archive. Amazon Web Services SDK and Amazon Web Services CLI clients handle the encoding for you.
- Returns:
- The base64-encoded contents of the layer archive. Amazon Web Services SDK and Amazon Web Services CLI clients handle the encoding for you.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<LayerVersionContentInput.Builder,LayerVersionContentInput>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-