Class LayerVersionContentOutput
java.lang.Object
software.amazon.awssdk.services.lambda.model.LayerVersionContentOutput
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<LayerVersionContentOutput.Builder,LayerVersionContentOutput>
@Generated("software.amazon.awssdk:codegen")
public final class LayerVersionContentOutput
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<LayerVersionContentOutput.Builder,LayerVersionContentOutput>
Details about a version of an Lambda layer.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe SHA-256 hash of the layer archive.final LongcodeSize()The size of the layer archive in bytes.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringlocation()A link to the layer archive in Amazon S3 that is valid for 10 minutes.static Class<? extends LayerVersionContentOutput.Builder>final StringThe Amazon Resource Name (ARN) of a signing job.final StringThe Amazon Resource Name (ARN) for a signing profile version.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
location
A link to the layer archive in Amazon S3 that is valid for 10 minutes.
- Returns:
- A link to the layer archive in Amazon S3 that is valid for 10 minutes.
-
codeSha256
The SHA-256 hash of the layer archive.
- Returns:
- The SHA-256 hash of the layer archive.
-
codeSize
The size of the layer archive in bytes.
- Returns:
- The size of the layer archive in bytes.
-
signingProfileVersionArn
The Amazon Resource Name (ARN) for a signing profile version.
- Returns:
- The Amazon Resource Name (ARN) for a signing profile version.
-
signingJobArn
The Amazon Resource Name (ARN) of a signing job.
- Returns:
- The Amazon Resource Name (ARN) of a signing job.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<LayerVersionContentOutput.Builder,LayerVersionContentOutput>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-