Class ListDurableExecutionsByFunctionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListDurableExecutionsByFunctionRequest.Builder,ListDurableExecutionsByFunctionRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListDurableExecutionsByFunctionRequest extends LambdaRequest implements ToCopyableBuilder<ListDurableExecutionsByFunctionRequest.Builder,ListDurableExecutionsByFunctionRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function. You can specify a function name, a partial ARN, or a full ARN.

      Returns:
      The name or ARN of the Lambda function. You can specify a function name, a partial ARN, or a full ARN.
    • qualifier

      public final String qualifier()

      The function version or alias. If not specified, lists executions for the $LATEST version.

      Returns:
      The function version or alias. If not specified, lists executions for the $LATEST version.
    • durableExecutionName

      public final String durableExecutionName()

      Filter executions by name. Only executions with names that matches this string are returned.

      Returns:
      Filter executions by name. Only executions with names that matches this string are returned.
    • statuses

      public final List<ExecutionStatus> statuses()

      Filter executions by status. Valid values: RUNNING, SUCCEEDED, FAILED, TIMED_OUT, STOPPED.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasStatuses() method.

      Returns:
      Filter executions by status. Valid values: RUNNING, SUCCEEDED, FAILED, TIMED_OUT, STOPPED.
    • hasStatuses

      public final boolean hasStatuses()
      For responses, this returns true if the service returned a value for the Statuses property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • statusesAsStrings

      public final List<String> statusesAsStrings()

      Filter executions by status. Valid values: RUNNING, SUCCEEDED, FAILED, TIMED_OUT, STOPPED.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasStatuses() method.

      Returns:
      Filter executions by status. Valid values: RUNNING, SUCCEEDED, FAILED, TIMED_OUT, STOPPED.
    • startedAfter

      public final Instant startedAfter()

      Filter executions that started after this timestamp (ISO 8601 format).

      Returns:
      Filter executions that started after this timestamp (ISO 8601 format).
    • startedBefore

      public final Instant startedBefore()

      Filter executions that started before this timestamp (ISO 8601 format).

      Returns:
      Filter executions that started before this timestamp (ISO 8601 format).
    • reverseOrder

      public final Boolean reverseOrder()

      Set to true to return results in reverse chronological order (newest first). Default is false.

      Returns:
      Set to true to return results in reverse chronological order (newest first). Default is false.
    • marker

      public final String marker()

      Pagination token from a previous request to continue retrieving results.

      Returns:
      Pagination token from a previous request to continue retrieving results.
    • maxItems

      public final Integer maxItems()

      Maximum number of executions to return (1-1000). Default is 100.

      Returns:
      Maximum number of executions to return (1-1000). Default is 100.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListDurableExecutionsByFunctionRequest.Builder,ListDurableExecutionsByFunctionRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends ListDurableExecutionsByFunctionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo