Class ListDurableExecutionsByFunctionResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.lambda.model.LambdaResponse
software.amazon.awssdk.services.lambda.model.ListDurableExecutionsByFunctionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListDurableExecutionsByFunctionResponse.Builder,ListDurableExecutionsByFunctionResponse>
@Generated("software.amazon.awssdk:codegen")
public final class ListDurableExecutionsByFunctionResponse
extends LambdaResponse
implements ToCopyableBuilder<ListDurableExecutionsByFunctionResponse.Builder,ListDurableExecutionsByFunctionResponse>
The response from the ListDurableExecutionsByFunction operation, containing a list of durable executions and pagination information.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()List of durable execution summaries matching the filter criteria.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the DurableExecutions property.final inthashCode()final StringPagination token for retrieving additional results.static Class<? extends ListDurableExecutionsByFunctionResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
hasDurableExecutions
public final boolean hasDurableExecutions()For responses, this returns true if the service returned a value for the DurableExecutions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
durableExecutions
List of durable execution summaries matching the filter criteria.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasDurableExecutions()method.- Returns:
- List of durable execution summaries matching the filter criteria.
-
nextMarker
Pagination token for retrieving additional results. Present only if there are more results available.
- Returns:
- Pagination token for retrieving additional results. Present only if there are more results available.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListDurableExecutionsByFunctionResponse.Builder,ListDurableExecutionsByFunctionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends ListDurableExecutionsByFunctionResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-