Interface ListFunctionsByCodeSigningConfigRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<ListFunctionsByCodeSigningConfigRequest.Builder,,ListFunctionsByCodeSigningConfigRequest> LambdaRequest.Builder,SdkBuilder<ListFunctionsByCodeSigningConfigRequest.Builder,,ListFunctionsByCodeSigningConfigRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- ListFunctionsByCodeSigningConfigRequest
@Mutable
@NotThreadSafe
public static interface ListFunctionsByCodeSigningConfigRequest.Builder
extends LambdaRequest.Builder, SdkPojo, CopyableBuilder<ListFunctionsByCodeSigningConfigRequest.Builder,ListFunctionsByCodeSigningConfigRequest>
-
Method Summary
Modifier and TypeMethodDescriptioncodeSigningConfigArn(String codeSigningConfigArn) The The Amazon Resource Name (ARN) of the code signing configuration.Specify the pagination token that's returned by a previous request to retrieve the next page of results.Maximum number of items to return.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.services.lambda.model.LambdaRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
codeSigningConfigArn
The The Amazon Resource Name (ARN) of the code signing configuration.
- Parameters:
codeSigningConfigArn- The The Amazon Resource Name (ARN) of the code signing configuration.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
marker
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
- Parameters:
marker- Specify the pagination token that's returned by a previous request to retrieve the next page of results.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
maxItems
Maximum number of items to return.
- Parameters:
maxItems- Maximum number of items to return.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
ListFunctionsByCodeSigningConfigRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
ListFunctionsByCodeSigningConfigRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-