Class ListFunctionsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListFunctionsRequest.Builder,ListFunctionsRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListFunctionsRequest extends LambdaRequest implements ToCopyableBuilder<ListFunctionsRequest.Builder,ListFunctionsRequest>
  • Method Details

    • masterRegion

      public final String masterRegion()

      For Lambda@Edge functions, the Amazon Web Services Region of the master function. For example, us-east-1 filters the list of functions to include only Lambda@Edge functions replicated from a master function in US East (N. Virginia). If specified, you must set FunctionVersion to ALL.

      Returns:
      For Lambda@Edge functions, the Amazon Web Services Region of the master function. For example, us-east-1 filters the list of functions to include only Lambda@Edge functions replicated from a master function in US East (N. Virginia). If specified, you must set FunctionVersion to ALL.
    • functionVersion

      public final FunctionVersion functionVersion()

      Set to ALL to include entries for all published versions of each function.

      If the service returns an enum value that is not available in the current SDK version, functionVersion will return FunctionVersion.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from functionVersionAsString().

      Returns:
      Set to ALL to include entries for all published versions of each function.
      See Also:
    • functionVersionAsString

      public final String functionVersionAsString()

      Set to ALL to include entries for all published versions of each function.

      If the service returns an enum value that is not available in the current SDK version, functionVersion will return FunctionVersion.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from functionVersionAsString().

      Returns:
      Set to ALL to include entries for all published versions of each function.
      See Also:
    • marker

      public final String marker()

      Specify the pagination token that's returned by a previous request to retrieve the next page of results.

      Returns:
      Specify the pagination token that's returned by a previous request to retrieve the next page of results.
    • maxItems

      public final Integer maxItems()

      The maximum number of functions to return in the response. Note that ListFunctions returns a maximum of 50 items in each response, even if you set the number higher.

      Returns:
      The maximum number of functions to return in the response. Note that ListFunctions returns a maximum of 50 items in each response, even if you set the number higher.
    • toBuilder

      public ListFunctionsRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<ListFunctionsRequest.Builder,ListFunctionsRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static ListFunctionsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ListFunctionsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo