Class ListLayerVersionsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListLayerVersionsRequest.Builder,ListLayerVersionsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final ArchitectureThe compatible instruction set architecture.final StringThe compatible instruction set architecture.final RuntimeA runtime identifier.final StringA runtime identifier.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name or Amazon Resource Name (ARN) of the layer.final Stringmarker()A pagination token returned by a previous call.final IntegermaxItems()The maximum number of versions to return.static Class<? extends ListLayerVersionsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
compatibleRuntime
A runtime identifier.
The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
If the service returns an enum value that is not available in the current SDK version,
compatibleRuntimewill returnRuntime.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcompatibleRuntimeAsString().- Returns:
- A runtime identifier.
The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
- See Also:
-
compatibleRuntimeAsString
A runtime identifier.
The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
If the service returns an enum value that is not available in the current SDK version,
compatibleRuntimewill returnRuntime.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcompatibleRuntimeAsString().- Returns:
- A runtime identifier.
The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
- See Also:
-
layerName
The name or Amazon Resource Name (ARN) of the layer.
- Returns:
- The name or Amazon Resource Name (ARN) of the layer.
-
marker
A pagination token returned by a previous call.
- Returns:
- A pagination token returned by a previous call.
-
maxItems
The maximum number of versions to return.
- Returns:
- The maximum number of versions to return.
-
compatibleArchitecture
The compatible instruction set architecture.
If the service returns an enum value that is not available in the current SDK version,
compatibleArchitecturewill returnArchitecture.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcompatibleArchitectureAsString().- Returns:
- The compatible instruction set architecture.
- See Also:
-
compatibleArchitectureAsString
The compatible instruction set architecture.
If the service returns an enum value that is not available in the current SDK version,
compatibleArchitecturewill returnArchitecture.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromcompatibleArchitectureAsString().- Returns:
- The compatible instruction set architecture.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListLayerVersionsRequest.Builder,ListLayerVersionsRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-