Class ListVersionsByFunctionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListVersionsByFunctionRequest.Builder,ListVersionsByFunctionRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListVersionsByFunctionRequest extends LambdaRequest implements ToCopyableBuilder<ListVersionsByFunctionRequest.Builder,ListVersionsByFunctionRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function.

      Name formats

      • Function name - MyFunction.

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

      • Partial ARN - 123456789012:function:MyFunction.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      The name or ARN of the Lambda function.

      Name formats

      • Function name - MyFunction.

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

      • Partial ARN - 123456789012:function:MyFunction.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    • marker

      public final String marker()

      Specify the pagination token that's returned by a previous request to retrieve the next page of results.

      Returns:
      Specify the pagination token that's returned by a previous request to retrieve the next page of results.
    • maxItems

      public final Integer maxItems()

      The maximum number of versions to return. Note that ListVersionsByFunction returns a maximum of 50 items in each response, even if you set the number higher.

      Returns:
      The maximum number of versions to return. Note that ListVersionsByFunction returns a maximum of 50 items in each response, even if you set the number higher.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListVersionsByFunctionRequest.Builder,ListVersionsByFunctionRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static ListVersionsByFunctionRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ListVersionsByFunctionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo