Class ListVersionsByFunctionResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListVersionsByFunctionResponse.Builder,ListVersionsByFunctionResponse>

@Generated("software.amazon.awssdk:codegen") public final class ListVersionsByFunctionResponse extends LambdaResponse implements ToCopyableBuilder<ListVersionsByFunctionResponse.Builder,ListVersionsByFunctionResponse>
  • Method Details

    • nextMarker

      public final String nextMarker()

      The pagination token that's included if more results are available.

      Returns:
      The pagination token that's included if more results are available.
    • hasVersions

      public final boolean hasVersions()
      For responses, this returns true if the service returned a value for the Versions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • versions

      public final List<FunctionConfiguration> versions()

      A list of Lambda function versions.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasVersions() method.

      Returns:
      A list of Lambda function versions.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListVersionsByFunctionResponse.Builder,ListVersionsByFunctionResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static ListVersionsByFunctionResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ListVersionsByFunctionResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo