Class LoggingConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<LoggingConfig.Builder,LoggingConfig>
The function's Amazon CloudWatch Logs configuration settings.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal ApplicationLogLevelSet this property to filter the application logs for your function that Lambda sends to CloudWatch.final StringSet this property to filter the application logs for your function that Lambda sends to CloudWatch.static LoggingConfig.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final LogFormatThe format in which Lambda sends your function's application and system logs to CloudWatch.final StringThe format in which Lambda sends your function's application and system logs to CloudWatch.final StringlogGroup()The name of the Amazon CloudWatch log group the function sends logs to.static Class<? extends LoggingConfig.Builder>final SystemLogLevelSet this property to filter the system logs for your function that Lambda sends to CloudWatch.final StringSet this property to filter the system logs for your function that Lambda sends to CloudWatch.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
logFormat
The format in which Lambda sends your function's application and system logs to CloudWatch. Select between plain text and structured JSON.
If the service returns an enum value that is not available in the current SDK version,
logFormatwill returnLogFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlogFormatAsString().- Returns:
- The format in which Lambda sends your function's application and system logs to CloudWatch. Select between plain text and structured JSON.
- See Also:
-
logFormatAsString
The format in which Lambda sends your function's application and system logs to CloudWatch. Select between plain text and structured JSON.
If the service returns an enum value that is not available in the current SDK version,
logFormatwill returnLogFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromlogFormatAsString().- Returns:
- The format in which Lambda sends your function's application and system logs to CloudWatch. Select between plain text and structured JSON.
- See Also:
-
applicationLogLevel
Set this property to filter the application logs for your function that Lambda sends to CloudWatch. Lambda only sends application logs at the selected level of detail and lower, where
TRACEis the highest level andFATALis the lowest.If the service returns an enum value that is not available in the current SDK version,
applicationLogLevelwill returnApplicationLogLevel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromapplicationLogLevelAsString().- Returns:
- Set this property to filter the application logs for your function that Lambda sends to CloudWatch.
Lambda only sends application logs at the selected level of detail and lower, where
TRACEis the highest level andFATALis the lowest. - See Also:
-
applicationLogLevelAsString
Set this property to filter the application logs for your function that Lambda sends to CloudWatch. Lambda only sends application logs at the selected level of detail and lower, where
TRACEis the highest level andFATALis the lowest.If the service returns an enum value that is not available in the current SDK version,
applicationLogLevelwill returnApplicationLogLevel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromapplicationLogLevelAsString().- Returns:
- Set this property to filter the application logs for your function that Lambda sends to CloudWatch.
Lambda only sends application logs at the selected level of detail and lower, where
TRACEis the highest level andFATALis the lowest. - See Also:
-
systemLogLevel
Set this property to filter the system logs for your function that Lambda sends to CloudWatch. Lambda only sends system logs at the selected level of detail and lower, where
DEBUGis the highest level andWARNis the lowest.If the service returns an enum value that is not available in the current SDK version,
systemLogLevelwill returnSystemLogLevel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsystemLogLevelAsString().- Returns:
- Set this property to filter the system logs for your function that Lambda sends to CloudWatch. Lambda
only sends system logs at the selected level of detail and lower, where
DEBUGis the highest level andWARNis the lowest. - See Also:
-
systemLogLevelAsString
Set this property to filter the system logs for your function that Lambda sends to CloudWatch. Lambda only sends system logs at the selected level of detail and lower, where
DEBUGis the highest level andWARNis the lowest.If the service returns an enum value that is not available in the current SDK version,
systemLogLevelwill returnSystemLogLevel.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsystemLogLevelAsString().- Returns:
- Set this property to filter the system logs for your function that Lambda sends to CloudWatch. Lambda
only sends system logs at the selected level of detail and lower, where
DEBUGis the highest level andWARNis the lowest. - See Also:
-
logGroup
The name of the Amazon CloudWatch log group the function sends logs to. By default, Lambda functions send logs to a default log group named
/aws/lambda/<function name>. To use a different log group, enter an existing log group or enter a new log group name.- Returns:
- The name of the Amazon CloudWatch log group the function sends logs to. By default, Lambda functions send
logs to a default log group named
/aws/lambda/<function name>. To use a different log group, enter an existing log group or enter a new log group name.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<LoggingConfig.Builder,LoggingConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-