java.lang.Object
software.amazon.awssdk.services.lambda.model.OnSuccess
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<OnSuccess.Builder,OnSuccess>

@Generated("software.amazon.awssdk:codegen") public final class OnSuccess extends Object implements SdkPojo, Serializable, ToCopyableBuilder<OnSuccess.Builder,OnSuccess>

A destination for events that were processed successfully.

To retain records of successful asynchronous invocations, you can configure an Amazon SNS topic, Amazon SQS queue, Lambda function, or Amazon EventBridge event bus as the destination.

OnSuccess is not supported in CreateEventSourceMapping or UpdateEventSourceMapping requests.

See Also:
  • Method Details

    • destination

      public final String destination()

      The Amazon Resource Name (ARN) of the destination resource.

      Amazon SNS destinations have a message size limit of 256 KB. If the combined size of the function request and response payload exceeds the limit, Lambda will drop the payload when sending OnFailure event to the destination. For details on this behavior, refer to Retaining records of asynchronous invocations.

      Returns:
      The Amazon Resource Name (ARN) of the destination resource.

      Amazon SNS destinations have a message size limit of 256 KB. If the combined size of the function request and response payload exceeds the limit, Lambda will drop the payload when sending OnFailure event to the destination. For details on this behavior, refer to Retaining records of asynchronous invocations.

    • toBuilder

      public OnSuccess.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<OnSuccess.Builder,OnSuccess>
    • builder

      public static OnSuccess.Builder builder()
    • serializableBuilderClass

      public static Class<? extends OnSuccess.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo