java.lang.Object
software.amazon.awssdk.services.lambda.model.Operation
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<Operation.Builder,Operation>

@Generated("software.amazon.awssdk:codegen") public final class Operation extends Object implements SdkPojo, Serializable, ToCopyableBuilder<Operation.Builder,Operation>

Information about an operation within a durable execution.

See Also:
  • Method Details

    • id

      public final String id()

      The unique identifier for this operation.

      Returns:
      The unique identifier for this operation.
    • parentId

      public final String parentId()

      The unique identifier of the parent operation, if this operation is running within a child context.

      Returns:
      The unique identifier of the parent operation, if this operation is running within a child context.
    • name

      public final String name()

      The customer-provided name for this operation.

      Returns:
      The customer-provided name for this operation.
    • type

      public final OperationType type()

      The type of operation.

      If the service returns an enum value that is not available in the current SDK version, type will return OperationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from typeAsString().

      Returns:
      The type of operation.
      See Also:
    • typeAsString

      public final String typeAsString()

      The type of operation.

      If the service returns an enum value that is not available in the current SDK version, type will return OperationType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from typeAsString().

      Returns:
      The type of operation.
      See Also:
    • subType

      public final String subType()

      The subtype of the operation, providing additional categorization.

      Returns:
      The subtype of the operation, providing additional categorization.
    • startTimestamp

      public final Instant startTimestamp()

      The date and time when the operation started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

      Returns:
      The date and time when the operation started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
    • endTimestamp

      public final Instant endTimestamp()

      The date and time when the operation ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

      Returns:
      The date and time when the operation ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
    • status

      public final OperationStatus status()

      The current status of the operation.

      If the service returns an enum value that is not available in the current SDK version, status will return OperationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from statusAsString().

      Returns:
      The current status of the operation.
      See Also:
    • statusAsString

      public final String statusAsString()

      The current status of the operation.

      If the service returns an enum value that is not available in the current SDK version, status will return OperationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from statusAsString().

      Returns:
      The current status of the operation.
      See Also:
    • executionDetails

      public final ExecutionDetails executionDetails()

      Details about the execution, if this operation represents an execution.

      Returns:
      Details about the execution, if this operation represents an execution.
    • contextDetails

      public final ContextDetails contextDetails()

      Details about the context, if this operation represents a context.

      Returns:
      Details about the context, if this operation represents a context.
    • stepDetails

      public final StepDetails stepDetails()

      Details about the step, if this operation represents a step.

      Returns:
      Details about the step, if this operation represents a step.
    • waitDetails

      public final WaitDetails waitDetails()

      Details about the wait operation, if this operation represents a wait.

      Returns:
      Details about the wait operation, if this operation represents a wait.
    • callbackDetails

      public final CallbackDetails callbackDetails()
      Returns the value of the CallbackDetails property for this object.
      Returns:
      The value of the CallbackDetails property for this object.
    • chainedInvokeDetails

      public final ChainedInvokeDetails chainedInvokeDetails()
      Returns the value of the ChainedInvokeDetails property for this object.
      Returns:
      The value of the ChainedInvokeDetails property for this object.
    • toBuilder

      public Operation.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<Operation.Builder,Operation>
    • builder

      public static Operation.Builder builder()
    • serializableBuilderClass

      public static Class<? extends Operation.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo