Class ProvisionedConcurrencyConfigListItem
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ProvisionedConcurrencyConfigListItem.Builder,ProvisionedConcurrencyConfigListItem>
Details about the provisioned concurrency configuration for a function alias or version.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal IntegerThe amount of provisioned concurrency allocated.final IntegerThe amount of provisioned concurrency available.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe Amazon Resource Name (ARN) of the alias or version.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe date and time that a user last updated the configuration, in ISO 8601 format.final IntegerThe amount of provisioned concurrency requested.static Class<? extends ProvisionedConcurrencyConfigListItem.Builder>status()The status of the allocation process.final StringThe status of the allocation process.final StringFor failed allocations, the reason that provisioned concurrency could not be allocated.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionArn
The Amazon Resource Name (ARN) of the alias or version.
- Returns:
- The Amazon Resource Name (ARN) of the alias or version.
-
requestedProvisionedConcurrentExecutions
The amount of provisioned concurrency requested.
- Returns:
- The amount of provisioned concurrency requested.
-
availableProvisionedConcurrentExecutions
The amount of provisioned concurrency available.
- Returns:
- The amount of provisioned concurrency available.
-
allocatedProvisionedConcurrentExecutions
The amount of provisioned concurrency allocated. When a weighted alias is used during linear and canary deployments, this value fluctuates depending on the amount of concurrency that is provisioned for the function versions.
- Returns:
- The amount of provisioned concurrency allocated. When a weighted alias is used during linear and canary deployments, this value fluctuates depending on the amount of concurrency that is provisioned for the function versions.
-
status
The status of the allocation process.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnProvisionedConcurrencyStatusEnum.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the allocation process.
- See Also:
-
statusAsString
The status of the allocation process.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnProvisionedConcurrencyStatusEnum.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the allocation process.
- See Also:
-
statusReason
For failed allocations, the reason that provisioned concurrency could not be allocated.
- Returns:
- For failed allocations, the reason that provisioned concurrency could not be allocated.
-
lastModified
The date and time that a user last updated the configuration, in ISO 8601 format.
- Returns:
- The date and time that a user last updated the configuration, in ISO 8601 format.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ProvisionedConcurrencyConfigListItem.Builder,ProvisionedConcurrencyConfigListItem>
-
builder
-
serializableBuilderClass
public static Class<? extends ProvisionedConcurrencyConfigListItem.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-