Interface ProvisionedPollerConfig.Builder

    • Method Detail

      • minimumPollers

        ProvisionedPollerConfig.Builder minimumPollers​(Integer minimumPollers)

        The minimum number of event pollers this event source can scale down to. For Amazon SQS events source mappings, default is 2, and minimum 2 required. For Amazon MSK and self-managed Apache Kafka event source mappings, default is 1.

        Parameters:
        minimumPollers - The minimum number of event pollers this event source can scale down to. For Amazon SQS events source mappings, default is 2, and minimum 2 required. For Amazon MSK and self-managed Apache Kafka event source mappings, default is 1.
        Returns:
        Returns a reference to this object so that method calls can be chained together.
      • maximumPollers

        ProvisionedPollerConfig.Builder maximumPollers​(Integer maximumPollers)

        The maximum number of event pollers this event source can scale up to. For Amazon SQS events source mappings, default is 200, and minimum value allowed is 2. For Amazon MSK and self-managed Apache Kafka event source mappings, default is 200, and minimum value allowed is 1.

        Parameters:
        maximumPollers - The maximum number of event pollers this event source can scale up to. For Amazon SQS events source mappings, default is 200, and minimum value allowed is 2. For Amazon MSK and self-managed Apache Kafka event source mappings, default is 200, and minimum value allowed is 1.
        Returns:
        Returns a reference to this object so that method calls can be chained together.