Class PublishLayerVersionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<PublishLayerVersionRequest.Builder,PublishLayerVersionRequest>

@Generated("software.amazon.awssdk:codegen") public final class PublishLayerVersionRequest extends LambdaRequest implements ToCopyableBuilder<PublishLayerVersionRequest.Builder,PublishLayerVersionRequest>
  • Method Details

    • layerName

      public final String layerName()

      The name or Amazon Resource Name (ARN) of the layer.

      Returns:
      The name or Amazon Resource Name (ARN) of the layer.
    • description

      public final String description()

      The description of the version.

      Returns:
      The description of the version.
    • content

      public final LayerVersionContentInput content()

      The function layer archive.

      Returns:
      The function layer archive.
    • compatibleRuntimes

      public final List<Runtime> compatibleRuntimes()

      A list of compatible function runtimes. Used for filtering with ListLayers and ListLayerVersions.

      The following list includes deprecated runtimes. For more information, see Runtime deprecation policy.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasCompatibleRuntimes() method.

      Returns:
      A list of compatible function runtimes. Used for filtering with ListLayers and ListLayerVersions.

      The following list includes deprecated runtimes. For more information, see Runtime deprecation policy.

    • hasCompatibleRuntimes

      public final boolean hasCompatibleRuntimes()
      For responses, this returns true if the service returned a value for the CompatibleRuntimes property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • compatibleRuntimesAsStrings

      public final List<String> compatibleRuntimesAsStrings()

      A list of compatible function runtimes. Used for filtering with ListLayers and ListLayerVersions.

      The following list includes deprecated runtimes. For more information, see Runtime deprecation policy.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasCompatibleRuntimes() method.

      Returns:
      A list of compatible function runtimes. Used for filtering with ListLayers and ListLayerVersions.

      The following list includes deprecated runtimes. For more information, see Runtime deprecation policy.

    • licenseInfo

      public final String licenseInfo()

      The layer's software license. It can be any of the following:

      • An SPDX license identifier. For example, MIT.

      • The URL of a license hosted on the internet. For example, https://opensource.org/licenses/MIT.

      • The full text of the license.

      Returns:
      The layer's software license. It can be any of the following:

      • An SPDX license identifier. For example, MIT.

      • The URL of a license hosted on the internet. For example, https://opensource.org/licenses/MIT.

      • The full text of the license.

    • compatibleArchitectures

      public final List<Architecture> compatibleArchitectures()

      A list of compatible instruction set architectures.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasCompatibleArchitectures() method.

      Returns:
      A list of compatible instruction set architectures.
    • hasCompatibleArchitectures

      public final boolean hasCompatibleArchitectures()
      For responses, this returns true if the service returned a value for the CompatibleArchitectures property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • compatibleArchitecturesAsStrings

      public final List<String> compatibleArchitecturesAsStrings()

      A list of compatible instruction set architectures.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasCompatibleArchitectures() method.

      Returns:
      A list of compatible instruction set architectures.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<PublishLayerVersionRequest.Builder,PublishLayerVersionRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static PublishLayerVersionRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends PublishLayerVersionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo