Class PublishLayerVersionResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<PublishLayerVersionResponse.Builder,PublishLayerVersionResponse>

@Generated("software.amazon.awssdk:codegen") public final class PublishLayerVersionResponse extends LambdaResponse implements ToCopyableBuilder<PublishLayerVersionResponse.Builder,PublishLayerVersionResponse>
  • Method Details

    • content

      public final LayerVersionContentOutput content()

      Details about the layer version.

      Returns:
      Details about the layer version.
    • layerArn

      public final String layerArn()

      The ARN of the layer.

      Returns:
      The ARN of the layer.
    • layerVersionArn

      public final String layerVersionArn()

      The ARN of the layer version.

      Returns:
      The ARN of the layer version.
    • description

      public final String description()

      The description of the version.

      Returns:
      The description of the version.
    • createdDate

      public final String createdDate()

      The date that the layer version was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

      Returns:
      The date that the layer version was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
    • version

      public final Long version()

      The version number.

      Returns:
      The version number.
    • compatibleRuntimes

      public final List<Runtime> compatibleRuntimes()

      The layer's compatible runtimes.

      The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.

      For a list of all currently supported runtimes, see Supported runtimes.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasCompatibleRuntimes() method.

      Returns:
      The layer's compatible runtimes.

      The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.

      For a list of all currently supported runtimes, see Supported runtimes.

    • hasCompatibleRuntimes

      public final boolean hasCompatibleRuntimes()
      For responses, this returns true if the service returned a value for the CompatibleRuntimes property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • compatibleRuntimesAsStrings

      public final List<String> compatibleRuntimesAsStrings()

      The layer's compatible runtimes.

      The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.

      For a list of all currently supported runtimes, see Supported runtimes.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasCompatibleRuntimes() method.

      Returns:
      The layer's compatible runtimes.

      The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.

      For a list of all currently supported runtimes, see Supported runtimes.

    • licenseInfo

      public final String licenseInfo()

      The layer's software license.

      Returns:
      The layer's software license.
    • compatibleArchitectures

      public final List<Architecture> compatibleArchitectures()

      A list of compatible instruction set architectures.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasCompatibleArchitectures() method.

      Returns:
      A list of compatible instruction set architectures.
    • hasCompatibleArchitectures

      public final boolean hasCompatibleArchitectures()
      For responses, this returns true if the service returned a value for the CompatibleArchitectures property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • compatibleArchitecturesAsStrings

      public final List<String> compatibleArchitecturesAsStrings()

      A list of compatible instruction set architectures.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasCompatibleArchitectures() method.

      Returns:
      A list of compatible instruction set architectures.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<PublishLayerVersionResponse.Builder,PublishLayerVersionResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static PublishLayerVersionResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends PublishLayerVersionResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo