Class PublishVersionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<PublishVersionRequest.Builder,PublishVersionRequest>

@Generated("software.amazon.awssdk:codegen") public final class PublishVersionRequest extends LambdaRequest implements ToCopyableBuilder<PublishVersionRequest.Builder,PublishVersionRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function.

      Name formats

      • Function name - MyFunction.

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

      • Partial ARN - 123456789012:function:MyFunction.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      The name or ARN of the Lambda function.

      Name formats

      • Function name - MyFunction.

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

      • Partial ARN - 123456789012:function:MyFunction.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    • codeSha256

      public final String codeSha256()

      Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. You can get the hash for the version that you uploaded from the output of UpdateFunctionCode.

      Returns:
      Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. You can get the hash for the version that you uploaded from the output of UpdateFunctionCode.
    • description

      public final String description()

      A description for the version to override the description in the function configuration.

      Returns:
      A description for the version to override the description in the function configuration.
    • revisionId

      public final String revisionId()

      Only update the function if the revision ID matches the ID that's specified. Use this option to avoid publishing a version if the function configuration has changed since you last updated it.

      Returns:
      Only update the function if the revision ID matches the ID that's specified. Use this option to avoid publishing a version if the function configuration has changed since you last updated it.
    • publishTo

      public final FunctionVersionLatestPublished publishTo()

      Specifies where to publish the function version or configuration.

      If the service returns an enum value that is not available in the current SDK version, publishTo will return FunctionVersionLatestPublished.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from publishToAsString().

      Returns:
      Specifies where to publish the function version or configuration.
      See Also:
    • publishToAsString

      public final String publishToAsString()

      Specifies where to publish the function version or configuration.

      If the service returns an enum value that is not available in the current SDK version, publishTo will return FunctionVersionLatestPublished.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from publishToAsString().

      Returns:
      Specifies where to publish the function version or configuration.
      See Also:
    • toBuilder

      public PublishVersionRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<PublishVersionRequest.Builder,PublishVersionRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static PublishVersionRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends PublishVersionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo