Class PutFunctionConcurrencyRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<PutFunctionConcurrencyRequest.Builder,PutFunctionConcurrencyRequest>

@Generated("software.amazon.awssdk:codegen") public final class PutFunctionConcurrencyRequest extends LambdaRequest implements ToCopyableBuilder<PutFunctionConcurrencyRequest.Builder,PutFunctionConcurrencyRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function.

      Name formats

      • Function namemy-function.

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      The name or ARN of the Lambda function.

      Name formats

      • Function namemy-function.

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    • reservedConcurrentExecutions

      public final Integer reservedConcurrentExecutions()

      The number of simultaneous executions to reserve for the function.

      Returns:
      The number of simultaneous executions to reserve for the function.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<PutFunctionConcurrencyRequest.Builder,PutFunctionConcurrencyRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static PutFunctionConcurrencyRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends PutFunctionConcurrencyRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo