Interface PutFunctionConcurrencyRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CopyableBuilder<PutFunctionConcurrencyRequest.Builder,PutFunctionConcurrencyRequest>, LambdaRequest.Builder, SdkBuilder<PutFunctionConcurrencyRequest.Builder,PutFunctionConcurrencyRequest>, SdkPojo, SdkRequest.Builder
Enclosing class:
PutFunctionConcurrencyRequest

  • Method Details

    • functionName

      PutFunctionConcurrencyRequest.Builder functionName(String functionName)

      The name or ARN of the Lambda function.

      Name formats

      • Function namemy-function.

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Parameters:
      functionName - The name or ARN of the Lambda function.

      Name formats

      • Function namemy-function.

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • reservedConcurrentExecutions

      PutFunctionConcurrencyRequest.Builder reservedConcurrentExecutions(Integer reservedConcurrentExecutions)

      The number of simultaneous executions to reserve for the function.

      Parameters:
      reservedConcurrentExecutions - The number of simultaneous executions to reserve for the function.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      PutFunctionConcurrencyRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder