Class PutFunctionEventInvokeConfigRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<PutFunctionEventInvokeConfigRequest.Builder,PutFunctionEventInvokeConfigRequest>

@Generated("software.amazon.awssdk:codegen") public final class PutFunctionEventInvokeConfigRequest extends LambdaRequest implements ToCopyableBuilder<PutFunctionEventInvokeConfigRequest.Builder,PutFunctionEventInvokeConfigRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function, version, or alias.

      Name formats

      • Function name - my-function (name-only), my-function:v1 (with alias).

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN - 123456789012:function:my-function.

      You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      The name or ARN of the Lambda function, version, or alias.

      Name formats

      • Function name - my-function (name-only), my-function:v1 (with alias).

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN - 123456789012:function:my-function.

      You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    • qualifier

      public final String qualifier()

      A version number or alias name.

      Returns:
      A version number or alias name.
    • maximumRetryAttempts

      public final Integer maximumRetryAttempts()

      The maximum number of times to retry when the function returns an error.

      Returns:
      The maximum number of times to retry when the function returns an error.
    • maximumEventAgeInSeconds

      public final Integer maximumEventAgeInSeconds()

      The maximum age of a request that Lambda sends to a function for processing.

      Returns:
      The maximum age of a request that Lambda sends to a function for processing.
    • destinationConfig

      public final DestinationConfig destinationConfig()

      A destination for events after they have been sent to a function for processing.

      Destinations

      • Function - The Amazon Resource Name (ARN) of a Lambda function.

      • Queue - The ARN of a standard SQS queue.

      • Bucket - The ARN of an Amazon S3 bucket.

      • Topic - The ARN of a standard SNS topic.

      • Event Bus - The ARN of an Amazon EventBridge event bus.

      S3 buckets are supported only for on-failure destinations. To retain records of successful invocations, use another destination type.

      Returns:
      A destination for events after they have been sent to a function for processing.

      Destinations

      • Function - The Amazon Resource Name (ARN) of a Lambda function.

      • Queue - The ARN of a standard SQS queue.

      • Bucket - The ARN of an Amazon S3 bucket.

      • Topic - The ARN of a standard SNS topic.

      • Event Bus - The ARN of an Amazon EventBridge event bus.

      S3 buckets are supported only for on-failure destinations. To retain records of successful invocations, use another destination type.

    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<PutFunctionEventInvokeConfigRequest.Builder,PutFunctionEventInvokeConfigRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends PutFunctionEventInvokeConfigRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo