Class PutFunctionEventInvokeConfigResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutFunctionEventInvokeConfigResponse.Builder,PutFunctionEventInvokeConfigResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final DestinationConfigA destination for events after they have been sent to a function for processing.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe Amazon Resource Name (ARN) of the function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InstantThe date and time that the configuration was last updated.final IntegerThe maximum age of a request that Lambda sends to a function for processing.final IntegerThe maximum number of times to retry when the function returns an error.static Class<? extends PutFunctionEventInvokeConfigResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
lastModified
The date and time that the configuration was last updated.
- Returns:
- The date and time that the configuration was last updated.
-
functionArn
The Amazon Resource Name (ARN) of the function.
- Returns:
- The Amazon Resource Name (ARN) of the function.
-
maximumRetryAttempts
The maximum number of times to retry when the function returns an error.
- Returns:
- The maximum number of times to retry when the function returns an error.
-
maximumEventAgeInSeconds
The maximum age of a request that Lambda sends to a function for processing.
- Returns:
- The maximum age of a request that Lambda sends to a function for processing.
-
destinationConfig
A destination for events after they have been sent to a function for processing.
Destinations
-
Function - The Amazon Resource Name (ARN) of a Lambda function.
-
Queue - The ARN of a standard SQS queue.
-
Bucket - The ARN of an Amazon S3 bucket.
-
Topic - The ARN of a standard SNS topic.
-
Event Bus - The ARN of an Amazon EventBridge event bus.
S3 buckets are supported only for on-failure destinations. To retain records of successful invocations, use another destination type.
- Returns:
- A destination for events after they have been sent to a function for processing.
Destinations
-
Function - The Amazon Resource Name (ARN) of a Lambda function.
-
Queue - The ARN of a standard SQS queue.
-
Bucket - The ARN of an Amazon S3 bucket.
-
Topic - The ARN of a standard SNS topic.
-
Event Bus - The ARN of an Amazon EventBridge event bus.
S3 buckets are supported only for on-failure destinations. To retain records of successful invocations, use another destination type.
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutFunctionEventInvokeConfigResponse.Builder,PutFunctionEventInvokeConfigResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends PutFunctionEventInvokeConfigResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-