Class PutFunctionRecursionConfigResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<PutFunctionRecursionConfigResponse.Builder,PutFunctionRecursionConfigResponse>

@Generated("software.amazon.awssdk:codegen") public final class PutFunctionRecursionConfigResponse extends LambdaResponse implements ToCopyableBuilder<PutFunctionRecursionConfigResponse.Builder,PutFunctionRecursionConfigResponse>
  • Method Details

    • recursiveLoop

      public final RecursiveLoop recursiveLoop()

      The status of your function's recursive loop detection configuration.

      When this value is set to Allowand Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.

      When this value is set to Terminate and Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you.

      If the service returns an enum value that is not available in the current SDK version, recursiveLoop will return RecursiveLoop.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from recursiveLoopAsString().

      Returns:
      The status of your function's recursive loop detection configuration.

      When this value is set to Allowand Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.

      When this value is set to Terminate and Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you.

      See Also:
    • recursiveLoopAsString

      public final String recursiveLoopAsString()

      The status of your function's recursive loop detection configuration.

      When this value is set to Allowand Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.

      When this value is set to Terminate and Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you.

      If the service returns an enum value that is not available in the current SDK version, recursiveLoop will return RecursiveLoop.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from recursiveLoopAsString().

      Returns:
      The status of your function's recursive loop detection configuration.

      When this value is set to Allowand Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.

      When this value is set to Terminate and Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you.

      See Also:
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<PutFunctionRecursionConfigResponse.Builder,PutFunctionRecursionConfigResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

    • serializableBuilderClass

      public static Class<? extends PutFunctionRecursionConfigResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo