Class PutFunctionScalingConfigRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.lambda.model.LambdaRequest
software.amazon.awssdk.services.lambda.model.PutFunctionScalingConfigRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutFunctionScalingConfigRequest.Builder,PutFunctionScalingConfigRequest>
@Generated("software.amazon.awssdk:codegen")
public final class PutFunctionScalingConfigRequest
extends LambdaRequest
implements ToCopyableBuilder<PutFunctionScalingConfigRequest.Builder,PutFunctionScalingConfigRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function.final FunctionScalingConfigThe scaling configuration to apply to the function, including minimum and maximum execution environment limits.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringSpecify a version or alias to set the scaling configuration for a published version of the function.static Class<? extends PutFunctionScalingConfigRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function.
- Returns:
- The name or ARN of the Lambda function.
-
qualifier
Specify a version or alias to set the scaling configuration for a published version of the function.
- Returns:
- Specify a version or alias to set the scaling configuration for a published version of the function.
-
functionScalingConfig
The scaling configuration to apply to the function, including minimum and maximum execution environment limits.
- Returns:
- The scaling configuration to apply to the function, including minimum and maximum execution environment limits.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutFunctionScalingConfigRequest.Builder,PutFunctionScalingConfigRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-