Class PutFunctionScalingConfigResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.lambda.model.LambdaResponse
software.amazon.awssdk.services.lambda.model.PutFunctionScalingConfigResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutFunctionScalingConfigResponse.Builder,PutFunctionScalingConfigResponse>
@Generated("software.amazon.awssdk:codegen")
public final class PutFunctionScalingConfigResponse
extends LambdaResponse
implements ToCopyableBuilder<PutFunctionScalingConfigResponse.Builder,PutFunctionScalingConfigResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StateThe current state of the function after applying the scaling configuration.final StringThe current state of the function after applying the scaling configuration.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends PutFunctionScalingConfigResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionState
The current state of the function after applying the scaling configuration.
If the service returns an enum value that is not available in the current SDK version,
functionStatewill returnState.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfunctionStateAsString().- Returns:
- The current state of the function after applying the scaling configuration.
- See Also:
-
functionStateAsString
The current state of the function after applying the scaling configuration.
If the service returns an enum value that is not available in the current SDK version,
functionStatewill returnState.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfunctionStateAsString().- Returns:
- The current state of the function after applying the scaling configuration.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutFunctionScalingConfigResponse.Builder,PutFunctionScalingConfigResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-