Interface PutFunctionScalingConfigResponse.Builder

All Superinterfaces:
AwsResponse.Builder, Buildable, CopyableBuilder<PutFunctionScalingConfigResponse.Builder,PutFunctionScalingConfigResponse>, LambdaResponse.Builder, SdkBuilder<PutFunctionScalingConfigResponse.Builder,PutFunctionScalingConfigResponse>, SdkPojo, SdkResponse.Builder
Enclosing class:
PutFunctionScalingConfigResponse

  • Method Details

    • functionState

      PutFunctionScalingConfigResponse.Builder functionState(String functionState)

      The current state of the function after applying the scaling configuration.

      Parameters:
      functionState - The current state of the function after applying the scaling configuration.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also:
    • functionState

      PutFunctionScalingConfigResponse.Builder functionState(State functionState)

      The current state of the function after applying the scaling configuration.

      Parameters:
      functionState - The current state of the function after applying the scaling configuration.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
      See Also: