Class PutRuntimeManagementConfigRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<PutRuntimeManagementConfigRequest.Builder,PutRuntimeManagementConfigRequest>

@Generated("software.amazon.awssdk:codegen") public final class PutRuntimeManagementConfigRequest extends LambdaRequest implements ToCopyableBuilder<PutRuntimeManagementConfigRequest.Builder,PutRuntimeManagementConfigRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function.

      Name formats

      • Function namemy-function.

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      The name or ARN of the Lambda function.

      Name formats

      • Function namemy-function.

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    • qualifier

      public final String qualifier()

      Specify a version of the function. This can be $LATEST or a published version number. If no value is specified, the configuration for the $LATEST version is returned.

      Returns:
      Specify a version of the function. This can be $LATEST or a published version number. If no value is specified, the configuration for the $LATEST version is returned.
    • updateRuntimeOn

      public final UpdateRuntimeOn updateRuntimeOn()

      Specify the runtime update mode.

      • Auto (default) - Automatically update to the most recent and secure runtime version using a Two-phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.

      • Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.

      • Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.

      If the service returns an enum value that is not available in the current SDK version, updateRuntimeOn will return UpdateRuntimeOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from updateRuntimeOnAsString().

      Returns:
      Specify the runtime update mode.

      • Auto (default) - Automatically update to the most recent and secure runtime version using a Two- phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.

      • Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.

      • Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.

      See Also:
    • updateRuntimeOnAsString

      public final String updateRuntimeOnAsString()

      Specify the runtime update mode.

      • Auto (default) - Automatically update to the most recent and secure runtime version using a Two-phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.

      • Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.

      • Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.

      If the service returns an enum value that is not available in the current SDK version, updateRuntimeOn will return UpdateRuntimeOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from updateRuntimeOnAsString().

      Returns:
      Specify the runtime update mode.

      • Auto (default) - Automatically update to the most recent and secure runtime version using a Two- phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.

      • Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.

      • Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.

      See Also:
    • runtimeVersionArn

      public final String runtimeVersionArn()

      The ARN of the runtime version you want the function to use.

      This is only required if you're using the Manual runtime update mode.

      Returns:
      The ARN of the runtime version you want the function to use.

      This is only required if you're using the Manual runtime update mode.

    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<PutRuntimeManagementConfigRequest.Builder,PutRuntimeManagementConfigRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends PutRuntimeManagementConfigRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo