Class PutRuntimeManagementConfigResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.lambda.model.LambdaResponse
software.amazon.awssdk.services.lambda.model.PutRuntimeManagementConfigResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutRuntimeManagementConfigResponse.Builder,PutRuntimeManagementConfigResponse>
@Generated("software.amazon.awssdk:codegen")
public final class PutRuntimeManagementConfigResponse
extends LambdaResponse
implements ToCopyableBuilder<PutRuntimeManagementConfigResponse.Builder,PutRuntimeManagementConfigResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe ARN of the functionfinal <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ARN of the runtime the function is configured to use.static Class<? extends PutRuntimeManagementConfigResponse.Builder>final StringtoString()Returns a string representation of this object.final UpdateRuntimeOnThe runtime update mode.final StringThe runtime update mode.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
updateRuntimeOn
The runtime update mode.
If the service returns an enum value that is not available in the current SDK version,
updateRuntimeOnwill returnUpdateRuntimeOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromupdateRuntimeOnAsString().- Returns:
- The runtime update mode.
- See Also:
-
updateRuntimeOnAsString
The runtime update mode.
If the service returns an enum value that is not available in the current SDK version,
updateRuntimeOnwill returnUpdateRuntimeOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromupdateRuntimeOnAsString().- Returns:
- The runtime update mode.
- See Also:
-
functionArn
The ARN of the function
- Returns:
- The ARN of the function
-
runtimeVersionArn
The ARN of the runtime the function is configured to use. If the runtime update mode is manual, the ARN is returned, otherwise
nullis returned.- Returns:
- The ARN of the runtime the function is configured to use. If the runtime update mode is manual,
the ARN is returned, otherwise
nullis returned.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutRuntimeManagementConfigResponse.Builder,PutRuntimeManagementConfigResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends PutRuntimeManagementConfigResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-