Class RemoveLayerVersionPermissionRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.lambda.model.LambdaRequest
software.amazon.awssdk.services.lambda.model.RemoveLayerVersionPermissionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<RemoveLayerVersionPermissionRequest.Builder,RemoveLayerVersionPermissionRequest>
@Generated("software.amazon.awssdk:codegen")
public final class RemoveLayerVersionPermissionRequest
extends LambdaRequest
implements ToCopyableBuilder<RemoveLayerVersionPermissionRequest.Builder,RemoveLayerVersionPermissionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name or Amazon Resource Name (ARN) of the layer.final StringOnly update the policy if the revision ID matches the ID specified.static Class<? extends RemoveLayerVersionPermissionRequest.Builder>final StringThe identifier that was specified when the statement was added.final StringtoString()Returns a string representation of this object.final LongThe version number.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
layerName
The name or Amazon Resource Name (ARN) of the layer.
- Returns:
- The name or Amazon Resource Name (ARN) of the layer.
-
versionNumber
The version number.
- Returns:
- The version number.
-
statementId
The identifier that was specified when the statement was added.
- Returns:
- The identifier that was specified when the statement was added.
-
revisionId
Only update the policy if the revision ID matches the ID specified. Use this option to avoid modifying a policy that has changed since you last read it.
- Returns:
- Only update the policy if the revision ID matches the ID specified. Use this option to avoid modifying a policy that has changed since you last read it.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RemoveLayerVersionPermissionRequest.Builder,RemoveLayerVersionPermissionRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
public static Class<? extends RemoveLayerVersionPermissionRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-