Class RemovePermissionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<RemovePermissionRequest.Builder,RemovePermissionRequest>

@Generated("software.amazon.awssdk:codegen") public final class RemovePermissionRequest extends LambdaRequest implements ToCopyableBuilder<RemovePermissionRequest.Builder,RemovePermissionRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function, version, or alias.

      Name formats

      • Function namemy-function (name-only), my-function:v1 (with alias).

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      The name or ARN of the Lambda function, version, or alias.

      Name formats

      • Function namemy-function (name-only), my-function:v1 (with alias).

      • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

      • Partial ARN123456789012:function:my-function.

      You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    • statementId

      public final String statementId()

      Statement ID of the permission to remove.

      Returns:
      Statement ID of the permission to remove.
    • qualifier

      public final String qualifier()

      Specify a version or alias to remove permissions from a published version of the function.

      Returns:
      Specify a version or alias to remove permissions from a published version of the function.
    • revisionId

      public final String revisionId()

      Update the policy only if the revision ID matches the ID that's specified. Use this option to avoid modifying a policy that has changed since you last read it.

      Returns:
      Update the policy only if the revision ID matches the ID that's specified. Use this option to avoid modifying a policy that has changed since you last read it.
    • toBuilder

      public RemovePermissionRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<RemovePermissionRequest.Builder,RemovePermissionRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static RemovePermissionRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends RemovePermissionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo