Interface ResourceNotFoundException.Builder
- All Superinterfaces:
AwsServiceException.Builder,Buildable,CopyableBuilder<ResourceNotFoundException.Builder,,ResourceNotFoundException> LambdaException.Builder,SdkBuilder<ResourceNotFoundException.Builder,,ResourceNotFoundException> SdkException.Builder,SdkPojo,SdkServiceException.Builder
- Enclosing class:
- ResourceNotFoundException
@Mutable
@NotThreadSafe
public static interface ResourceNotFoundException.Builder
extends SdkPojo, CopyableBuilder<ResourceNotFoundException.Builder,ResourceNotFoundException>, LambdaException.Builder
-
Method Summary
Modifier and TypeMethodDescriptionawsErrorDetails(AwsErrorDetails awsErrorDetails) numAttempts(Integer numAttempts) statusCode(int statusCode) Sets the value of the Type property for this object.writableStackTrace(Boolean writableStackTrace) Methods inherited from interface software.amazon.awssdk.awscore.exception.AwsServiceException.Builder
awsErrorDetails, build, clockSkew, clockSkew, extendedRequestIdMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.exception.SdkException.Builder
cause, message, numAttempts, writableStackTraceMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.core.exception.SdkServiceException.Builder
extendedRequestId, requestId, statusCode
-
Method Details
-
type
Sets the value of the Type property for this object.- Parameters:
type- The new value for the Type property for this object.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
awsErrorDetails
- Specified by:
awsErrorDetailsin interfaceAwsServiceException.Builder- Specified by:
awsErrorDetailsin interfaceLambdaException.Builder
-
message
- Specified by:
messagein interfaceAwsServiceException.Builder- Specified by:
messagein interfaceLambdaException.Builder- Specified by:
messagein interfaceSdkException.Builder- Specified by:
messagein interfaceSdkServiceException.Builder
-
requestId
- Specified by:
requestIdin interfaceAwsServiceException.Builder- Specified by:
requestIdin interfaceLambdaException.Builder- Specified by:
requestIdin interfaceSdkServiceException.Builder
-
statusCode
- Specified by:
statusCodein interfaceAwsServiceException.Builder- Specified by:
statusCodein interfaceLambdaException.Builder- Specified by:
statusCodein interfaceSdkServiceException.Builder
-
cause
- Specified by:
causein interfaceAwsServiceException.Builder- Specified by:
causein interfaceLambdaException.Builder- Specified by:
causein interfaceSdkException.Builder- Specified by:
causein interfaceSdkServiceException.Builder
-
writableStackTrace
- Specified by:
writableStackTracein interfaceLambdaException.Builder- Specified by:
writableStackTracein interfaceSdkException.Builder- Specified by:
writableStackTracein interfaceSdkServiceException.Builder
-
numAttempts
- Specified by:
numAttemptsin interfaceAwsServiceException.Builder- Specified by:
numAttemptsin interfaceLambdaException.Builder- Specified by:
numAttemptsin interfaceSdkException.Builder- Specified by:
numAttemptsin interfaceSdkServiceException.Builder
-