Class RuntimeVersionConfig
java.lang.Object
software.amazon.awssdk.services.lambda.model.RuntimeVersionConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RuntimeVersionConfig.Builder,RuntimeVersionConfig>
@Generated("software.amazon.awssdk:codegen")
public final class RuntimeVersionConfig
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<RuntimeVersionConfig.Builder,RuntimeVersionConfig>
The ARN of the runtime and any errors that occured.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic RuntimeVersionConfig.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final RuntimeVersionErrorerror()Error response when Lambda is unable to retrieve the runtime version for a function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ARN of the runtime version you want the function to use.static Class<? extends RuntimeVersionConfig.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
runtimeVersionArn
The ARN of the runtime version you want the function to use.
- Returns:
- The ARN of the runtime version you want the function to use.
-
error
Error response when Lambda is unable to retrieve the runtime version for a function.
- Returns:
- Error response when Lambda is unable to retrieve the runtime version for a function.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RuntimeVersionConfig.Builder,RuntimeVersionConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-