Interface SendDurableExecutionCallbackFailureRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<SendDurableExecutionCallbackFailureRequest.Builder,,SendDurableExecutionCallbackFailureRequest> LambdaRequest.Builder,SdkBuilder<SendDurableExecutionCallbackFailureRequest.Builder,,SendDurableExecutionCallbackFailureRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- SendDurableExecutionCallbackFailureRequest
@Mutable
@NotThreadSafe
public static interface SendDurableExecutionCallbackFailureRequest.Builder
extends LambdaRequest.Builder, SdkPojo, CopyableBuilder<SendDurableExecutionCallbackFailureRequest.Builder,SendDurableExecutionCallbackFailureRequest>
-
Method Summary
Modifier and TypeMethodDescriptioncallbackId(String callbackId) The unique identifier for the callback operation.error(Consumer<ErrorObject.Builder> error) Error details describing why the callback operation failed.error(ErrorObject error) Error details describing why the callback operation failed.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.services.lambda.model.LambdaRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
callbackId
The unique identifier for the callback operation.
- Parameters:
callbackId- The unique identifier for the callback operation.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
error
Error details describing why the callback operation failed.
- Parameters:
error- Error details describing why the callback operation failed.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
error
default SendDurableExecutionCallbackFailureRequest.Builder error(Consumer<ErrorObject.Builder> error) Error details describing why the callback operation failed.
This is a convenience method that creates an instance of theErrorObject.Builderavoiding the need to create one manually viaErrorObject.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed toerror(ErrorObject).- Parameters:
error- a consumer that will call methods onErrorObject.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
SendDurableExecutionCallbackFailureRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
SendDurableExecutionCallbackFailureRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-