Interface SendDurableExecutionCallbackSuccessRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<SendDurableExecutionCallbackSuccessRequest.Builder,,SendDurableExecutionCallbackSuccessRequest> LambdaRequest.Builder,SdkBuilder<SendDurableExecutionCallbackSuccessRequest.Builder,,SendDurableExecutionCallbackSuccessRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- SendDurableExecutionCallbackSuccessRequest
@Mutable
@NotThreadSafe
public static interface SendDurableExecutionCallbackSuccessRequest.Builder
extends LambdaRequest.Builder, SdkPojo, CopyableBuilder<SendDurableExecutionCallbackSuccessRequest.Builder,SendDurableExecutionCallbackSuccessRequest>
-
Method Summary
Modifier and TypeMethodDescriptioncallbackId(String callbackId) The unique identifier for the callback operation.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) The result data from the successful callback operation.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.services.lambda.model.LambdaRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
callbackId
The unique identifier for the callback operation.
- Parameters:
callbackId- The unique identifier for the callback operation.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
result
The result data from the successful callback operation. Maximum size is 256 KB.
- Parameters:
result- The result data from the successful callback operation. Maximum size is 256 KB.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
SendDurableExecutionCallbackSuccessRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
SendDurableExecutionCallbackSuccessRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-