Class SnapStart
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SnapStart.Builder,SnapStart>
The function's Lambda SnapStart setting.
Set ApplyOn to PublishedVersions to create a snapshot of the initialized execution
environment when you publish a function version.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal SnapStartApplyOnapplyOn()Set toPublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.final StringSet toPublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.static SnapStart.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends SnapStart.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
applyOn
Set to
PublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.If the service returns an enum value that is not available in the current SDK version,
applyOnwill returnSnapStartApplyOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromapplyOnAsString().- Returns:
- Set to
PublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version. - See Also:
-
applyOnAsString
Set to
PublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.If the service returns an enum value that is not available in the current SDK version,
applyOnwill returnSnapStartApplyOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromapplyOnAsString().- Returns:
- Set to
PublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SnapStart.Builder,SnapStart>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-