Class SnapStartResponse
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SnapStartResponse.Builder,SnapStartResponse>
The function's SnapStart setting.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal SnapStartApplyOnapplyOn()When set toPublishedVersions, Lambda creates a snapshot of the execution environment when you publish a function version.final StringWhen set toPublishedVersions, Lambda creates a snapshot of the execution environment when you publish a function version.static SnapStartResponse.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()When you provide a qualified Amazon Resource Name (ARN), this response element indicates whether SnapStart is activated for the specified function version.final StringWhen you provide a qualified Amazon Resource Name (ARN), this response element indicates whether SnapStart is activated for the specified function version.static Class<? extends SnapStartResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
applyOn
When set to
PublishedVersions, Lambda creates a snapshot of the execution environment when you publish a function version.If the service returns an enum value that is not available in the current SDK version,
applyOnwill returnSnapStartApplyOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromapplyOnAsString().- Returns:
- When set to
PublishedVersions, Lambda creates a snapshot of the execution environment when you publish a function version. - See Also:
-
applyOnAsString
When set to
PublishedVersions, Lambda creates a snapshot of the execution environment when you publish a function version.If the service returns an enum value that is not available in the current SDK version,
applyOnwill returnSnapStartApplyOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromapplyOnAsString().- Returns:
- When set to
PublishedVersions, Lambda creates a snapshot of the execution environment when you publish a function version. - See Also:
-
optimizationStatus
When you provide a qualified Amazon Resource Name (ARN), this response element indicates whether SnapStart is activated for the specified function version.
If the service returns an enum value that is not available in the current SDK version,
optimizationStatuswill returnSnapStartOptimizationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoptimizationStatusAsString().- Returns:
- When you provide a qualified Amazon Resource Name (ARN), this response element indicates whether SnapStart is activated for the specified function version.
- See Also:
-
optimizationStatusAsString
When you provide a qualified Amazon Resource Name (ARN), this response element indicates whether SnapStart is activated for the specified function version.
If the service returns an enum value that is not available in the current SDK version,
optimizationStatuswill returnSnapStartOptimizationStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoptimizationStatusAsString().- Returns:
- When you provide a qualified Amazon Resource Name (ARN), this response element indicates whether SnapStart is activated for the specified function version.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SnapStartResponse.Builder,SnapStartResponse>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-