Class StepDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.StepDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<StepDetails.Builder,StepDetails>
@Generated("software.amazon.awssdk:codegen")
public final class StepDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<StepDetails.Builder,StepDetails>
Details about a step operation.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Integerattempt()The current attempt number for this step.static StepDetails.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final ErrorObjecterror()Details about the step failure.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InstantThe date and time when the next attempt is scheduled, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).final Stringresult()The JSON response payload from the step operation.static Class<? extends StepDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
attempt
The current attempt number for this step.
- Returns:
- The current attempt number for this step.
-
nextAttemptTimestamp
The date and time when the next attempt is scheduled, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD). Only populated when the step is in a pending state.
- Returns:
- The date and time when the next attempt is scheduled, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD). Only populated when the step is in a pending state.
-
result
The JSON response payload from the step operation.
- Returns:
- The JSON response payload from the step operation.
-
error
Details about the step failure.
- Returns:
- Details about the step failure.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<StepDetails.Builder,StepDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-