Interface StepOptions.Builder

All Superinterfaces:
Buildable, CopyableBuilder<StepOptions.Builder,StepOptions>, SdkBuilder<StepOptions.Builder,StepOptions>, SdkPojo
Enclosing class:
StepOptions

@Mutable @NotThreadSafe public static interface StepOptions.Builder extends SdkPojo, CopyableBuilder<StepOptions.Builder,StepOptions>
  • Method Details

    • nextAttemptDelaySeconds

      StepOptions.Builder nextAttemptDelaySeconds(Integer nextAttemptDelaySeconds)

      The delay in seconds before the next retry attempt.

      Parameters:
      nextAttemptDelaySeconds - The delay in seconds before the next retry attempt.
      Returns:
      Returns a reference to this object so that method calls can be chained together.