Class TargetTrackingScalingPolicy
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<TargetTrackingScalingPolicy.Builder,TargetTrackingScalingPolicy>
A scaling policy for the capacity provider that automatically adjusts capacity to maintain a target value for a specific metric.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()The predefined metric type to track for scaling decisions.final StringThe predefined metric type to track for scaling decisions.static Class<? extends TargetTrackingScalingPolicy.Builder>final DoubleThe target value for the metric that the scaling policy attempts to maintain through scaling actions.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
predefinedMetricType
The predefined metric type to track for scaling decisions.
If the service returns an enum value that is not available in the current SDK version,
predefinedMetricTypewill returnCapacityProviderPredefinedMetricType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frompredefinedMetricTypeAsString().- Returns:
- The predefined metric type to track for scaling decisions.
- See Also:
-
predefinedMetricTypeAsString
The predefined metric type to track for scaling decisions.
If the service returns an enum value that is not available in the current SDK version,
predefinedMetricTypewill returnCapacityProviderPredefinedMetricType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frompredefinedMetricTypeAsString().- Returns:
- The predefined metric type to track for scaling decisions.
- See Also:
-
targetValue
The target value for the metric that the scaling policy attempts to maintain through scaling actions.
- Returns:
- The target value for the metric that the scaling policy attempts to maintain through scaling actions.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<TargetTrackingScalingPolicy.Builder,TargetTrackingScalingPolicy>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-