Class TenancyConfig
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<TenancyConfig.Builder,TenancyConfig>
Specifies the tenant isolation mode configuration for a Lambda function. This allows you to configure specific tenant isolation strategies for your function invocations. Tenant isolation configuration cannot be modified after function creation.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic TenancyConfig.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends TenancyConfig.Builder>final TenantIsolationModeTenant isolation mode allows for invocation to be sent to a corresponding execution environment dedicated to a specific tenant ID.final StringTenant isolation mode allows for invocation to be sent to a corresponding execution environment dedicated to a specific tenant ID.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
tenantIsolationMode
Tenant isolation mode allows for invocation to be sent to a corresponding execution environment dedicated to a specific tenant ID.
If the service returns an enum value that is not available in the current SDK version,
tenantIsolationModewill returnTenantIsolationMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtenantIsolationModeAsString().- Returns:
- Tenant isolation mode allows for invocation to be sent to a corresponding execution environment dedicated to a specific tenant ID.
- See Also:
-
tenantIsolationModeAsString
Tenant isolation mode allows for invocation to be sent to a corresponding execution environment dedicated to a specific tenant ID.
If the service returns an enum value that is not available in the current SDK version,
tenantIsolationModewill returnTenantIsolationMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromtenantIsolationModeAsString().- Returns:
- Tenant isolation mode allows for invocation to be sent to a corresponding execution environment dedicated to a specific tenant ID.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<TenancyConfig.Builder,TenancyConfig>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-