Interface TooManyRequestsException.Builder
- All Superinterfaces:
AwsServiceException.Builder,Buildable,CopyableBuilder<TooManyRequestsException.Builder,,TooManyRequestsException> LambdaException.Builder,SdkBuilder<TooManyRequestsException.Builder,,TooManyRequestsException> SdkException.Builder,SdkPojo,SdkServiceException.Builder
- Enclosing class:
- TooManyRequestsException
@Mutable
@NotThreadSafe
public static interface TooManyRequestsException.Builder
extends SdkPojo, CopyableBuilder<TooManyRequestsException.Builder,TooManyRequestsException>, LambdaException.Builder
-
Method Summary
Modifier and TypeMethodDescriptionawsErrorDetails(AwsErrorDetails awsErrorDetails) numAttempts(Integer numAttempts) Sets the value of the Reason property for this object.reason(ThrottleReason reason) Sets the value of the Reason property for this object.retryAfterSeconds(String retryAfterSeconds) The number of seconds the caller should wait before retrying.statusCode(int statusCode) Sets the value of the Type property for this object.writableStackTrace(Boolean writableStackTrace) Methods inherited from interface software.amazon.awssdk.awscore.exception.AwsServiceException.Builder
awsErrorDetails, build, clockSkew, clockSkew, extendedRequestIdMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.exception.SdkException.Builder
cause, message, numAttempts, writableStackTraceMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.core.exception.SdkServiceException.Builder
extendedRequestId, requestId, statusCode
-
Method Details
-
retryAfterSeconds
The number of seconds the caller should wait before retrying.
- Parameters:
retryAfterSeconds- The number of seconds the caller should wait before retrying.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
type
Sets the value of the Type property for this object.- Parameters:
type- The new value for the Type property for this object.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
reason
Sets the value of the Reason property for this object.- Parameters:
reason- The new value for the Reason property for this object.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
reason
Sets the value of the Reason property for this object.- Parameters:
reason- The new value for the Reason property for this object.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
awsErrorDetails
- Specified by:
awsErrorDetailsin interfaceAwsServiceException.Builder- Specified by:
awsErrorDetailsin interfaceLambdaException.Builder
-
message
- Specified by:
messagein interfaceAwsServiceException.Builder- Specified by:
messagein interfaceLambdaException.Builder- Specified by:
messagein interfaceSdkException.Builder- Specified by:
messagein interfaceSdkServiceException.Builder
-
requestId
- Specified by:
requestIdin interfaceAwsServiceException.Builder- Specified by:
requestIdin interfaceLambdaException.Builder- Specified by:
requestIdin interfaceSdkServiceException.Builder
-
statusCode
- Specified by:
statusCodein interfaceAwsServiceException.Builder- Specified by:
statusCodein interfaceLambdaException.Builder- Specified by:
statusCodein interfaceSdkServiceException.Builder
-
cause
- Specified by:
causein interfaceAwsServiceException.Builder- Specified by:
causein interfaceLambdaException.Builder- Specified by:
causein interfaceSdkException.Builder- Specified by:
causein interfaceSdkServiceException.Builder
-
writableStackTrace
- Specified by:
writableStackTracein interfaceLambdaException.Builder- Specified by:
writableStackTracein interfaceSdkException.Builder- Specified by:
writableStackTracein interfaceSdkServiceException.Builder
-
numAttempts
- Specified by:
numAttemptsin interfaceAwsServiceException.Builder- Specified by:
numAttemptsin interfaceLambdaException.Builder- Specified by:
numAttemptsin interfaceSdkException.Builder- Specified by:
numAttemptsin interfaceSdkServiceException.Builder
-