Class UpdateAliasRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdateAliasRequest.Builder,UpdateAliasRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdateAliasRequest extends LambdaRequest implements ToCopyableBuilder<UpdateAliasRequest.Builder,UpdateAliasRequest>
  • Method Details

    • functionName

      public final String functionName()

      The name or ARN of the Lambda function.

      Name formats

      • Function name - MyFunction.

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

      • Partial ARN - 123456789012:function:MyFunction.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

      Returns:
      The name or ARN of the Lambda function.

      Name formats

      • Function name - MyFunction.

      • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

      • Partial ARN - 123456789012:function:MyFunction.

      The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

    • name

      public final String name()

      The name of the alias.

      Returns:
      The name of the alias.
    • functionVersion

      public final String functionVersion()

      The function version that the alias invokes.

      Returns:
      The function version that the alias invokes.
    • description

      public final String description()

      A description of the alias.

      Returns:
      A description of the alias.
    • routingConfig

      public final AliasRoutingConfiguration routingConfig()

      The routing configuration of the alias.

      Returns:
      The routing configuration of the alias.
    • revisionId

      public final String revisionId()

      Only update the alias if the revision ID matches the ID that's specified. Use this option to avoid modifying an alias that has changed since you last read it.

      Returns:
      Only update the alias if the revision ID matches the ID that's specified. Use this option to avoid modifying an alias that has changed since you last read it.
    • toBuilder

      public UpdateAliasRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdateAliasRequest.Builder,UpdateAliasRequest>
      Specified by:
      toBuilder in class LambdaRequest
    • builder

      public static UpdateAliasRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends UpdateAliasRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo