Class UpdateFunctionCodeRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateFunctionCodeRequest.Builder,UpdateFunctionCodeRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal List<Architecture>The instruction set architecture that the function supports.The instruction set architecture that the function supports.builder()final BooleandryRun()Set to true to validate the request parameters and access permissions without modifying the function code.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the Architectures property.final inthashCode()final StringimageUri()URI of a container image in the Amazon ECR registry.final Booleanpublish()Set to true to publish a new version of the function after updating the code.Specifies where to publish the function version or configuration.final StringSpecifies where to publish the function version or configuration.final StringUpdate the function only if the revision ID matches the ID that's specified.final Strings3Bucket()An Amazon S3 bucket in the same Amazon Web Services Region as your function.final Strings3Key()The Amazon S3 key of the deployment package.final StringFor versioned objects, the version of the deployment package object to use.static Class<? extends UpdateFunctionCodeRequest.Builder>final StringThe ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package.final StringtoString()Returns a string representation of this object.final SdkByteszipFile()The base64-encoded contents of the deployment package.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Returns:
- The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
-
-
zipFile
The base64-encoded contents of the deployment package. Amazon Web Services SDK and CLI clients handle the encoding for you. Use only with a function defined with a .zip file archive deployment package.
- Returns:
- The base64-encoded contents of the deployment package. Amazon Web Services SDK and CLI clients handle the encoding for you. Use only with a function defined with a .zip file archive deployment package.
-
s3Bucket
An Amazon S3 bucket in the same Amazon Web Services Region as your function. The bucket can be in a different Amazon Web Services account. Use only with a function defined with a .zip file archive deployment package.
- Returns:
- An Amazon S3 bucket in the same Amazon Web Services Region as your function. The bucket can be in a different Amazon Web Services account. Use only with a function defined with a .zip file archive deployment package.
-
s3Key
The Amazon S3 key of the deployment package. Use only with a function defined with a .zip file archive deployment package.
- Returns:
- The Amazon S3 key of the deployment package. Use only with a function defined with a .zip file archive deployment package.
-
s3ObjectVersion
For versioned objects, the version of the deployment package object to use.
- Returns:
- For versioned objects, the version of the deployment package object to use.
-
imageUri
URI of a container image in the Amazon ECR registry. Do not use for a function defined with a .zip file archive.
- Returns:
- URI of a container image in the Amazon ECR registry. Do not use for a function defined with a .zip file archive.
-
publish
Set to true to publish a new version of the function after updating the code. This has the same effect as calling PublishVersion separately.
- Returns:
- Set to true to publish a new version of the function after updating the code. This has the same effect as calling PublishVersion separately.
-
dryRun
Set to true to validate the request parameters and access permissions without modifying the function code.
- Returns:
- Set to true to validate the request parameters and access permissions without modifying the function code.
-
revisionId
Update the function only if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it.
- Returns:
- Update the function only if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it.
-
architectures
The instruction set architecture that the function supports. Enter a string array with one of the valid values (arm64 or x86_64). The default value is
x86_64.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasArchitectures()method.- Returns:
- The instruction set architecture that the function supports. Enter a string array with one of the valid
values (arm64 or x86_64). The default value is
x86_64.
-
hasArchitectures
public final boolean hasArchitectures()For responses, this returns true if the service returned a value for the Architectures property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
architecturesAsStrings
The instruction set architecture that the function supports. Enter a string array with one of the valid values (arm64 or x86_64). The default value is
x86_64.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasArchitectures()method.- Returns:
- The instruction set architecture that the function supports. Enter a string array with one of the valid
values (arm64 or x86_64). The default value is
x86_64.
-
sourceKMSKeyArn
The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package. If you don't provide a customer managed key, Lambda uses an Amazon Web Services managed key.
- Returns:
- The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package. If you don't provide a customer managed key, Lambda uses an Amazon Web Services managed key.
-
publishTo
Specifies where to publish the function version or configuration.
If the service returns an enum value that is not available in the current SDK version,
publishTowill returnFunctionVersionLatestPublished.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frompublishToAsString().- Returns:
- Specifies where to publish the function version or configuration.
- See Also:
-
publishToAsString
Specifies where to publish the function version or configuration.
If the service returns an enum value that is not available in the current SDK version,
publishTowill returnFunctionVersionLatestPublished.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frompublishToAsString().- Returns:
- Specifies where to publish the function version or configuration.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateFunctionCodeRequest.Builder,UpdateFunctionCodeRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-