Class WaitDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.WaitDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<WaitDetails.Builder,WaitDetails>
@Generated("software.amazon.awssdk:codegen")
public final class WaitDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<WaitDetails.Builder,WaitDetails>
Details about a wait operation.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic WaitDetails.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InstantThe date and time when the wait operation is scheduled to complete, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).static Class<? extends WaitDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
scheduledEndTimestamp
The date and time when the wait operation is scheduled to complete, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- The date and time when the wait operation is scheduled to complete, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<WaitDetails.Builder,WaitDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-