Interface WaitDetails.Builder

All Superinterfaces:
Buildable, CopyableBuilder<WaitDetails.Builder,WaitDetails>, SdkBuilder<WaitDetails.Builder,WaitDetails>, SdkPojo
Enclosing class:
WaitDetails

@Mutable @NotThreadSafe public static interface WaitDetails.Builder extends SdkPojo, CopyableBuilder<WaitDetails.Builder,WaitDetails>
  • Method Details

    • scheduledEndTimestamp

      WaitDetails.Builder scheduledEndTimestamp(Instant scheduledEndTimestamp)

      The date and time when the wait operation is scheduled to complete, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

      Parameters:
      scheduledEndTimestamp - The date and time when the wait operation is scheduled to complete, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
      Returns:
      Returns a reference to this object so that method calls can be chained together.