Class WaitStartedDetails
java.lang.Object
software.amazon.awssdk.services.lambda.model.WaitStartedDetails
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<WaitStartedDetails.Builder,WaitStartedDetails>
@Generated("software.amazon.awssdk:codegen")
public final class WaitStartedDetails
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<WaitStartedDetails.Builder,WaitStartedDetails>
Details about a wait operation that has started.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic WaitStartedDetails.Builderbuilder()final Integerduration()The duration to wait, in seconds.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InstantThe date and time when the wait operation is scheduled to complete, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).static Class<? extends WaitStartedDetails.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
duration
The duration to wait, in seconds.
- Returns:
- The duration to wait, in seconds.
-
scheduledEndTimestamp
The date and time when the wait operation is scheduled to complete, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- The date and time when the wait operation is scheduled to complete, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<WaitStartedDetails.Builder,WaitStartedDetails>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-