Uses of Enum
software.amazon.awssdk.services.lambda.model.ApplicationLogLevel
Packages that use ApplicationLogLevel
-
Uses of ApplicationLogLevel in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return ApplicationLogLevelModifier and TypeMethodDescriptionfinal ApplicationLogLevelLoggingConfig.applicationLogLevel()Set this property to filter the application logs for your function that Lambda sends to CloudWatch.static ApplicationLogLevelUse this in place of valueOf to convert the raw string returned by the service into the enum value.static ApplicationLogLevelReturns the enum constant of this type with the specified name.static ApplicationLogLevel[]ApplicationLogLevel.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type ApplicationLogLevelModifier and TypeMethodDescriptionstatic Set<ApplicationLogLevel>ApplicationLogLevel.knownValues()Methods in software.amazon.awssdk.services.lambda.model with parameters of type ApplicationLogLevelModifier and TypeMethodDescriptionLoggingConfig.Builder.applicationLogLevel(ApplicationLogLevel applicationLogLevel) Set this property to filter the application logs for your function that Lambda sends to CloudWatch.