Uses of Interface
software.amazon.awssdk.services.lambda.model.CallbackOptions.Builder
Packages that use CallbackOptions.Builder
-
Uses of CallbackOptions.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return CallbackOptions.BuilderModifier and TypeMethodDescriptionstatic CallbackOptions.BuilderCallbackOptions.builder()CallbackOptions.Builder.heartbeatTimeoutSeconds(Integer heartbeatTimeoutSeconds) The heartbeat timeout for the callback operation, in seconds.CallbackOptions.Builder.timeoutSeconds(Integer timeoutSeconds) The timeout for the callback operation in seconds.CallbackOptions.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type CallbackOptions.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CallbackOptions.Builder>CallbackOptions.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type CallbackOptions.BuilderModifier and TypeMethodDescriptiondefault OperationUpdate.BuilderOperationUpdate.Builder.callbackOptions(Consumer<CallbackOptions.Builder> callbackOptions) Sets the value of the CallbackOptions property for this object.