Uses of Interface
software.amazon.awssdk.services.lambda.model.CheckpointDurableExecutionResponse.Builder
Packages that use CheckpointDurableExecutionResponse.Builder
-
Uses of CheckpointDurableExecutionResponse.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return CheckpointDurableExecutionResponse.BuilderModifier and TypeMethodDescriptionCheckpointDurableExecutionResponse.builder()CheckpointDurableExecutionResponse.Builder.checkpointToken(String checkpointToken) A new checkpoint token to use for the next checkpoint operation.CheckpointDurableExecutionResponse.Builder.newExecutionState(Consumer<CheckpointUpdatedExecutionState.Builder> newExecutionState) Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers.CheckpointDurableExecutionResponse.Builder.newExecutionState(CheckpointUpdatedExecutionState newExecutionState) Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers.CheckpointDurableExecutionResponse.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type CheckpointDurableExecutionResponse.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CheckpointDurableExecutionResponse.Builder>CheckpointDurableExecutionResponse.serializableBuilderClass()