Uses of Class
software.amazon.awssdk.services.lambda.model.CheckpointUpdatedExecutionState
Packages that use CheckpointUpdatedExecutionState
-
Uses of CheckpointUpdatedExecutionState in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return CheckpointUpdatedExecutionStateModifier and TypeMethodDescriptionCheckpointDurableExecutionResponse.newExecutionState()Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers.Methods in software.amazon.awssdk.services.lambda.model with parameters of type CheckpointUpdatedExecutionStateModifier and TypeMethodDescriptionCheckpointDurableExecutionResponse.Builder.newExecutionState(CheckpointUpdatedExecutionState newExecutionState) Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers.