Uses of Enum
software.amazon.awssdk.services.lambda.model.CodeSigningPolicy
Packages that use CodeSigningPolicy
-
Uses of CodeSigningPolicy in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return CodeSigningPolicyModifier and TypeMethodDescriptionstatic CodeSigningPolicyUse this in place of valueOf to convert the raw string returned by the service into the enum value.final CodeSigningPolicyCodeSigningPolicies.untrustedArtifactOnDeployment()Code signing configuration policy for deployment validation failure.static CodeSigningPolicyReturns the enum constant of this type with the specified name.static CodeSigningPolicy[]CodeSigningPolicy.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type CodeSigningPolicyMethods in software.amazon.awssdk.services.lambda.model with parameters of type CodeSigningPolicyModifier and TypeMethodDescriptionCodeSigningPolicies.Builder.untrustedArtifactOnDeployment(CodeSigningPolicy untrustedArtifactOnDeployment) Code signing configuration policy for deployment validation failure.