Uses of Interface
software.amazon.awssdk.services.lambda.model.CreateEventSourceMappingResponse.Builder
Packages that use CreateEventSourceMappingResponse.Builder
-
Uses of CreateEventSourceMappingResponse.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return CreateEventSourceMappingResponse.BuilderModifier and TypeMethodDescriptionCreateEventSourceMappingResponse.Builder.amazonManagedKafkaEventSourceConfig(Consumer<AmazonManagedKafkaEventSourceConfig.Builder> amazonManagedKafkaEventSourceConfig) Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.CreateEventSourceMappingResponse.Builder.amazonManagedKafkaEventSourceConfig(AmazonManagedKafkaEventSourceConfig amazonManagedKafkaEventSourceConfig) Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function.CreateEventSourceMappingResponse.Builder.bisectBatchOnFunctionError(Boolean bisectBatchOnFunctionError) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) If the function returns an error, split the batch in two and retry.CreateEventSourceMappingResponse.builder()CreateEventSourceMappingResponse.Builder.destinationConfig(Consumer<DestinationConfig.Builder> destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.CreateEventSourceMappingResponse.Builder.destinationConfig(DestinationConfig destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.CreateEventSourceMappingResponse.Builder.documentDBEventSourceConfig(Consumer<DocumentDBEventSourceConfig.Builder> documentDBEventSourceConfig) Specific configuration settings for a DocumentDB event source.CreateEventSourceMappingResponse.Builder.documentDBEventSourceConfig(DocumentDBEventSourceConfig documentDBEventSourceConfig) Specific configuration settings for a DocumentDB event source.CreateEventSourceMappingResponse.Builder.eventSourceArn(String eventSourceArn) The Amazon Resource Name (ARN) of the event source.CreateEventSourceMappingResponse.Builder.eventSourceMappingArn(String eventSourceMappingArn) The Amazon Resource Name (ARN) of the event source mapping.CreateEventSourceMappingResponse.Builder.filterCriteria(Consumer<FilterCriteria.Builder> filterCriteria) An object that defines the filter criteria that determine whether Lambda should process an event.CreateEventSourceMappingResponse.Builder.filterCriteria(FilterCriteria filterCriteria) An object that defines the filter criteria that determine whether Lambda should process an event.CreateEventSourceMappingResponse.Builder.filterCriteriaError(Consumer<FilterCriteriaError.Builder> filterCriteriaError) An object that contains details about an error related to filter criteria encryption.CreateEventSourceMappingResponse.Builder.filterCriteriaError(FilterCriteriaError filterCriteriaError) An object that contains details about an error related to filter criteria encryption.CreateEventSourceMappingResponse.Builder.functionArn(String functionArn) The ARN of the Lambda function.CreateEventSourceMappingResponse.Builder.functionResponseTypes(Collection<FunctionResponseType> functionResponseTypes) (Kinesis, DynamoDB Streams, Amazon MSK, self-managed Apache Kafka, and Amazon SQS) A list of current response type enums applied to the event source mapping.CreateEventSourceMappingResponse.Builder.functionResponseTypes(FunctionResponseType... functionResponseTypes) (Kinesis, DynamoDB Streams, Amazon MSK, self-managed Apache Kafka, and Amazon SQS) A list of current response type enums applied to the event source mapping.CreateEventSourceMappingResponse.Builder.functionResponseTypesWithStrings(String... functionResponseTypes) (Kinesis, DynamoDB Streams, Amazon MSK, self-managed Apache Kafka, and Amazon SQS) A list of current response type enums applied to the event source mapping.CreateEventSourceMappingResponse.Builder.functionResponseTypesWithStrings(Collection<String> functionResponseTypes) (Kinesis, DynamoDB Streams, Amazon MSK, self-managed Apache Kafka, and Amazon SQS) A list of current response type enums applied to the event source mapping.The ARN of the Key Management Service (KMS) customer managed key that Lambda uses to encrypt your function's filter criteria.CreateEventSourceMappingResponse.Builder.lastModified(Instant lastModified) The date that the event source mapping was last updated or that its state changed.CreateEventSourceMappingResponse.Builder.lastProcessingResult(String lastProcessingResult) The result of the event source mapping's last processing attempt.CreateEventSourceMappingResponse.Builder.loggingConfig(Consumer<EventSourceMappingLoggingConfig.Builder> loggingConfig) (Amazon MSK, and self-managed Apache Kafka only) The logging configuration for your event source.CreateEventSourceMappingResponse.Builder.loggingConfig(EventSourceMappingLoggingConfig loggingConfig) (Amazon MSK, and self-managed Apache Kafka only) The logging configuration for your event source.CreateEventSourceMappingResponse.Builder.maximumBatchingWindowInSeconds(Integer maximumBatchingWindowInSeconds) The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function.CreateEventSourceMappingResponse.Builder.maximumRecordAgeInSeconds(Integer maximumRecordAgeInSeconds) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) Discard records older than the specified age.CreateEventSourceMappingResponse.Builder.maximumRetryAttempts(Integer maximumRetryAttempts) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) Discard records after the specified number of retries.CreateEventSourceMappingResponse.Builder.metricsConfig(Consumer<EventSourceMappingMetricsConfig.Builder> metricsConfig) The metrics configuration for your event source.CreateEventSourceMappingResponse.Builder.metricsConfig(EventSourceMappingMetricsConfig metricsConfig) The metrics configuration for your event source.CreateEventSourceMappingResponse.Builder.parallelizationFactor(Integer parallelizationFactor) (Kinesis and DynamoDB Streams only) The number of batches to process concurrently from each shard.CreateEventSourceMappingResponse.Builder.provisionedPollerConfig(Consumer<ProvisionedPollerConfig.Builder> provisionedPollerConfig) (Amazon SQS, Amazon MSK, and self-managed Apache Kafka only) The provisioned mode configuration for the event source.CreateEventSourceMappingResponse.Builder.provisionedPollerConfig(ProvisionedPollerConfig provisionedPollerConfig) (Amazon SQS, Amazon MSK, and self-managed Apache Kafka only) The provisioned mode configuration for the event source.(Amazon MQ) The name of the Amazon MQ broker destination queue to consume.CreateEventSourceMappingResponse.Builder.queues(Collection<String> queues) (Amazon MQ) The name of the Amazon MQ broker destination queue to consume.CreateEventSourceMappingResponse.Builder.scalingConfig(Consumer<ScalingConfig.Builder> scalingConfig) (Amazon SQS only) The scaling configuration for the event source.CreateEventSourceMappingResponse.Builder.scalingConfig(ScalingConfig scalingConfig) (Amazon SQS only) The scaling configuration for the event source.CreateEventSourceMappingResponse.Builder.selfManagedEventSource(Consumer<SelfManagedEventSource.Builder> selfManagedEventSource) The self-managed Apache Kafka cluster for your event source.CreateEventSourceMappingResponse.Builder.selfManagedEventSource(SelfManagedEventSource selfManagedEventSource) The self-managed Apache Kafka cluster for your event source.CreateEventSourceMappingResponse.Builder.selfManagedKafkaEventSourceConfig(Consumer<SelfManagedKafkaEventSourceConfig.Builder> selfManagedKafkaEventSourceConfig) Specific configuration settings for a self-managed Apache Kafka event source.CreateEventSourceMappingResponse.Builder.selfManagedKafkaEventSourceConfig(SelfManagedKafkaEventSourceConfig selfManagedKafkaEventSourceConfig) Specific configuration settings for a self-managed Apache Kafka event source.CreateEventSourceMappingResponse.Builder.sourceAccessConfigurations(Collection<SourceAccessConfiguration> sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.CreateEventSourceMappingResponse.Builder.sourceAccessConfigurations(Consumer<SourceAccessConfiguration.Builder>... sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.CreateEventSourceMappingResponse.Builder.sourceAccessConfigurations(SourceAccessConfiguration... sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.CreateEventSourceMappingResponse.Builder.startingPosition(String startingPosition) The position in a stream from which to start reading.CreateEventSourceMappingResponse.Builder.startingPosition(EventSourcePosition startingPosition) The position in a stream from which to start reading.CreateEventSourceMappingResponse.Builder.startingPositionTimestamp(Instant startingPositionTimestamp) WithStartingPositionset toAT_TIMESTAMP, the time from which to start reading.The state of the event source mapping.CreateEventSourceMappingResponse.Builder.stateTransitionReason(String stateTransitionReason) Indicates whether a user or Lambda made the last change to the event source mapping.CreateEventSourceMappingResponse.toBuilder()The name of the Kafka topic.CreateEventSourceMappingResponse.Builder.topics(Collection<String> topics) The name of the Kafka topic.CreateEventSourceMappingResponse.Builder.tumblingWindowInSeconds(Integer tumblingWindowInSeconds) (Kinesis and DynamoDB Streams only) The duration in seconds of a processing window for DynamoDB and Kinesis Streams event sources.The identifier of the event source mapping.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type CreateEventSourceMappingResponse.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CreateEventSourceMappingResponse.Builder>CreateEventSourceMappingResponse.serializableBuilderClass()