Uses of Interface
software.amazon.awssdk.services.lambda.model.CreateFunctionRequest.Builder
Packages that use CreateFunctionRequest.Builder
Package
Description
-
Uses of CreateFunctionRequest.Builder in software.amazon.awssdk.services.lambda
Method parameters in software.amazon.awssdk.services.lambda with type arguments of type CreateFunctionRequest.BuilderModifier and TypeMethodDescriptiondefault CompletableFuture<CreateFunctionResponse>LambdaAsyncClient.createFunction(Consumer<CreateFunctionRequest.Builder> createFunctionRequest) Creates a Lambda function.default CreateFunctionResponseLambdaClient.createFunction(Consumer<CreateFunctionRequest.Builder> createFunctionRequest) Creates a Lambda function. -
Uses of CreateFunctionRequest.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return CreateFunctionRequest.BuilderModifier and TypeMethodDescriptionCreateFunctionRequest.Builder.architectures(Collection<Architecture> architectures) The instruction set architecture that the function supports.CreateFunctionRequest.Builder.architectures(Architecture... architectures) The instruction set architecture that the function supports.CreateFunctionRequest.Builder.architecturesWithStrings(String... architectures) The instruction set architecture that the function supports.CreateFunctionRequest.Builder.architecturesWithStrings(Collection<String> architectures) The instruction set architecture that the function supports.CreateFunctionRequest.builder()default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.capacityProviderConfig(Consumer<CapacityProviderConfig.Builder> capacityProviderConfig) Configuration for the capacity provider that manages compute resources for Lambda functions.CreateFunctionRequest.Builder.capacityProviderConfig(CapacityProviderConfig capacityProviderConfig) Configuration for the capacity provider that manages compute resources for Lambda functions.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.code(Consumer<FunctionCode.Builder> code) The code for the function.CreateFunctionRequest.Builder.code(FunctionCode code) The code for the function.CreateFunctionRequest.Builder.codeSigningConfigArn(String codeSigningConfigArn) To enable code signing for this function, specify the ARN of a code-signing configuration.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.deadLetterConfig(Consumer<DeadLetterConfig.Builder> deadLetterConfig) A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing.CreateFunctionRequest.Builder.deadLetterConfig(DeadLetterConfig deadLetterConfig) A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing.CreateFunctionRequest.Builder.description(String description) A description of the function.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.durableConfig(Consumer<DurableConfig.Builder> durableConfig) Configuration settings for durable functions.CreateFunctionRequest.Builder.durableConfig(DurableConfig durableConfig) Configuration settings for durable functions.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.environment(Consumer<Environment.Builder> environment) Environment variables that are accessible from function code during execution.CreateFunctionRequest.Builder.environment(Environment environment) Environment variables that are accessible from function code during execution.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.ephemeralStorage(Consumer<EphemeralStorage.Builder> ephemeralStorage) The size of the function's/tmpdirectory in MB.CreateFunctionRequest.Builder.ephemeralStorage(EphemeralStorage ephemeralStorage) The size of the function's/tmpdirectory in MB.CreateFunctionRequest.Builder.fileSystemConfigs(Collection<FileSystemConfig> fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.CreateFunctionRequest.Builder.fileSystemConfigs(Consumer<FileSystemConfig.Builder>... fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.CreateFunctionRequest.Builder.fileSystemConfigs(FileSystemConfig... fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.CreateFunctionRequest.Builder.functionName(String functionName) The name or ARN of the Lambda function.The name of the method within your code that Lambda calls to run your function.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.imageConfig(Consumer<ImageConfig.Builder> imageConfig) Container image configuration values that override the values in the container image Dockerfile.CreateFunctionRequest.Builder.imageConfig(ImageConfig imageConfig) Container image configuration values that override the values in the container image Dockerfile.The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt the following resources:A list of function layers to add to the function's execution environment.CreateFunctionRequest.Builder.layers(Collection<String> layers) A list of function layers to add to the function's execution environment.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.loggingConfig(Consumer<LoggingConfig.Builder> loggingConfig) The function's Amazon CloudWatch Logs configuration settings.CreateFunctionRequest.Builder.loggingConfig(LoggingConfig loggingConfig) The function's Amazon CloudWatch Logs configuration settings.CreateFunctionRequest.Builder.memorySize(Integer memorySize) The amount of memory available to the function at runtime.CreateFunctionRequest.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) CreateFunctionRequest.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) CreateFunctionRequest.Builder.packageType(String packageType) The type of deployment package.CreateFunctionRequest.Builder.packageType(PackageType packageType) The type of deployment package.Set to true to publish the first version of the function during creation.Specifies where to publish the function version or configuration.CreateFunctionRequest.Builder.publishTo(FunctionVersionLatestPublished publishTo) Specifies where to publish the function version or configuration.The Amazon Resource Name (ARN) of the function's execution role.The identifier of the function's runtime.The identifier of the function's runtime.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.snapStart(Consumer<SnapStart.Builder> snapStart) The function's SnapStart setting.The function's SnapStart setting.A list of tags to apply to the function.default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.tenancyConfig(Consumer<TenancyConfig.Builder> tenancyConfig) Configuration for multi-tenant applications that use Lambda functions.CreateFunctionRequest.Builder.tenancyConfig(TenancyConfig tenancyConfig) Configuration for multi-tenant applications that use Lambda functions.The amount of time (in seconds) that Lambda allows a function to run before stopping it.CreateFunctionRequest.toBuilder()default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.tracingConfig(Consumer<TracingConfig.Builder> tracingConfig) CreateFunctionRequest.Builder.tracingConfig(TracingConfig tracingConfig) default CreateFunctionRequest.BuilderCreateFunctionRequest.Builder.vpcConfig(Consumer<VpcConfig.Builder> vpcConfig) For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC.For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type CreateFunctionRequest.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CreateFunctionRequest.Builder>CreateFunctionRequest.serializableBuilderClass()