Uses of Interface
software.amazon.awssdk.services.lambda.model.CreateFunctionResponse.Builder
Packages that use CreateFunctionResponse.Builder
-
Uses of CreateFunctionResponse.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return CreateFunctionResponse.BuilderModifier and TypeMethodDescriptionCreateFunctionResponse.Builder.architectures(Collection<Architecture> architectures) The instruction set architecture that the function supports.CreateFunctionResponse.Builder.architectures(Architecture... architectures) The instruction set architecture that the function supports.CreateFunctionResponse.Builder.architecturesWithStrings(String... architectures) The instruction set architecture that the function supports.CreateFunctionResponse.Builder.architecturesWithStrings(Collection<String> architectures) The instruction set architecture that the function supports.CreateFunctionResponse.builder()default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.capacityProviderConfig(Consumer<CapacityProviderConfig.Builder> capacityProviderConfig) Configuration for the capacity provider that manages compute resources for Lambda functions.CreateFunctionResponse.Builder.capacityProviderConfig(CapacityProviderConfig capacityProviderConfig) Configuration for the capacity provider that manages compute resources for Lambda functions.CreateFunctionResponse.Builder.codeSha256(String codeSha256) The SHA256 hash of the function's deployment package.The size of the function's deployment package, in bytes.CreateFunctionResponse.Builder.configSha256(String configSha256) The SHA256 hash of the function configuration.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.deadLetterConfig(Consumer<DeadLetterConfig.Builder> deadLetterConfig) The function's dead letter queue.CreateFunctionResponse.Builder.deadLetterConfig(DeadLetterConfig deadLetterConfig) The function's dead letter queue.CreateFunctionResponse.Builder.description(String description) The function's description.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.durableConfig(Consumer<DurableConfig.Builder> durableConfig) The function's durable execution configuration settings, if the function is configured for durability.CreateFunctionResponse.Builder.durableConfig(DurableConfig durableConfig) The function's durable execution configuration settings, if the function is configured for durability.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.environment(Consumer<EnvironmentResponse.Builder> environment) The function's environment variables.CreateFunctionResponse.Builder.environment(EnvironmentResponse environment) The function's environment variables.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.ephemeralStorage(Consumer<EphemeralStorage.Builder> ephemeralStorage) The size of the function's/tmpdirectory in MB.CreateFunctionResponse.Builder.ephemeralStorage(EphemeralStorage ephemeralStorage) The size of the function's/tmpdirectory in MB.CreateFunctionResponse.Builder.fileSystemConfigs(Collection<FileSystemConfig> fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.CreateFunctionResponse.Builder.fileSystemConfigs(Consumer<FileSystemConfig.Builder>... fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.CreateFunctionResponse.Builder.fileSystemConfigs(FileSystemConfig... fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.CreateFunctionResponse.Builder.functionArn(String functionArn) The function's Amazon Resource Name (ARN).CreateFunctionResponse.Builder.functionName(String functionName) The name of the function.The function that Lambda calls to begin running your function.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.imageConfigResponse(Consumer<ImageConfigResponse.Builder> imageConfigResponse) The function's image configuration values.CreateFunctionResponse.Builder.imageConfigResponse(ImageConfigResponse imageConfigResponse) The function's image configuration values.The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt the following resources:CreateFunctionResponse.Builder.lastModified(String lastModified) The date and time that the function was last updated, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).CreateFunctionResponse.Builder.lastUpdateStatus(String lastUpdateStatus) The status of the last update that was performed on the function.CreateFunctionResponse.Builder.lastUpdateStatus(LastUpdateStatus lastUpdateStatus) The status of the last update that was performed on the function.CreateFunctionResponse.Builder.lastUpdateStatusReason(String lastUpdateStatusReason) The reason for the last update that was performed on the function.CreateFunctionResponse.Builder.lastUpdateStatusReasonCode(String lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.CreateFunctionResponse.Builder.lastUpdateStatusReasonCode(LastUpdateStatusReasonCode lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.CreateFunctionResponse.Builder.layers(Collection<Layer> layers) The function's layers.CreateFunctionResponse.Builder.layers(Consumer<Layer.Builder>... layers) The function's layers.The function's layers.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.loggingConfig(Consumer<LoggingConfig.Builder> loggingConfig) The function's Amazon CloudWatch Logs configuration settings.CreateFunctionResponse.Builder.loggingConfig(LoggingConfig loggingConfig) The function's Amazon CloudWatch Logs configuration settings.For Lambda@Edge functions, the ARN of the main function.CreateFunctionResponse.Builder.memorySize(Integer memorySize) The amount of memory available to the function at runtime.CreateFunctionResponse.Builder.packageType(String packageType) The type of deployment package.CreateFunctionResponse.Builder.packageType(PackageType packageType) The type of deployment package.CreateFunctionResponse.Builder.revisionId(String revisionId) The latest updated revision of the function or alias.The function's execution role.The identifier of the function's runtime.The identifier of the function's runtime.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.runtimeVersionConfig(Consumer<RuntimeVersionConfig.Builder> runtimeVersionConfig) The ARN of the runtime and any errors that occured.CreateFunctionResponse.Builder.runtimeVersionConfig(RuntimeVersionConfig runtimeVersionConfig) The ARN of the runtime and any errors that occured.CreateFunctionResponse.Builder.signingJobArn(String signingJobArn) The ARN of the signing job.CreateFunctionResponse.Builder.signingProfileVersionArn(String signingProfileVersionArn) The ARN of the signing profile version.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.snapStart(Consumer<SnapStartResponse.Builder> snapStart) SetApplyOntoPublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.CreateFunctionResponse.Builder.snapStart(SnapStartResponse snapStart) SetApplyOntoPublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.The current state of the function.The current state of the function.CreateFunctionResponse.Builder.stateReason(String stateReason) The reason for the function's current state.CreateFunctionResponse.Builder.stateReasonCode(String stateReasonCode) The reason code for the function's current state.CreateFunctionResponse.Builder.stateReasonCode(StateReasonCode stateReasonCode) The reason code for the function's current state.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.tenancyConfig(Consumer<TenancyConfig.Builder> tenancyConfig) The function's tenant isolation configuration settings.CreateFunctionResponse.Builder.tenancyConfig(TenancyConfig tenancyConfig) The function's tenant isolation configuration settings.The amount of time in seconds that Lambda allows a function to run before stopping it.CreateFunctionResponse.toBuilder()default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.tracingConfig(Consumer<TracingConfigResponse.Builder> tracingConfig) The function's X-Ray tracing configuration.CreateFunctionResponse.Builder.tracingConfig(TracingConfigResponse tracingConfig) The function's X-Ray tracing configuration.The version of the Lambda function.default CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.vpcConfig(Consumer<VpcConfigResponse.Builder> vpcConfig) The function's networking configuration.CreateFunctionResponse.Builder.vpcConfig(VpcConfigResponse vpcConfig) The function's networking configuration.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type CreateFunctionResponse.BuilderModifier and TypeMethodDescriptionstatic Class<? extends CreateFunctionResponse.Builder>CreateFunctionResponse.serializableBuilderClass()