Uses of Class
software.amazon.awssdk.services.lambda.model.DestinationConfig
Packages that use DestinationConfig
-
Uses of DestinationConfig in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return DestinationConfigModifier and TypeMethodDescriptionfinal DestinationConfigCreateEventSourceMappingRequest.destinationConfig()(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.final DestinationConfigCreateEventSourceMappingResponse.destinationConfig()(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.final DestinationConfigDeleteEventSourceMappingResponse.destinationConfig()(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.final DestinationConfigEventSourceMappingConfiguration.destinationConfig()(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.final DestinationConfigFunctionEventInvokeConfig.destinationConfig()A destination for events after they have been sent to a function for processing.final DestinationConfigGetEventSourceMappingResponse.destinationConfig()(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.final DestinationConfigGetFunctionEventInvokeConfigResponse.destinationConfig()A destination for events after they have been sent to a function for processing.final DestinationConfigPutFunctionEventInvokeConfigRequest.destinationConfig()A destination for events after they have been sent to a function for processing.final DestinationConfigPutFunctionEventInvokeConfigResponse.destinationConfig()A destination for events after they have been sent to a function for processing.final DestinationConfigUpdateEventSourceMappingRequest.destinationConfig()(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.final DestinationConfigUpdateEventSourceMappingResponse.destinationConfig()(Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.final DestinationConfigUpdateFunctionEventInvokeConfigRequest.destinationConfig()A destination for events after they have been sent to a function for processing.final DestinationConfigUpdateFunctionEventInvokeConfigResponse.destinationConfig()A destination for events after they have been sent to a function for processing.Methods in software.amazon.awssdk.services.lambda.model with parameters of type DestinationConfigModifier and TypeMethodDescriptionCreateEventSourceMappingRequest.Builder.destinationConfig(DestinationConfig destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.CreateEventSourceMappingResponse.Builder.destinationConfig(DestinationConfig destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.DeleteEventSourceMappingResponse.Builder.destinationConfig(DestinationConfig destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.EventSourceMappingConfiguration.Builder.destinationConfig(DestinationConfig destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.FunctionEventInvokeConfig.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.GetEventSourceMappingResponse.Builder.destinationConfig(DestinationConfig destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.GetFunctionEventInvokeConfigResponse.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.PutFunctionEventInvokeConfigRequest.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.PutFunctionEventInvokeConfigResponse.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.UpdateEventSourceMappingRequest.Builder.destinationConfig(DestinationConfig destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.UpdateEventSourceMappingResponse.Builder.destinationConfig(DestinationConfig destinationConfig) (Kinesis, DynamoDB Streams, Amazon MSK, and self-managed Apache Kafka) A configuration object that specifies the destination of an event after Lambda processes it.UpdateFunctionEventInvokeConfigRequest.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.UpdateFunctionEventInvokeConfigResponse.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.