Uses of Class
software.amazon.awssdk.services.lambda.model.EventError
Packages that use EventError
-
Uses of EventError in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return EventErrorModifier and TypeMethodDescriptionfinal EventErrorCallbackFailedDetails.error()An error object that contains details about the failure.final EventErrorCallbackTimedOutDetails.error()Details about the callback timeout.final EventErrorChainedInvokeFailedDetails.error()Details about the chained invocation failure.final EventErrorChainedInvokeStoppedDetails.error()Details about why the chained invocation stopped.final EventErrorChainedInvokeTimedOutDetails.error()Details about the chained invocation timeout.final EventErrorContextFailedDetails.error()Details about the context failure.final EventErrorExecutionFailedDetails.error()Details about the execution failure.final EventErrorExecutionStoppedDetails.error()Details about why the execution stopped.final EventErrorExecutionTimedOutDetails.error()Details about the execution timeout.final EventErrorInvocationCompletedDetails.error()Details about the invocation failure.final EventErrorStepFailedDetails.error()Details about the step failure.final EventErrorWaitCancelledDetails.error()Details about why the wait operation was cancelled.Methods in software.amazon.awssdk.services.lambda.model with parameters of type EventErrorModifier and TypeMethodDescriptionCallbackFailedDetails.Builder.error(EventError error) An error object that contains details about the failure.CallbackTimedOutDetails.Builder.error(EventError error) Details about the callback timeout.ChainedInvokeFailedDetails.Builder.error(EventError error) Details about the chained invocation failure.ChainedInvokeStoppedDetails.Builder.error(EventError error) Details about why the chained invocation stopped.ChainedInvokeTimedOutDetails.Builder.error(EventError error) Details about the chained invocation timeout.ContextFailedDetails.Builder.error(EventError error) Details about the context failure.ExecutionFailedDetails.Builder.error(EventError error) Details about the execution failure.ExecutionStoppedDetails.Builder.error(EventError error) Details about why the execution stopped.ExecutionTimedOutDetails.Builder.error(EventError error) Details about the execution timeout.InvocationCompletedDetails.Builder.error(EventError error) Details about the invocation failure.StepFailedDetails.Builder.error(EventError error) Details about the step failure.WaitCancelledDetails.Builder.error(EventError error) Details about why the wait operation was cancelled.