Uses of Interface
software.amazon.awssdk.services.lambda.model.EventInput.Builder
Packages that use EventInput.Builder
-
Uses of EventInput.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return EventInput.BuilderModifier and TypeMethodDescriptionstatic EventInput.BuilderEventInput.builder()The input payload.EventInput.toBuilder()Indicates if the error payload was truncated due to size limits.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type EventInput.BuilderModifier and TypeMethodDescriptionstatic Class<? extends EventInput.Builder>EventInput.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type EventInput.BuilderModifier and TypeMethodDescriptionChainedInvokeStartedDetails.Builder.input(Consumer<EventInput.Builder> input) The JSON input payload provided to the chained invocation.default ExecutionStartedDetails.BuilderExecutionStartedDetails.Builder.input(Consumer<EventInput.Builder> input) The input payload provided for the durable execution.