Uses of Class
software.amazon.awssdk.services.lambda.model.EventSourceMappingConfiguration
Packages that use EventSourceMappingConfiguration
Package
Description
-
Uses of EventSourceMappingConfiguration in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type EventSourceMappingConfigurationModifier and TypeMethodDescriptionListEventSourceMappingsResponse.eventSourceMappings()A list of event source mappings.Methods in software.amazon.awssdk.services.lambda.model with parameters of type EventSourceMappingConfigurationModifier and TypeMethodDescriptionListEventSourceMappingsResponse.Builder.eventSourceMappings(EventSourceMappingConfiguration... eventSourceMappings) A list of event source mappings.Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type EventSourceMappingConfigurationModifier and TypeMethodDescriptionListEventSourceMappingsResponse.Builder.eventSourceMappings(Collection<EventSourceMappingConfiguration> eventSourceMappings) A list of event source mappings. -
Uses of EventSourceMappingConfiguration in software.amazon.awssdk.services.lambda.paginators
Methods in software.amazon.awssdk.services.lambda.paginators that return types with arguments of type EventSourceMappingConfigurationModifier and TypeMethodDescriptionListEventSourceMappingsIterable.eventSourceMappings()Returns an iterable to iterate through the paginatedListEventSourceMappingsResponse.eventSourceMappings()member.ListEventSourceMappingsPublisher.eventSourceMappings()Returns a publisher that can be used to get a stream of data.