Uses of Class
software.amazon.awssdk.services.lambda.model.Execution
Packages that use Execution
Package
Description
-
Uses of Execution in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type ExecutionModifier and TypeMethodDescriptionListDurableExecutionsByFunctionResponse.durableExecutions()List of durable execution summaries matching the filter criteria.Methods in software.amazon.awssdk.services.lambda.model with parameters of type ExecutionModifier and TypeMethodDescriptionListDurableExecutionsByFunctionResponse.Builder.durableExecutions(Execution... durableExecutions) List of durable execution summaries matching the filter criteria.Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type ExecutionModifier and TypeMethodDescriptionListDurableExecutionsByFunctionResponse.Builder.durableExecutions(Collection<Execution> durableExecutions) List of durable execution summaries matching the filter criteria. -
Uses of Execution in software.amazon.awssdk.services.lambda.paginators
Methods in software.amazon.awssdk.services.lambda.paginators that return types with arguments of type ExecutionModifier and TypeMethodDescriptionfinal SdkIterable<Execution>ListDurableExecutionsByFunctionIterable.durableExecutions()Returns an iterable to iterate through the paginatedListDurableExecutionsByFunctionResponse.durableExecutions()member.final SdkPublisher<Execution>ListDurableExecutionsByFunctionPublisher.durableExecutions()Returns a publisher that can be used to get a stream of data.