Uses of Enum
software.amazon.awssdk.services.lambda.model.ExecutionStatus
Packages that use ExecutionStatus
-
Uses of ExecutionStatus in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return ExecutionStatusModifier and TypeMethodDescriptionstatic ExecutionStatusUse this in place of valueOf to convert the raw string returned by the service into the enum value.final ExecutionStatusExecution.status()The current status of the durable execution.final ExecutionStatusGetDurableExecutionResponse.status()The current status of the durable execution.static ExecutionStatusReturns the enum constant of this type with the specified name.static ExecutionStatus[]ExecutionStatus.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type ExecutionStatusModifier and TypeMethodDescriptionstatic Set<ExecutionStatus>ExecutionStatus.knownValues()final List<ExecutionStatus>ListDurableExecutionsByFunctionRequest.statuses()Filter executions by status.Methods in software.amazon.awssdk.services.lambda.model with parameters of type ExecutionStatusModifier and TypeMethodDescriptionExecution.Builder.status(ExecutionStatus status) The current status of the durable execution.GetDurableExecutionResponse.Builder.status(ExecutionStatus status) The current status of the durable execution.ListDurableExecutionsByFunctionRequest.Builder.statuses(ExecutionStatus... statuses) Filter executions by status.Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type ExecutionStatusModifier and TypeMethodDescriptionListDurableExecutionsByFunctionRequest.Builder.statuses(Collection<ExecutionStatus> statuses) Filter executions by status.