Uses of Interface
software.amazon.awssdk.services.lambda.model.FileSystemConfig.Builder
Packages that use FileSystemConfig.Builder
-
Uses of FileSystemConfig.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return FileSystemConfig.BuilderModifier and TypeMethodDescriptionThe Amazon Resource Name (ARN) of the Amazon EFS or Amazon S3 Files access point that provides access to the file system.static FileSystemConfig.BuilderFileSystemConfig.builder()FileSystemConfig.Builder.localMountPath(String localMountPath) The path where the function can access the file system, starting with/mnt/.FileSystemConfig.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type FileSystemConfig.BuilderModifier and TypeMethodDescriptionstatic Class<? extends FileSystemConfig.Builder>FileSystemConfig.serializableBuilderClass()