Uses of Enum
software.amazon.awssdk.services.lambda.model.FullDocument
Packages that use FullDocument
-
Uses of FullDocument in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return FullDocumentModifier and TypeMethodDescriptionstatic FullDocumentUse this in place of valueOf to convert the raw string returned by the service into the enum value.final FullDocumentDocumentDBEventSourceConfig.fullDocument()Determines what DocumentDB sends to your event stream during document update operations.static FullDocumentReturns the enum constant of this type with the specified name.static FullDocument[]FullDocument.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type FullDocumentMethods in software.amazon.awssdk.services.lambda.model with parameters of type FullDocumentModifier and TypeMethodDescriptionDocumentDBEventSourceConfig.Builder.fullDocument(FullDocument fullDocument) Determines what DocumentDB sends to your event stream during document update operations.