Uses of Interface
software.amazon.awssdk.services.lambda.model.FunctionCodeLocation.Builder
Packages that use FunctionCodeLocation.Builder
-
Uses of FunctionCodeLocation.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return FunctionCodeLocation.BuilderModifier and TypeMethodDescriptionstatic FunctionCodeLocation.BuilderFunctionCodeLocation.builder()URI of a container image in the Amazon ECR registry.A presigned URL that you can use to download the deployment package.FunctionCodeLocation.Builder.repositoryType(String repositoryType) The service that's hosting the file.FunctionCodeLocation.Builder.resolvedImageUri(String resolvedImageUri) The resolved URI for the image.FunctionCodeLocation.Builder.sourceKMSKeyArn(String sourceKMSKeyArn) The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package.FunctionCodeLocation.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type FunctionCodeLocation.BuilderModifier and TypeMethodDescriptionstatic Class<? extends FunctionCodeLocation.Builder>FunctionCodeLocation.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type FunctionCodeLocation.BuilderModifier and TypeMethodDescriptiondefault GetFunctionResponse.BuilderGetFunctionResponse.Builder.code(Consumer<FunctionCodeLocation.Builder> code) The deployment package of the function or version.