Uses of Interface
software.amazon.awssdk.services.lambda.model.FunctionEventInvokeConfig.Builder
Packages that use FunctionEventInvokeConfig.Builder
-
Uses of FunctionEventInvokeConfig.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return FunctionEventInvokeConfig.BuilderModifier and TypeMethodDescriptionFunctionEventInvokeConfig.builder()FunctionEventInvokeConfig.Builder.destinationConfig(Consumer<DestinationConfig.Builder> destinationConfig) A destination for events after they have been sent to a function for processing.FunctionEventInvokeConfig.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.FunctionEventInvokeConfig.Builder.functionArn(String functionArn) The Amazon Resource Name (ARN) of the function.FunctionEventInvokeConfig.Builder.lastModified(Instant lastModified) The date and time that the configuration was last updated.FunctionEventInvokeConfig.Builder.maximumEventAgeInSeconds(Integer maximumEventAgeInSeconds) The maximum age of a request that Lambda sends to a function for processing.FunctionEventInvokeConfig.Builder.maximumRetryAttempts(Integer maximumRetryAttempts) The maximum number of times to retry when the function returns an error.FunctionEventInvokeConfig.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type FunctionEventInvokeConfig.BuilderModifier and TypeMethodDescriptionstatic Class<? extends FunctionEventInvokeConfig.Builder>FunctionEventInvokeConfig.serializableBuilderClass()