Uses of Interface
software.amazon.awssdk.services.lambda.model.GetFunctionScalingConfigResponse.Builder
Packages that use GetFunctionScalingConfigResponse.Builder
-
Uses of GetFunctionScalingConfigResponse.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return GetFunctionScalingConfigResponse.BuilderModifier and TypeMethodDescriptionGetFunctionScalingConfigResponse.Builder.appliedFunctionScalingConfig(Consumer<FunctionScalingConfig.Builder> appliedFunctionScalingConfig) The scaling configuration that is currently applied to the function.GetFunctionScalingConfigResponse.Builder.appliedFunctionScalingConfig(FunctionScalingConfig appliedFunctionScalingConfig) The scaling configuration that is currently applied to the function.GetFunctionScalingConfigResponse.builder()GetFunctionScalingConfigResponse.Builder.functionArn(String functionArn) The Amazon Resource Name (ARN) of the function.GetFunctionScalingConfigResponse.Builder.requestedFunctionScalingConfig(Consumer<FunctionScalingConfig.Builder> requestedFunctionScalingConfig) The scaling configuration that was requested for the function.GetFunctionScalingConfigResponse.Builder.requestedFunctionScalingConfig(FunctionScalingConfig requestedFunctionScalingConfig) The scaling configuration that was requested for the function.GetFunctionScalingConfigResponse.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type GetFunctionScalingConfigResponse.BuilderModifier and TypeMethodDescriptionstatic Class<? extends GetFunctionScalingConfigResponse.Builder>GetFunctionScalingConfigResponse.serializableBuilderClass()