Uses of Class
software.amazon.awssdk.services.lambda.model.ImageConfig
Packages that use ImageConfig
-
Uses of ImageConfig in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return ImageConfigModifier and TypeMethodDescriptionfinal ImageConfigCreateFunctionRequest.imageConfig()Container image configuration values that override the values in the container image Dockerfile.final ImageConfigImageConfigResponse.imageConfig()Configuration values that override the container image Dockerfile.final ImageConfigUpdateFunctionConfigurationRequest.imageConfig()Container image configuration values that override the values in the container image Docker file.Methods in software.amazon.awssdk.services.lambda.model with parameters of type ImageConfigModifier and TypeMethodDescriptionCreateFunctionRequest.Builder.imageConfig(ImageConfig imageConfig) Container image configuration values that override the values in the container image Dockerfile.ImageConfigResponse.Builder.imageConfig(ImageConfig imageConfig) Configuration values that override the container image Dockerfile.UpdateFunctionConfigurationRequest.Builder.imageConfig(ImageConfig imageConfig) Container image configuration values that override the values in the container image Docker file.