Uses of Interface
software.amazon.awssdk.services.lambda.model.InvalidSubnetIdException.Builder
Packages that use InvalidSubnetIdException.Builder
-
Uses of InvalidSubnetIdException.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return InvalidSubnetIdException.BuilderModifier and TypeMethodDescriptionInvalidSubnetIdException.Builder.awsErrorDetails(AwsErrorDetails awsErrorDetails) InvalidSubnetIdException.builder()InvalidSubnetIdException.Builder.numAttempts(Integer numAttempts) InvalidSubnetIdException.Builder.statusCode(int statusCode) InvalidSubnetIdException.toBuilder()Sets the value of the Type property for this object.InvalidSubnetIdException.Builder.writableStackTrace(Boolean writableStackTrace) Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type InvalidSubnetIdException.BuilderModifier and TypeMethodDescriptionstatic Class<? extends InvalidSubnetIdException.Builder>InvalidSubnetIdException.serializableBuilderClass()