Uses of Interface
software.amazon.awssdk.services.lambda.model.KmsNotFoundException.Builder
Packages that use KmsNotFoundException.Builder
-
Uses of KmsNotFoundException.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return KmsNotFoundException.BuilderModifier and TypeMethodDescriptionKmsNotFoundException.Builder.awsErrorDetails(AwsErrorDetails awsErrorDetails) static KmsNotFoundException.BuilderKmsNotFoundException.builder()KmsNotFoundException.Builder.numAttempts(Integer numAttempts) KmsNotFoundException.Builder.statusCode(int statusCode) KmsNotFoundException.toBuilder()Sets the value of the Type property for this object.KmsNotFoundException.Builder.writableStackTrace(Boolean writableStackTrace) Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type KmsNotFoundException.BuilderModifier and TypeMethodDescriptionstatic Class<? extends KmsNotFoundException.Builder>KmsNotFoundException.serializableBuilderClass()