Uses of Enum
software.amazon.awssdk.services.lambda.model.LastUpdateStatus
Packages that use LastUpdateStatus
-
Uses of LastUpdateStatus in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return LastUpdateStatusModifier and TypeMethodDescriptionstatic LastUpdateStatusUse this in place of valueOf to convert the raw string returned by the service into the enum value.final LastUpdateStatusCreateFunctionResponse.lastUpdateStatus()The status of the last update that was performed on the function.final LastUpdateStatusFunctionConfiguration.lastUpdateStatus()The status of the last update that was performed on the function.final LastUpdateStatusGetFunctionConfigurationResponse.lastUpdateStatus()The status of the last update that was performed on the function.final LastUpdateStatusPublishVersionResponse.lastUpdateStatus()The status of the last update that was performed on the function.final LastUpdateStatusUpdateFunctionCodeResponse.lastUpdateStatus()The status of the last update that was performed on the function.final LastUpdateStatusUpdateFunctionConfigurationResponse.lastUpdateStatus()The status of the last update that was performed on the function.static LastUpdateStatusReturns the enum constant of this type with the specified name.static LastUpdateStatus[]LastUpdateStatus.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type LastUpdateStatusMethods in software.amazon.awssdk.services.lambda.model with parameters of type LastUpdateStatusModifier and TypeMethodDescriptionCreateFunctionResponse.Builder.lastUpdateStatus(LastUpdateStatus lastUpdateStatus) The status of the last update that was performed on the function.FunctionConfiguration.Builder.lastUpdateStatus(LastUpdateStatus lastUpdateStatus) The status of the last update that was performed on the function.GetFunctionConfigurationResponse.Builder.lastUpdateStatus(LastUpdateStatus lastUpdateStatus) The status of the last update that was performed on the function.PublishVersionResponse.Builder.lastUpdateStatus(LastUpdateStatus lastUpdateStatus) The status of the last update that was performed on the function.UpdateFunctionCodeResponse.Builder.lastUpdateStatus(LastUpdateStatus lastUpdateStatus) The status of the last update that was performed on the function.UpdateFunctionConfigurationResponse.Builder.lastUpdateStatus(LastUpdateStatus lastUpdateStatus) The status of the last update that was performed on the function.