Uses of Enum
software.amazon.awssdk.services.lambda.model.LastUpdateStatusReasonCode
Packages that use LastUpdateStatusReasonCode
-
Uses of LastUpdateStatusReasonCode in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return LastUpdateStatusReasonCodeModifier and TypeMethodDescriptionstatic LastUpdateStatusReasonCodeUse this in place of valueOf to convert the raw string returned by the service into the enum value.CreateFunctionResponse.lastUpdateStatusReasonCode()The reason code for the last update that was performed on the function.FunctionConfiguration.lastUpdateStatusReasonCode()The reason code for the last update that was performed on the function.GetFunctionConfigurationResponse.lastUpdateStatusReasonCode()The reason code for the last update that was performed on the function.PublishVersionResponse.lastUpdateStatusReasonCode()The reason code for the last update that was performed on the function.UpdateFunctionCodeResponse.lastUpdateStatusReasonCode()The reason code for the last update that was performed on the function.UpdateFunctionConfigurationResponse.lastUpdateStatusReasonCode()The reason code for the last update that was performed on the function.static LastUpdateStatusReasonCodeReturns the enum constant of this type with the specified name.static LastUpdateStatusReasonCode[]LastUpdateStatusReasonCode.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type LastUpdateStatusReasonCodeModifier and TypeMethodDescriptionstatic Set<LastUpdateStatusReasonCode>LastUpdateStatusReasonCode.knownValues()Methods in software.amazon.awssdk.services.lambda.model with parameters of type LastUpdateStatusReasonCodeModifier and TypeMethodDescriptionCreateFunctionResponse.Builder.lastUpdateStatusReasonCode(LastUpdateStatusReasonCode lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.FunctionConfiguration.Builder.lastUpdateStatusReasonCode(LastUpdateStatusReasonCode lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.GetFunctionConfigurationResponse.Builder.lastUpdateStatusReasonCode(LastUpdateStatusReasonCode lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.PublishVersionResponse.Builder.lastUpdateStatusReasonCode(LastUpdateStatusReasonCode lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.UpdateFunctionCodeResponse.Builder.lastUpdateStatusReasonCode(LastUpdateStatusReasonCode lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.UpdateFunctionConfigurationResponse.Builder.lastUpdateStatusReasonCode(LastUpdateStatusReasonCode lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.