Uses of Interface
software.amazon.awssdk.services.lambda.model.LayerVersionContentInput.Builder
Packages that use LayerVersionContentInput.Builder
-
Uses of LayerVersionContentInput.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return LayerVersionContentInput.BuilderModifier and TypeMethodDescriptionLayerVersionContentInput.builder()The Amazon S3 bucket of the layer archive.The Amazon S3 key of the layer archive.LayerVersionContentInput.Builder.s3ObjectStorageMode(String s3ObjectStorageMode) Sets the value of the S3ObjectStorageMode property for this object.LayerVersionContentInput.Builder.s3ObjectStorageMode(S3ObjectStorageMode s3ObjectStorageMode) Sets the value of the S3ObjectStorageMode property for this object.LayerVersionContentInput.Builder.s3ObjectVersion(String s3ObjectVersion) For versioned objects, the version of the layer archive object to use.LayerVersionContentInput.toBuilder()The base64-encoded contents of the layer archive.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type LayerVersionContentInput.BuilderModifier and TypeMethodDescriptionstatic Class<? extends LayerVersionContentInput.Builder>LayerVersionContentInput.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type LayerVersionContentInput.BuilderModifier and TypeMethodDescriptionPublishLayerVersionRequest.Builder.content(Consumer<LayerVersionContentInput.Builder> content) The function layer archive.