Uses of Class
software.amazon.awssdk.services.lambda.model.ListFunctionUrlConfigsResponse
Packages that use ListFunctionUrlConfigsResponse
Package
Description
-
Uses of ListFunctionUrlConfigsResponse in software.amazon.awssdk.services.lambda
Methods in software.amazon.awssdk.services.lambda that return ListFunctionUrlConfigsResponseModifier and TypeMethodDescriptiondefault ListFunctionUrlConfigsResponseLambdaClient.listFunctionUrlConfigs(Consumer<ListFunctionUrlConfigsRequest.Builder> listFunctionUrlConfigsRequest) Returns a list of Lambda function URLs for the specified function.default ListFunctionUrlConfigsResponseLambdaClient.listFunctionUrlConfigs(ListFunctionUrlConfigsRequest listFunctionUrlConfigsRequest) Returns a list of Lambda function URLs for the specified function.Methods in software.amazon.awssdk.services.lambda that return types with arguments of type ListFunctionUrlConfigsResponseModifier and TypeMethodDescriptionLambdaAsyncClient.listFunctionUrlConfigs(Consumer<ListFunctionUrlConfigsRequest.Builder> listFunctionUrlConfigsRequest) Returns a list of Lambda function URLs for the specified function.LambdaAsyncClient.listFunctionUrlConfigs(ListFunctionUrlConfigsRequest listFunctionUrlConfigsRequest) Returns a list of Lambda function URLs for the specified function. -
Uses of ListFunctionUrlConfigsResponse in software.amazon.awssdk.services.lambda.paginators
Methods in software.amazon.awssdk.services.lambda.paginators that return types with arguments of type ListFunctionUrlConfigsResponseMethod parameters in software.amazon.awssdk.services.lambda.paginators with type arguments of type ListFunctionUrlConfigsResponseModifier and TypeMethodDescriptionvoidListFunctionUrlConfigsPublisher.subscribe(org.reactivestreams.Subscriber<? super ListFunctionUrlConfigsResponse> subscriber)