Uses of Enum
software.amazon.awssdk.services.lambda.model.OperationStatus
Packages that use OperationStatus
-
Uses of OperationStatus in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return OperationStatusModifier and TypeMethodDescriptionstatic OperationStatusUse this in place of valueOf to convert the raw string returned by the service into the enum value.final OperationStatusOperation.status()The current status of the operation.static OperationStatusReturns the enum constant of this type with the specified name.static OperationStatus[]OperationStatus.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type OperationStatusMethods in software.amazon.awssdk.services.lambda.model with parameters of type OperationStatusModifier and TypeMethodDescriptionOperation.Builder.status(OperationStatus status) The current status of the operation.