Uses of Enum
software.amazon.awssdk.services.lambda.model.ProvisionedConcurrencyStatusEnum
Packages that use ProvisionedConcurrencyStatusEnum
-
Uses of ProvisionedConcurrencyStatusEnum in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return ProvisionedConcurrencyStatusEnumModifier and TypeMethodDescriptionUse this in place of valueOf to convert the raw string returned by the service into the enum value.GetProvisionedConcurrencyConfigResponse.status()The status of the allocation process.ProvisionedConcurrencyConfigListItem.status()The status of the allocation process.PutProvisionedConcurrencyConfigResponse.status()The status of the allocation process.Returns the enum constant of this type with the specified name.static ProvisionedConcurrencyStatusEnum[]ProvisionedConcurrencyStatusEnum.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type ProvisionedConcurrencyStatusEnumModifier and TypeMethodDescriptionstatic Set<ProvisionedConcurrencyStatusEnum>ProvisionedConcurrencyStatusEnum.knownValues()Methods in software.amazon.awssdk.services.lambda.model with parameters of type ProvisionedConcurrencyStatusEnumModifier and TypeMethodDescriptionGetProvisionedConcurrencyConfigResponse.Builder.status(ProvisionedConcurrencyStatusEnum status) The status of the allocation process.ProvisionedConcurrencyConfigListItem.Builder.status(ProvisionedConcurrencyStatusEnum status) The status of the allocation process.PutProvisionedConcurrencyConfigResponse.Builder.status(ProvisionedConcurrencyStatusEnum status) The status of the allocation process.