Uses of Class
software.amazon.awssdk.services.lambda.model.PutFunctionConcurrencyResponse
Packages that use PutFunctionConcurrencyResponse
-
Uses of PutFunctionConcurrencyResponse in software.amazon.awssdk.services.lambda
Methods in software.amazon.awssdk.services.lambda that return PutFunctionConcurrencyResponseModifier and TypeMethodDescriptiondefault PutFunctionConcurrencyResponseLambdaClient.putFunctionConcurrency(Consumer<PutFunctionConcurrencyRequest.Builder> putFunctionConcurrencyRequest) Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level.default PutFunctionConcurrencyResponseLambdaClient.putFunctionConcurrency(PutFunctionConcurrencyRequest putFunctionConcurrencyRequest) Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level.Methods in software.amazon.awssdk.services.lambda that return types with arguments of type PutFunctionConcurrencyResponseModifier and TypeMethodDescriptionLambdaAsyncClient.putFunctionConcurrency(Consumer<PutFunctionConcurrencyRequest.Builder> putFunctionConcurrencyRequest) Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level.LambdaAsyncClient.putFunctionConcurrency(PutFunctionConcurrencyRequest putFunctionConcurrencyRequest) Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level.