Uses of Interface
software.amazon.awssdk.services.lambda.model.PutFunctionEventInvokeConfigRequest.Builder
Packages that use PutFunctionEventInvokeConfigRequest.Builder
Package
Description
-
Uses of PutFunctionEventInvokeConfigRequest.Builder in software.amazon.awssdk.services.lambda
Method parameters in software.amazon.awssdk.services.lambda with type arguments of type PutFunctionEventInvokeConfigRequest.BuilderModifier and TypeMethodDescriptionLambdaAsyncClient.putFunctionEventInvokeConfig(Consumer<PutFunctionEventInvokeConfigRequest.Builder> putFunctionEventInvokeConfigRequest) Configures options for asynchronous invocation on a function, version, or alias.LambdaClient.putFunctionEventInvokeConfig(Consumer<PutFunctionEventInvokeConfigRequest.Builder> putFunctionEventInvokeConfigRequest) Configures options for asynchronous invocation on a function, version, or alias. -
Uses of PutFunctionEventInvokeConfigRequest.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return PutFunctionEventInvokeConfigRequest.BuilderModifier and TypeMethodDescriptionPutFunctionEventInvokeConfigRequest.builder()PutFunctionEventInvokeConfigRequest.Builder.destinationConfig(Consumer<DestinationConfig.Builder> destinationConfig) A destination for events after they have been sent to a function for processing.PutFunctionEventInvokeConfigRequest.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.PutFunctionEventInvokeConfigRequest.Builder.functionName(String functionName) The name or ARN of the Lambda function, version, or alias.PutFunctionEventInvokeConfigRequest.Builder.maximumEventAgeInSeconds(Integer maximumEventAgeInSeconds) The maximum age of a request that Lambda sends to a function for processing.PutFunctionEventInvokeConfigRequest.Builder.maximumRetryAttempts(Integer maximumRetryAttempts) The maximum number of times to retry when the function returns an error.PutFunctionEventInvokeConfigRequest.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) PutFunctionEventInvokeConfigRequest.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) A version number or alias name.PutFunctionEventInvokeConfigRequest.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type PutFunctionEventInvokeConfigRequest.BuilderModifier and TypeMethodDescriptionstatic Class<? extends PutFunctionEventInvokeConfigRequest.Builder>PutFunctionEventInvokeConfigRequest.serializableBuilderClass()