Uses of Class
software.amazon.awssdk.services.lambda.model.PutFunctionScalingConfigResponse
Packages that use PutFunctionScalingConfigResponse
-
Uses of PutFunctionScalingConfigResponse in software.amazon.awssdk.services.lambda
Methods in software.amazon.awssdk.services.lambda that return PutFunctionScalingConfigResponseModifier and TypeMethodDescriptiondefault PutFunctionScalingConfigResponseLambdaClient.putFunctionScalingConfig(Consumer<PutFunctionScalingConfigRequest.Builder> putFunctionScalingConfigRequest) Sets the scaling configuration for a Lambda Managed Instances function.default PutFunctionScalingConfigResponseLambdaClient.putFunctionScalingConfig(PutFunctionScalingConfigRequest putFunctionScalingConfigRequest) Sets the scaling configuration for a Lambda Managed Instances function.Methods in software.amazon.awssdk.services.lambda that return types with arguments of type PutFunctionScalingConfigResponseModifier and TypeMethodDescriptionLambdaAsyncClient.putFunctionScalingConfig(Consumer<PutFunctionScalingConfigRequest.Builder> putFunctionScalingConfigRequest) Sets the scaling configuration for a Lambda Managed Instances function.LambdaAsyncClient.putFunctionScalingConfig(PutFunctionScalingConfigRequest putFunctionScalingConfigRequest) Sets the scaling configuration for a Lambda Managed Instances function.