Uses of Interface
software.amazon.awssdk.services.lambda.model.RuntimeVersionConfig.Builder
Packages that use RuntimeVersionConfig.Builder
-
Uses of RuntimeVersionConfig.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return RuntimeVersionConfig.BuilderModifier and TypeMethodDescriptionstatic RuntimeVersionConfig.BuilderRuntimeVersionConfig.builder()default RuntimeVersionConfig.BuilderRuntimeVersionConfig.Builder.error(Consumer<RuntimeVersionError.Builder> error) Error response when Lambda is unable to retrieve the runtime version for a function.RuntimeVersionConfig.Builder.error(RuntimeVersionError error) Error response when Lambda is unable to retrieve the runtime version for a function.RuntimeVersionConfig.Builder.runtimeVersionArn(String runtimeVersionArn) The ARN of the runtime version you want the function to use.RuntimeVersionConfig.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type RuntimeVersionConfig.BuilderModifier and TypeMethodDescriptionstatic Class<? extends RuntimeVersionConfig.Builder>RuntimeVersionConfig.serializableBuilderClass()Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type RuntimeVersionConfig.BuilderModifier and TypeMethodDescriptiondefault CreateFunctionResponse.BuilderCreateFunctionResponse.Builder.runtimeVersionConfig(Consumer<RuntimeVersionConfig.Builder> runtimeVersionConfig) The ARN of the runtime and any errors that occured.default FunctionConfiguration.BuilderFunctionConfiguration.Builder.runtimeVersionConfig(Consumer<RuntimeVersionConfig.Builder> runtimeVersionConfig) The ARN of the runtime and any errors that occured.GetFunctionConfigurationResponse.Builder.runtimeVersionConfig(Consumer<RuntimeVersionConfig.Builder> runtimeVersionConfig) The ARN of the runtime and any errors that occured.default PublishVersionResponse.BuilderPublishVersionResponse.Builder.runtimeVersionConfig(Consumer<RuntimeVersionConfig.Builder> runtimeVersionConfig) The ARN of the runtime and any errors that occured.UpdateFunctionCodeResponse.Builder.runtimeVersionConfig(Consumer<RuntimeVersionConfig.Builder> runtimeVersionConfig) The ARN of the runtime and any errors that occured.UpdateFunctionConfigurationResponse.Builder.runtimeVersionConfig(Consumer<RuntimeVersionConfig.Builder> runtimeVersionConfig) The ARN of the runtime and any errors that occured.