Uses of Class
software.amazon.awssdk.services.lambda.model.RuntimeVersionError
Packages that use RuntimeVersionError
-
Uses of RuntimeVersionError in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return RuntimeVersionErrorModifier and TypeMethodDescriptionfinal RuntimeVersionErrorRuntimeVersionConfig.error()Error response when Lambda is unable to retrieve the runtime version for a function.Methods in software.amazon.awssdk.services.lambda.model with parameters of type RuntimeVersionErrorModifier and TypeMethodDescriptionRuntimeVersionConfig.Builder.error(RuntimeVersionError error) Error response when Lambda is unable to retrieve the runtime version for a function.