Uses of Enum
software.amazon.awssdk.services.lambda.model.SnapStartApplyOn
Packages that use SnapStartApplyOn
-
Uses of SnapStartApplyOn in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return SnapStartApplyOnModifier and TypeMethodDescriptionfinal SnapStartApplyOnSnapStart.applyOn()Set toPublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.final SnapStartApplyOnSnapStartResponse.applyOn()When set toPublishedVersions, Lambda creates a snapshot of the execution environment when you publish a function version.static SnapStartApplyOnUse this in place of valueOf to convert the raw string returned by the service into the enum value.static SnapStartApplyOnReturns the enum constant of this type with the specified name.static SnapStartApplyOn[]SnapStartApplyOn.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type SnapStartApplyOnMethods in software.amazon.awssdk.services.lambda.model with parameters of type SnapStartApplyOnModifier and TypeMethodDescriptionSnapStart.Builder.applyOn(SnapStartApplyOn applyOn) Set toPublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.SnapStartResponse.Builder.applyOn(SnapStartApplyOn applyOn) When set toPublishedVersions, Lambda creates a snapshot of the execution environment when you publish a function version.