Uses of Interface
software.amazon.awssdk.services.lambda.model.SnapStartException.Builder
Packages that use SnapStartException.Builder
-
Uses of SnapStartException.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return SnapStartException.BuilderModifier and TypeMethodDescriptionSnapStartException.Builder.awsErrorDetails(AwsErrorDetails awsErrorDetails) static SnapStartException.BuilderSnapStartException.builder()SnapStartException.Builder.numAttempts(Integer numAttempts) SnapStartException.Builder.statusCode(int statusCode) SnapStartException.toBuilder()Sets the value of the Type property for this object.SnapStartException.Builder.writableStackTrace(Boolean writableStackTrace) Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type SnapStartException.BuilderModifier and TypeMethodDescriptionstatic Class<? extends SnapStartException.Builder>SnapStartException.serializableBuilderClass()