Uses of Class
software.amazon.awssdk.services.lambda.model.SourceAccessConfiguration
Packages that use SourceAccessConfiguration
-
Uses of SourceAccessConfiguration in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type SourceAccessConfigurationModifier and TypeMethodDescriptionfinal List<SourceAccessConfiguration>CreateEventSourceMappingRequest.sourceAccessConfigurations()An array of authentication protocols or VPC components required to secure your event source.final List<SourceAccessConfiguration>CreateEventSourceMappingResponse.sourceAccessConfigurations()An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.final List<SourceAccessConfiguration>DeleteEventSourceMappingResponse.sourceAccessConfigurations()An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.final List<SourceAccessConfiguration>EventSourceMappingConfiguration.sourceAccessConfigurations()An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.final List<SourceAccessConfiguration>GetEventSourceMappingResponse.sourceAccessConfigurations()An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.final List<SourceAccessConfiguration>UpdateEventSourceMappingRequest.sourceAccessConfigurations()An array of authentication protocols or VPC components required to secure your event source.final List<SourceAccessConfiguration>UpdateEventSourceMappingResponse.sourceAccessConfigurations()An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.Methods in software.amazon.awssdk.services.lambda.model with parameters of type SourceAccessConfigurationModifier and TypeMethodDescriptionCreateEventSourceMappingRequest.Builder.sourceAccessConfigurations(SourceAccessConfiguration... sourceAccessConfigurations) An array of authentication protocols or VPC components required to secure your event source.CreateEventSourceMappingResponse.Builder.sourceAccessConfigurations(SourceAccessConfiguration... sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.DeleteEventSourceMappingResponse.Builder.sourceAccessConfigurations(SourceAccessConfiguration... sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.EventSourceMappingConfiguration.Builder.sourceAccessConfigurations(SourceAccessConfiguration... sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.GetEventSourceMappingResponse.Builder.sourceAccessConfigurations(SourceAccessConfiguration... sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.UpdateEventSourceMappingRequest.Builder.sourceAccessConfigurations(SourceAccessConfiguration... sourceAccessConfigurations) An array of authentication protocols or VPC components required to secure your event source.UpdateEventSourceMappingResponse.Builder.sourceAccessConfigurations(SourceAccessConfiguration... sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.Method parameters in software.amazon.awssdk.services.lambda.model with type arguments of type SourceAccessConfigurationModifier and TypeMethodDescriptionCreateEventSourceMappingRequest.Builder.sourceAccessConfigurations(Collection<SourceAccessConfiguration> sourceAccessConfigurations) An array of authentication protocols or VPC components required to secure your event source.CreateEventSourceMappingResponse.Builder.sourceAccessConfigurations(Collection<SourceAccessConfiguration> sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.DeleteEventSourceMappingResponse.Builder.sourceAccessConfigurations(Collection<SourceAccessConfiguration> sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.EventSourceMappingConfiguration.Builder.sourceAccessConfigurations(Collection<SourceAccessConfiguration> sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.GetEventSourceMappingResponse.Builder.sourceAccessConfigurations(Collection<SourceAccessConfiguration> sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.UpdateEventSourceMappingRequest.Builder.sourceAccessConfigurations(Collection<SourceAccessConfiguration> sourceAccessConfigurations) An array of authentication protocols or VPC components required to secure your event source.UpdateEventSourceMappingResponse.Builder.sourceAccessConfigurations(Collection<SourceAccessConfiguration> sourceAccessConfigurations) An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.