Uses of Enum
software.amazon.awssdk.services.lambda.model.StateReasonCode
Packages that use StateReasonCode
-
Uses of StateReasonCode in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return StateReasonCodeModifier and TypeMethodDescriptionstatic StateReasonCodeUse this in place of valueOf to convert the raw string returned by the service into the enum value.final StateReasonCodeCreateFunctionResponse.stateReasonCode()The reason code for the function's current state.final StateReasonCodeFunctionConfiguration.stateReasonCode()The reason code for the function's current state.final StateReasonCodeGetFunctionConfigurationResponse.stateReasonCode()The reason code for the function's current state.final StateReasonCodePublishVersionResponse.stateReasonCode()The reason code for the function's current state.final StateReasonCodeUpdateFunctionCodeResponse.stateReasonCode()The reason code for the function's current state.final StateReasonCodeUpdateFunctionConfigurationResponse.stateReasonCode()The reason code for the function's current state.static StateReasonCodeReturns the enum constant of this type with the specified name.static StateReasonCode[]StateReasonCode.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type StateReasonCodeMethods in software.amazon.awssdk.services.lambda.model with parameters of type StateReasonCodeModifier and TypeMethodDescriptionCreateFunctionResponse.Builder.stateReasonCode(StateReasonCode stateReasonCode) The reason code for the function's current state.FunctionConfiguration.Builder.stateReasonCode(StateReasonCode stateReasonCode) The reason code for the function's current state.GetFunctionConfigurationResponse.Builder.stateReasonCode(StateReasonCode stateReasonCode) The reason code for the function's current state.PublishVersionResponse.Builder.stateReasonCode(StateReasonCode stateReasonCode) The reason code for the function's current state.UpdateFunctionCodeResponse.Builder.stateReasonCode(StateReasonCode stateReasonCode) The reason code for the function's current state.UpdateFunctionConfigurationResponse.Builder.stateReasonCode(StateReasonCode stateReasonCode) The reason code for the function's current state.