Uses of Enum
software.amazon.awssdk.services.lambda.model.ThrottleReason
Packages that use ThrottleReason
-
Uses of ThrottleReason in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return ThrottleReasonModifier and TypeMethodDescriptionstatic ThrottleReasonUse this in place of valueOf to convert the raw string returned by the service into the enum value.TooManyRequestsException.reason()Returns the value of the Reason property for this object.static ThrottleReasonReturns the enum constant of this type with the specified name.static ThrottleReason[]ThrottleReason.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type ThrottleReasonMethods in software.amazon.awssdk.services.lambda.model with parameters of type ThrottleReasonModifier and TypeMethodDescriptionTooManyRequestsException.Builder.reason(ThrottleReason reason) Sets the value of the Reason property for this object.