Uses of Enum
software.amazon.awssdk.services.lambda.model.TracingMode
Packages that use TracingMode
-
Uses of TracingMode in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return TracingModeModifier and TypeMethodDescriptionstatic TracingModeUse this in place of valueOf to convert the raw string returned by the service into the enum value.final TracingModeTracingConfig.mode()The tracing mode.final TracingModeTracingConfigResponse.mode()The tracing mode.static TracingModeReturns the enum constant of this type with the specified name.static TracingMode[]TracingMode.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type TracingModeMethods in software.amazon.awssdk.services.lambda.model with parameters of type TracingModeModifier and TypeMethodDescriptionTracingConfig.Builder.mode(TracingMode mode) The tracing mode.TracingConfigResponse.Builder.mode(TracingMode mode) The tracing mode.