Uses of Interface
software.amazon.awssdk.services.lambda.model.UpdateFunctionCodeRequest.Builder
Packages that use UpdateFunctionCodeRequest.Builder
Package
Description
-
Uses of UpdateFunctionCodeRequest.Builder in software.amazon.awssdk.services.lambda
Method parameters in software.amazon.awssdk.services.lambda with type arguments of type UpdateFunctionCodeRequest.BuilderModifier and TypeMethodDescriptionLambdaAsyncClient.updateFunctionCode(Consumer<UpdateFunctionCodeRequest.Builder> updateFunctionCodeRequest) Updates a Lambda function's code.default UpdateFunctionCodeResponseLambdaClient.updateFunctionCode(Consumer<UpdateFunctionCodeRequest.Builder> updateFunctionCodeRequest) Updates a Lambda function's code. -
Uses of UpdateFunctionCodeRequest.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return UpdateFunctionCodeRequest.BuilderModifier and TypeMethodDescriptionUpdateFunctionCodeRequest.Builder.architectures(Collection<Architecture> architectures) The instruction set architecture that the function supports.UpdateFunctionCodeRequest.Builder.architectures(Architecture... architectures) The instruction set architecture that the function supports.UpdateFunctionCodeRequest.Builder.architecturesWithStrings(String... architectures) The instruction set architecture that the function supports.UpdateFunctionCodeRequest.Builder.architecturesWithStrings(Collection<String> architectures) The instruction set architecture that the function supports.UpdateFunctionCodeRequest.builder()Set to true to validate the request parameters and access permissions without modifying the function code.UpdateFunctionCodeRequest.Builder.functionName(String functionName) The name or ARN of the Lambda function.URI of a container image in the Amazon ECR registry.UpdateFunctionCodeRequest.Builder.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) UpdateFunctionCodeRequest.Builder.overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Set to true to publish a new version of the function after updating the code.Specifies where to publish the function version or configuration.UpdateFunctionCodeRequest.Builder.publishTo(FunctionVersionLatestPublished publishTo) Specifies where to publish the function version or configuration.UpdateFunctionCodeRequest.Builder.revisionId(String revisionId) Update the function only if the revision ID matches the ID that's specified.An Amazon S3 bucket in the same Amazon Web Services Region as your function.The Amazon S3 key of the deployment package.UpdateFunctionCodeRequest.Builder.s3ObjectVersion(String s3ObjectVersion) For versioned objects, the version of the deployment package object to use.UpdateFunctionCodeRequest.Builder.sourceKMSKeyArn(String sourceKMSKeyArn) The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package.UpdateFunctionCodeRequest.toBuilder()The base64-encoded contents of the deployment package.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type UpdateFunctionCodeRequest.BuilderModifier and TypeMethodDescriptionstatic Class<? extends UpdateFunctionCodeRequest.Builder>UpdateFunctionCodeRequest.serializableBuilderClass()