Uses of Interface
software.amazon.awssdk.services.lambda.model.UpdateFunctionConfigurationResponse.Builder
Packages that use UpdateFunctionConfigurationResponse.Builder
-
Uses of UpdateFunctionConfigurationResponse.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return UpdateFunctionConfigurationResponse.BuilderModifier and TypeMethodDescriptionUpdateFunctionConfigurationResponse.Builder.architectures(Collection<Architecture> architectures) The instruction set architecture that the function supports.UpdateFunctionConfigurationResponse.Builder.architectures(Architecture... architectures) The instruction set architecture that the function supports.UpdateFunctionConfigurationResponse.Builder.architecturesWithStrings(String... architectures) The instruction set architecture that the function supports.UpdateFunctionConfigurationResponse.Builder.architecturesWithStrings(Collection<String> architectures) The instruction set architecture that the function supports.UpdateFunctionConfigurationResponse.builder()UpdateFunctionConfigurationResponse.Builder.capacityProviderConfig(Consumer<CapacityProviderConfig.Builder> capacityProviderConfig) Configuration for the capacity provider that manages compute resources for Lambda functions.UpdateFunctionConfigurationResponse.Builder.capacityProviderConfig(CapacityProviderConfig capacityProviderConfig) Configuration for the capacity provider that manages compute resources for Lambda functions.UpdateFunctionConfigurationResponse.Builder.codeSha256(String codeSha256) The SHA256 hash of the function's deployment package.The size of the function's deployment package, in bytes.UpdateFunctionConfigurationResponse.Builder.configSha256(String configSha256) The SHA256 hash of the function configuration.UpdateFunctionConfigurationResponse.Builder.deadLetterConfig(Consumer<DeadLetterConfig.Builder> deadLetterConfig) The function's dead letter queue.UpdateFunctionConfigurationResponse.Builder.deadLetterConfig(DeadLetterConfig deadLetterConfig) The function's dead letter queue.UpdateFunctionConfigurationResponse.Builder.description(String description) The function's description.UpdateFunctionConfigurationResponse.Builder.durableConfig(Consumer<DurableConfig.Builder> durableConfig) The function's durable execution configuration settings, if the function is configured for durability.UpdateFunctionConfigurationResponse.Builder.durableConfig(DurableConfig durableConfig) The function's durable execution configuration settings, if the function is configured for durability.UpdateFunctionConfigurationResponse.Builder.environment(Consumer<EnvironmentResponse.Builder> environment) The function's environment variables.UpdateFunctionConfigurationResponse.Builder.environment(EnvironmentResponse environment) The function's environment variables.UpdateFunctionConfigurationResponse.Builder.ephemeralStorage(Consumer<EphemeralStorage.Builder> ephemeralStorage) The size of the function's/tmpdirectory in MB.UpdateFunctionConfigurationResponse.Builder.ephemeralStorage(EphemeralStorage ephemeralStorage) The size of the function's/tmpdirectory in MB.UpdateFunctionConfigurationResponse.Builder.fileSystemConfigs(Collection<FileSystemConfig> fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.UpdateFunctionConfigurationResponse.Builder.fileSystemConfigs(Consumer<FileSystemConfig.Builder>... fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.UpdateFunctionConfigurationResponse.Builder.fileSystemConfigs(FileSystemConfig... fileSystemConfigs) Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.UpdateFunctionConfigurationResponse.Builder.functionArn(String functionArn) The function's Amazon Resource Name (ARN).UpdateFunctionConfigurationResponse.Builder.functionName(String functionName) The name of the function.The function that Lambda calls to begin running your function.UpdateFunctionConfigurationResponse.Builder.imageConfigResponse(Consumer<ImageConfigResponse.Builder> imageConfigResponse) The function's image configuration values.UpdateFunctionConfigurationResponse.Builder.imageConfigResponse(ImageConfigResponse imageConfigResponse) The function's image configuration values.The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt the following resources:UpdateFunctionConfigurationResponse.Builder.lastModified(String lastModified) The date and time that the function was last updated, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).UpdateFunctionConfigurationResponse.Builder.lastUpdateStatus(String lastUpdateStatus) The status of the last update that was performed on the function.UpdateFunctionConfigurationResponse.Builder.lastUpdateStatus(LastUpdateStatus lastUpdateStatus) The status of the last update that was performed on the function.UpdateFunctionConfigurationResponse.Builder.lastUpdateStatusReason(String lastUpdateStatusReason) The reason for the last update that was performed on the function.UpdateFunctionConfigurationResponse.Builder.lastUpdateStatusReasonCode(String lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.UpdateFunctionConfigurationResponse.Builder.lastUpdateStatusReasonCode(LastUpdateStatusReasonCode lastUpdateStatusReasonCode) The reason code for the last update that was performed on the function.UpdateFunctionConfigurationResponse.Builder.layers(Collection<Layer> layers) The function's layers.UpdateFunctionConfigurationResponse.Builder.layers(Consumer<Layer.Builder>... layers) The function's layers.The function's layers.UpdateFunctionConfigurationResponse.Builder.loggingConfig(Consumer<LoggingConfig.Builder> loggingConfig) The function's Amazon CloudWatch Logs configuration settings.UpdateFunctionConfigurationResponse.Builder.loggingConfig(LoggingConfig loggingConfig) The function's Amazon CloudWatch Logs configuration settings.For Lambda@Edge functions, the ARN of the main function.UpdateFunctionConfigurationResponse.Builder.memorySize(Integer memorySize) The amount of memory available to the function at runtime.UpdateFunctionConfigurationResponse.Builder.packageType(String packageType) The type of deployment package.UpdateFunctionConfigurationResponse.Builder.packageType(PackageType packageType) The type of deployment package.UpdateFunctionConfigurationResponse.Builder.revisionId(String revisionId) The latest updated revision of the function or alias.The function's execution role.The identifier of the function's runtime.The identifier of the function's runtime.UpdateFunctionConfigurationResponse.Builder.runtimeVersionConfig(Consumer<RuntimeVersionConfig.Builder> runtimeVersionConfig) The ARN of the runtime and any errors that occured.UpdateFunctionConfigurationResponse.Builder.runtimeVersionConfig(RuntimeVersionConfig runtimeVersionConfig) The ARN of the runtime and any errors that occured.UpdateFunctionConfigurationResponse.Builder.signingJobArn(String signingJobArn) The ARN of the signing job.UpdateFunctionConfigurationResponse.Builder.signingProfileVersionArn(String signingProfileVersionArn) The ARN of the signing profile version.UpdateFunctionConfigurationResponse.Builder.snapStart(Consumer<SnapStartResponse.Builder> snapStart) SetApplyOntoPublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.UpdateFunctionConfigurationResponse.Builder.snapStart(SnapStartResponse snapStart) SetApplyOntoPublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.The current state of the function.The current state of the function.UpdateFunctionConfigurationResponse.Builder.stateReason(String stateReason) The reason for the function's current state.UpdateFunctionConfigurationResponse.Builder.stateReasonCode(String stateReasonCode) The reason code for the function's current state.UpdateFunctionConfigurationResponse.Builder.stateReasonCode(StateReasonCode stateReasonCode) The reason code for the function's current state.UpdateFunctionConfigurationResponse.Builder.tenancyConfig(Consumer<TenancyConfig.Builder> tenancyConfig) The function's tenant isolation configuration settings.UpdateFunctionConfigurationResponse.Builder.tenancyConfig(TenancyConfig tenancyConfig) The function's tenant isolation configuration settings.The amount of time in seconds that Lambda allows a function to run before stopping it.UpdateFunctionConfigurationResponse.toBuilder()UpdateFunctionConfigurationResponse.Builder.tracingConfig(Consumer<TracingConfigResponse.Builder> tracingConfig) The function's X-Ray tracing configuration.UpdateFunctionConfigurationResponse.Builder.tracingConfig(TracingConfigResponse tracingConfig) The function's X-Ray tracing configuration.The version of the Lambda function.UpdateFunctionConfigurationResponse.Builder.vpcConfig(Consumer<VpcConfigResponse.Builder> vpcConfig) The function's networking configuration.UpdateFunctionConfigurationResponse.Builder.vpcConfig(VpcConfigResponse vpcConfig) The function's networking configuration.Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type UpdateFunctionConfigurationResponse.BuilderModifier and TypeMethodDescriptionstatic Class<? extends UpdateFunctionConfigurationResponse.Builder>UpdateFunctionConfigurationResponse.serializableBuilderClass()