Uses of Interface
software.amazon.awssdk.services.lambda.model.UpdateFunctionEventInvokeConfigResponse.Builder
Packages that use UpdateFunctionEventInvokeConfigResponse.Builder
-
Uses of UpdateFunctionEventInvokeConfigResponse.Builder in software.amazon.awssdk.services.lambda.model
Methods in software.amazon.awssdk.services.lambda.model that return UpdateFunctionEventInvokeConfigResponse.BuilderModifier and TypeMethodDescriptionUpdateFunctionEventInvokeConfigResponse.builder()UpdateFunctionEventInvokeConfigResponse.Builder.destinationConfig(Consumer<DestinationConfig.Builder> destinationConfig) A destination for events after they have been sent to a function for processing.UpdateFunctionEventInvokeConfigResponse.Builder.destinationConfig(DestinationConfig destinationConfig) A destination for events after they have been sent to a function for processing.UpdateFunctionEventInvokeConfigResponse.Builder.functionArn(String functionArn) The Amazon Resource Name (ARN) of the function.UpdateFunctionEventInvokeConfigResponse.Builder.lastModified(Instant lastModified) The date and time that the configuration was last updated.UpdateFunctionEventInvokeConfigResponse.Builder.maximumEventAgeInSeconds(Integer maximumEventAgeInSeconds) The maximum age of a request that Lambda sends to a function for processing.UpdateFunctionEventInvokeConfigResponse.Builder.maximumRetryAttempts(Integer maximumRetryAttempts) The maximum number of times to retry when the function returns an error.UpdateFunctionEventInvokeConfigResponse.toBuilder()Methods in software.amazon.awssdk.services.lambda.model that return types with arguments of type UpdateFunctionEventInvokeConfigResponse.BuilderModifier and TypeMethodDescriptionstatic Class<? extends UpdateFunctionEventInvokeConfigResponse.Builder>UpdateFunctionEventInvokeConfigResponse.serializableBuilderClass()