Uses of Package
software.amazon.awssdk.services.lambda
Packages that use software.amazon.awssdk.services.lambda
Package
Description
-
Classes in software.amazon.awssdk.services.lambda used by software.amazon.awssdk.services.lambdaClassDescriptionService client for accessing AWS Lambda asynchronously.A builder for creating an instance of
LambdaAsyncClient.This includes configuration specific to AWS Lambda that is supported by bothLambdaClientBuilderandLambdaAsyncClientBuilder.Service client for accessing AWS Lambda.A builder for creating an instance ofLambdaClient.Class to expose the service client settings to the user.A builder for creating aLambdaServiceClientConfiguration -
Classes in software.amazon.awssdk.services.lambda used by software.amazon.awssdk.services.lambda.internalClassDescriptionClass to expose the service client settings to the user.A builder for creating a
LambdaServiceClientConfiguration -
Classes in software.amazon.awssdk.services.lambda used by software.amazon.awssdk.services.lambda.paginatorsClassDescriptionService client for accessing AWS Lambda asynchronously.Service client for accessing AWS Lambda.
-
Classes in software.amazon.awssdk.services.lambda used by software.amazon.awssdk.services.lambda.waitersClassDescriptionService client for accessing AWS Lambda asynchronously.Service client for accessing AWS Lambda.