Class CallbackOptions
java.lang.Object
software.amazon.awssdk.services.lambda.model.CallbackOptions
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<CallbackOptions.Builder,CallbackOptions>
@Generated("software.amazon.awssdk:codegen")
public final class CallbackOptions
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<CallbackOptions.Builder,CallbackOptions>
Configuration options for callback operations in durable executions, including timeout settings and retry behavior.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic CallbackOptions.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe heartbeat timeout for the callback operation, in seconds.static Class<? extends CallbackOptions.Builder>final IntegerThe timeout for the callback operation in seconds.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
timeoutSeconds
The timeout for the callback operation in seconds. If not specified or set to 0, the callback has no timeout.
- Returns:
- The timeout for the callback operation in seconds. If not specified or set to 0, the callback has no timeout.
-
heartbeatTimeoutSeconds
The heartbeat timeout for the callback operation, in seconds. If not specified or set to 0, heartbeat timeout is disabled.
- Returns:
- The heartbeat timeout for the callback operation, in seconds. If not specified or set to 0, heartbeat timeout is disabled.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CallbackOptions.Builder,CallbackOptions>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-