Class CreateFunctionUrlConfigResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreateFunctionUrlConfigResponse.Builder,CreateFunctionUrlConfigResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal FunctionUrlAuthTypeauthType()The type of authentication that your function URL uses.final StringThe type of authentication that your function URL uses.builder()final Corscors()The cross-origin resource sharing (CORS) settings for your function URL.final StringWhen the function URL was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe Amazon Resource Name (ARN) of your function.final StringThe HTTP URL endpoint for your function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final InvokeModeUse one of the following options:final StringUse one of the following options:static Class<? extends CreateFunctionUrlConfigResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionUrl
The HTTP URL endpoint for your function.
- Returns:
- The HTTP URL endpoint for your function.
-
functionArn
The Amazon Resource Name (ARN) of your function.
- Returns:
- The Amazon Resource Name (ARN) of your function.
-
authType
The type of authentication that your function URL uses. Set to
AWS_IAMif you want to restrict access to authenticated users only. Set toNONEif you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs.If the service returns an enum value that is not available in the current SDK version,
authTypewill returnFunctionUrlAuthType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromauthTypeAsString().- Returns:
- The type of authentication that your function URL uses. Set to
AWS_IAMif you want to restrict access to authenticated users only. Set toNONEif you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs. - See Also:
-
authTypeAsString
The type of authentication that your function URL uses. Set to
AWS_IAMif you want to restrict access to authenticated users only. Set toNONEif you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs.If the service returns an enum value that is not available in the current SDK version,
authTypewill returnFunctionUrlAuthType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromauthTypeAsString().- Returns:
- The type of authentication that your function URL uses. Set to
AWS_IAMif you want to restrict access to authenticated users only. Set toNONEif you want to bypass IAM authentication to create a public endpoint. For more information, see Control access to Lambda function URLs. - See Also:
-
cors
The cross-origin resource sharing (CORS) settings for your function URL.
- Returns:
- The cross-origin resource sharing (CORS) settings for your function URL.
-
creationTime
When the function URL was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- When the function URL was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
invokeMode
Use one of the following options:
-
BUFFERED– This is the default option. Lambda invokes your function using theInvokeAPI operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB. -
RESPONSE_STREAM– Your function streams payload results as they become available. Lambda invokes your function using theInvokeWithResponseStreamAPI operation. The maximum response payload size is 200 MB.
If the service returns an enum value that is not available in the current SDK version,
invokeModewill returnInvokeMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frominvokeModeAsString().- Returns:
- Use one of the following options:
-
BUFFERED– This is the default option. Lambda invokes your function using theInvokeAPI operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB. -
RESPONSE_STREAM– Your function streams payload results as they become available. Lambda invokes your function using theInvokeWithResponseStreamAPI operation. The maximum response payload size is 200 MB.
-
- See Also:
-
-
invokeModeAsString
Use one of the following options:
-
BUFFERED– This is the default option. Lambda invokes your function using theInvokeAPI operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB. -
RESPONSE_STREAM– Your function streams payload results as they become available. Lambda invokes your function using theInvokeWithResponseStreamAPI operation. The maximum response payload size is 200 MB.
If the service returns an enum value that is not available in the current SDK version,
invokeModewill returnInvokeMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frominvokeModeAsString().- Returns:
- Use one of the following options:
-
BUFFERED– This is the default option. Lambda invokes your function using theInvokeAPI operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB. -
RESPONSE_STREAM– Your function streams payload results as they become available. Lambda invokes your function using theInvokeWithResponseStreamAPI operation. The maximum response payload size is 200 MB.
-
- See Also:
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreateFunctionUrlConfigResponse.Builder,CreateFunctionUrlConfigResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-