Interface DeleteFunctionEventInvokeConfigRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<DeleteFunctionEventInvokeConfigRequest.Builder,,DeleteFunctionEventInvokeConfigRequest> LambdaRequest.Builder,SdkBuilder<DeleteFunctionEventInvokeConfigRequest.Builder,,DeleteFunctionEventInvokeConfigRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- DeleteFunctionEventInvokeConfigRequest
-
Method Summary
Modifier and TypeMethodDescriptionfunctionName(String functionName) The name or ARN of the Lambda function, version, or alias.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) A version number or alias name.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.services.lambda.model.LambdaRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
functionName
The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name -
my-function(name-only),my-function:v1(with alias). -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN -
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Parameters:
functionName- The name or ARN of the Lambda function, version, or alias.Name formats
-
Function name -
my-function(name-only),my-function:v1(with alias). -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN -
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-
qualifier
A version number or alias name.
- Parameters:
qualifier- A version number or alias name.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DeleteFunctionEventInvokeConfigRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DeleteFunctionEventInvokeConfigRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-