Class Execution
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<Execution.Builder,Execution>
Information about a durable execution.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic Execution.Builderbuilder()final StringThe Amazon Resource Name (ARN) of the durable execution, if this execution is a durable execution.final StringThe unique name of the durable execution, if one was provided when the execution was started.final InstantThe date and time when the durable execution ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe Amazon Resource Name (ARN) of the Lambda function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends Execution.Builder>final InstantThe date and time when the durable execution started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).final ExecutionStatusstatus()The current status of the durable execution.final StringThe current status of the durable execution.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
durableExecutionArn
The Amazon Resource Name (ARN) of the durable execution, if this execution is a durable execution.
- Returns:
- The Amazon Resource Name (ARN) of the durable execution, if this execution is a durable execution.
-
durableExecutionName
The unique name of the durable execution, if one was provided when the execution was started.
- Returns:
- The unique name of the durable execution, if one was provided when the execution was started.
-
functionArn
The Amazon Resource Name (ARN) of the Lambda function.
- Returns:
- The Amazon Resource Name (ARN) of the Lambda function.
-
status
The current status of the durable execution.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The current status of the durable execution.
- See Also:
-
statusAsString
The current status of the durable execution.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The current status of the durable execution.
- See Also:
-
startTimestamp
The date and time when the durable execution started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- The date and time when the durable execution started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
endTimestamp
The date and time when the durable execution ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- The date and time when the durable execution ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<Execution.Builder,Execution>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-