Class GetDurableExecutionHistoryRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetDurableExecutionHistoryRequest.Builder,GetDurableExecutionHistoryRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe Amazon Resource Name (ARN) of the durable execution.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final BooleanSpecifies whether to include execution data such as step results and callback payloads in the history events.final Stringmarker()IfNextMarkerwas returned from a previous request, use this value to retrieve the next page of results.final IntegermaxItems()The maximum number of history events to return per call.final BooleanWhen set totrue, returns the history events in reverse chronological order (newest first).static Class<? extends GetDurableExecutionHistoryRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
durableExecutionArn
The Amazon Resource Name (ARN) of the durable execution.
- Returns:
- The Amazon Resource Name (ARN) of the durable execution.
-
includeExecutionData
Specifies whether to include execution data such as step results and callback payloads in the history events. Set to
trueto include data, orfalseto exclude it for a more compact response. The default istrue.- Returns:
- Specifies whether to include execution data such as step results and callback payloads in the history
events. Set to
trueto include data, orfalseto exclude it for a more compact response. The default istrue.
-
maxItems
The maximum number of history events to return per call. You can use
Markerto retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.- Returns:
- The maximum number of history events to return per call. You can use
Markerto retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.
-
marker
If
NextMarkerwas returned from a previous request, use this value to retrieve the next page of results. Each pagination token expires after 24 hours.- Returns:
- If
NextMarkerwas returned from a previous request, use this value to retrieve the next page of results. Each pagination token expires after 24 hours.
-
reverseOrder
When set to
true, returns the history events in reverse chronological order (newest first). By default, events are returned in chronological order (oldest first).- Returns:
- When set to
true, returns the history events in reverse chronological order (newest first). By default, events are returned in chronological order (oldest first).
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetDurableExecutionHistoryRequest.Builder,GetDurableExecutionHistoryRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-