Class GetDurableExecutionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetDurableExecutionResponse.Builder,GetDurableExecutionResponse>
The response from the GetDurableExecution operation, containing detailed information about the durable execution.
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe Amazon Resource Name (ARN) of the durable execution.final StringThe name of the durable execution.final InstantThe date and time when the durable execution ended, in Unix timestamp format.final booleanfinal booleanequalsBySdkFields(Object obj) final ErrorObjecterror()Error information if the durable execution failed.final StringThe Amazon Resource Name (ARN) of the Lambda function that was invoked to start this durable execution.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe JSON input payload that was provided when the durable execution was started.final Stringresult()The JSON result returned by the durable execution if it completed successfully.static Class<? extends GetDurableExecutionResponse.Builder>final InstantThe date and time when the durable execution started, in Unix timestamp format.final ExecutionStatusstatus()The current status of the durable execution.final StringThe current status of the durable execution.final StringtoString()Returns a string representation of this object.final TraceHeaderThe trace headers associated with the durable execution.final Stringversion()The version of the Lambda function that was invoked for this durable execution.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
durableExecutionArn
The Amazon Resource Name (ARN) of the durable execution.
- Returns:
- The Amazon Resource Name (ARN) of the durable execution.
-
durableExecutionName
The name of the durable execution. This is either the name you provided when invoking the function, or a system-generated unique identifier if no name was provided.
- Returns:
- The name of the durable execution. This is either the name you provided when invoking the function, or a system-generated unique identifier if no name was provided.
-
functionArn
The Amazon Resource Name (ARN) of the Lambda function that was invoked to start this durable execution.
- Returns:
- The Amazon Resource Name (ARN) of the Lambda function that was invoked to start this durable execution.
-
inputPayload
The JSON input payload that was provided when the durable execution was started. For asynchronous invocations, this is limited to 256 KB. For synchronous invocations, this can be up to 6 MB.
- Returns:
- The JSON input payload that was provided when the durable execution was started. For asynchronous invocations, this is limited to 256 KB. For synchronous invocations, this can be up to 6 MB.
-
result
The JSON result returned by the durable execution if it completed successfully. This field is only present when the execution status is
SUCCEEDED. The result is limited to 256 KB.- Returns:
- The JSON result returned by the durable execution if it completed successfully. This field is only
present when the execution status is
SUCCEEDED. The result is limited to 256 KB.
-
error
Error information if the durable execution failed. This field is only present when the execution status is
FAILED,TIMED_OUT, orSTOPPED. The combined size of all error fields is limited to 256 KB.- Returns:
- Error information if the durable execution failed. This field is only present when the execution status
is
FAILED,TIMED_OUT, orSTOPPED. The combined size of all error fields is limited to 256 KB.
-
startTimestamp
The date and time when the durable execution started, in Unix timestamp format.
- Returns:
- The date and time when the durable execution started, in Unix timestamp format.
-
status
The current status of the durable execution. Valid values are
RUNNING,SUCCEEDED,FAILED,TIMED_OUT, andSTOPPED.If the service returns an enum value that is not available in the current SDK version,
statuswill returnExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The current status of the durable execution. Valid values are
RUNNING,SUCCEEDED,FAILED,TIMED_OUT, andSTOPPED. - See Also:
-
statusAsString
The current status of the durable execution. Valid values are
RUNNING,SUCCEEDED,FAILED,TIMED_OUT, andSTOPPED.If the service returns an enum value that is not available in the current SDK version,
statuswill returnExecutionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The current status of the durable execution. Valid values are
RUNNING,SUCCEEDED,FAILED,TIMED_OUT, andSTOPPED. - See Also:
-
endTimestamp
The date and time when the durable execution ended, in Unix timestamp format. This field is only present if the execution has completed (status is
SUCCEEDED,FAILED,TIMED_OUT, orSTOPPED).- Returns:
- The date and time when the durable execution ended, in Unix timestamp format. This field is only present
if the execution has completed (status is
SUCCEEDED,FAILED,TIMED_OUT, orSTOPPED).
-
version
The version of the Lambda function that was invoked for this durable execution. This ensures that all replays during the execution use the same function version.
- Returns:
- The version of the Lambda function that was invoked for this durable execution. This ensures that all replays during the execution use the same function version.
-
traceHeader
The trace headers associated with the durable execution.
- Returns:
- The trace headers associated with the durable execution.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetDurableExecutionResponse.Builder,GetDurableExecutionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-