Class GetDurableExecutionStateRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.lambda.model.LambdaRequest
software.amazon.awssdk.services.lambda.model.GetDurableExecutionStateRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest>
@Generated("software.amazon.awssdk:codegen")
public final class GetDurableExecutionStateRequest
extends LambdaRequest
implements ToCopyableBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringA checkpoint token that identifies the current state of the execution.final StringThe Amazon Resource Name (ARN) of the durable execution.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringmarker()IfNextMarkerwas returned from a previous request, use this value to retrieve the next page of operations.final IntegermaxItems()The maximum number of operations to return per call.static Class<? extends GetDurableExecutionStateRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
durableExecutionArn
The Amazon Resource Name (ARN) of the durable execution.
- Returns:
- The Amazon Resource Name (ARN) of the durable execution.
-
checkpointToken
A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.
- Returns:
- A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.
-
marker
If
NextMarkerwas returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.- Returns:
- If
NextMarkerwas returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.
-
maxItems
The maximum number of operations to return per call. You can use
Markerto retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.- Returns:
- The maximum number of operations to return per call. You can use
Markerto retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-