Interface GetDurableExecutionStateRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<GetDurableExecutionStateRequest.Builder,,GetDurableExecutionStateRequest> LambdaRequest.Builder,SdkBuilder<GetDurableExecutionStateRequest.Builder,,GetDurableExecutionStateRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- GetDurableExecutionStateRequest
@Mutable
@NotThreadSafe
public static interface GetDurableExecutionStateRequest.Builder
extends LambdaRequest.Builder, SdkPojo, CopyableBuilder<GetDurableExecutionStateRequest.Builder,GetDurableExecutionStateRequest>
-
Method Summary
Modifier and TypeMethodDescriptioncheckpointToken(String checkpointToken) A checkpoint token that identifies the current state of the execution.durableExecutionArn(String durableExecutionArn) The Amazon Resource Name (ARN) of the durable execution.IfNextMarkerwas returned from a previous request, use this value to retrieve the next page of operations.The maximum number of operations to return per call.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.services.lambda.model.LambdaRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
durableExecutionArn
The Amazon Resource Name (ARN) of the durable execution.
- Parameters:
durableExecutionArn- The Amazon Resource Name (ARN) of the durable execution.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
checkpointToken
A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.
- Parameters:
checkpointToken- A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
marker
If
NextMarkerwas returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.- Parameters:
marker- IfNextMarkerwas returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
maxItems
The maximum number of operations to return per call. You can use
Markerto retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.- Parameters:
maxItems- The maximum number of operations to return per call. You can useMarkerto retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetDurableExecutionStateRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetDurableExecutionStateRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-