Class InvokeResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<InvokeResponse.Builder,InvokeResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic InvokeResponse.Builderbuilder()final StringThe ARN of the durable execution that was started.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe version of the function that executed.final StringIf present, indicates that an error occurred during function execution.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe last 4 KB of the execution log, which is base64-encoded.final SdkBytespayload()The response from the function, or an error object.static Class<? extends InvokeResponse.Builder>final IntegerThe HTTP status code is in the 200 range for a successful request.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
statusCode
The HTTP status code is in the 200 range for a successful request. For the
RequestResponseinvocation type, this status code is 200. For theEventinvocation type, this status code is 202. For theDryRuninvocation type, the status code is 204.- Returns:
- The HTTP status code is in the 200 range for a successful request. For the
RequestResponseinvocation type, this status code is 200. For theEventinvocation type, this status code is 202. For theDryRuninvocation type, the status code is 204.
-
functionError
If present, indicates that an error occurred during function execution. Details about the error are included in the response payload.
- Returns:
- If present, indicates that an error occurred during function execution. Details about the error are included in the response payload.
-
logResult
The last 4 KB of the execution log, which is base64-encoded.
- Returns:
- The last 4 KB of the execution log, which is base64-encoded.
-
payload
The response from the function, or an error object.
- Returns:
- The response from the function, or an error object.
-
executedVersion
The version of the function that executed. When you invoke a function with an alias, this indicates which version the alias resolved to.
- Returns:
- The version of the function that executed. When you invoke a function with an alias, this indicates which version the alias resolved to.
-
durableExecutionArn
The ARN of the durable execution that was started. This is returned when invoking a durable function and provides a unique identifier for tracking the execution.
- Returns:
- The ARN of the durable execution that was started. This is returned when invoking a durable function and provides a unique identifier for tracking the execution.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<InvokeResponse.Builder,InvokeResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-