Class LayerVersionContentInput

java.lang.Object
software.amazon.awssdk.services.lambda.model.LayerVersionContentInput
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<LayerVersionContentInput.Builder,LayerVersionContentInput>

@Generated("software.amazon.awssdk:codegen") public final class LayerVersionContentInput extends Object implements SdkPojo, Serializable, ToCopyableBuilder<LayerVersionContentInput.Builder,LayerVersionContentInput>

A ZIP archive that contains the contents of an Lambda layer. You can specify either an Amazon S3 location, or upload a layer archive directly.

See Also:
  • Method Details

    • s3Bucket

      public final String s3Bucket()

      The Amazon S3 bucket of the layer archive.

      Returns:
      The Amazon S3 bucket of the layer archive.
    • s3Key

      public final String s3Key()

      The Amazon S3 key of the layer archive.

      Returns:
      The Amazon S3 key of the layer archive.
    • s3ObjectVersion

      public final String s3ObjectVersion()

      For versioned objects, the version of the layer archive object to use.

      Returns:
      For versioned objects, the version of the layer archive object to use.
    • zipFile

      public final SdkBytes zipFile()

      The base64-encoded contents of the layer archive. Amazon Web Services SDK and Amazon Web Services CLI clients handle the encoding for you.

      Returns:
      The base64-encoded contents of the layer archive. Amazon Web Services SDK and Amazon Web Services CLI clients handle the encoding for you.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<LayerVersionContentInput.Builder,LayerVersionContentInput>
    • builder

      public static LayerVersionContentInput.Builder builder()
    • serializableBuilderClass

      public static Class<? extends LayerVersionContentInput.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo