Class LayerVersionContentInput
java.lang.Object
software.amazon.awssdk.services.lambda.model.LayerVersionContentInput
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<LayerVersionContentInput.Builder,LayerVersionContentInput>
@Generated("software.amazon.awssdk:codegen")
public final class LayerVersionContentInput
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<LayerVersionContentInput.Builder,LayerVersionContentInput>
A ZIP archive that contains the contents of an Lambda layer. You can specify either an Amazon S3 location, or upload a layer archive directly.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Strings3Bucket()The Amazon S3 bucket of the layer archive.final Strings3Key()The Amazon S3 key of the layer archive.final StringFor versioned objects, the version of the layer archive object to use.static Class<? extends LayerVersionContentInput.Builder>final StringtoString()Returns a string representation of this object.final SdkByteszipFile()The base64-encoded contents of the layer archive.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
s3Bucket
The Amazon S3 bucket of the layer archive.
- Returns:
- The Amazon S3 bucket of the layer archive.
-
s3Key
The Amazon S3 key of the layer archive.
- Returns:
- The Amazon S3 key of the layer archive.
-
s3ObjectVersion
For versioned objects, the version of the layer archive object to use.
- Returns:
- For versioned objects, the version of the layer archive object to use.
-
zipFile
The base64-encoded contents of the layer archive. Amazon Web Services SDK and Amazon Web Services CLI clients handle the encoding for you.
- Returns:
- The base64-encoded contents of the layer archive. Amazon Web Services SDK and Amazon Web Services CLI clients handle the encoding for you.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<LayerVersionContentInput.Builder,LayerVersionContentInput>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-