Class ListDurableExecutionsByFunctionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListDurableExecutionsByFunctionRequest.Builder,ListDurableExecutionsByFunctionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringFilter executions by name.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Statuses property.final Stringmarker()Pagination token from a previous request to continue retrieving results.final IntegermaxItems()Maximum number of executions to return (1-1000).final StringThe function version or alias.final BooleanSet to true to return results in reverse chronological order (newest first).static Class<? extends ListDurableExecutionsByFunctionRequest.Builder>final InstantFilter executions that started after this timestamp (ISO 8601 format).final InstantFilter executions that started before this timestamp (ISO 8601 format).final List<ExecutionStatus>statuses()Filter executions by status.Filter executions by status.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function. You can specify a function name, a partial ARN, or a full ARN.
- Returns:
- The name or ARN of the Lambda function. You can specify a function name, a partial ARN, or a full ARN.
-
qualifier
The function version or alias. If not specified, lists executions for the $LATEST version.
- Returns:
- The function version or alias. If not specified, lists executions for the $LATEST version.
-
durableExecutionName
Filter executions by name. Only executions with names that matches this string are returned.
- Returns:
- Filter executions by name. Only executions with names that matches this string are returned.
-
statuses
Filter executions by status. Valid values: RUNNING, SUCCEEDED, FAILED, TIMED_OUT, STOPPED.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasStatuses()method.- Returns:
- Filter executions by status. Valid values: RUNNING, SUCCEEDED, FAILED, TIMED_OUT, STOPPED.
-
hasStatuses
public final boolean hasStatuses()For responses, this returns true if the service returned a value for the Statuses property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
statusesAsStrings
Filter executions by status. Valid values: RUNNING, SUCCEEDED, FAILED, TIMED_OUT, STOPPED.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasStatuses()method.- Returns:
- Filter executions by status. Valid values: RUNNING, SUCCEEDED, FAILED, TIMED_OUT, STOPPED.
-
startedAfter
Filter executions that started after this timestamp (ISO 8601 format).
- Returns:
- Filter executions that started after this timestamp (ISO 8601 format).
-
startedBefore
Filter executions that started before this timestamp (ISO 8601 format).
- Returns:
- Filter executions that started before this timestamp (ISO 8601 format).
-
reverseOrder
Set to true to return results in reverse chronological order (newest first). Default is false.
- Returns:
- Set to true to return results in reverse chronological order (newest first). Default is false.
-
marker
Pagination token from a previous request to continue retrieving results.
- Returns:
- Pagination token from a previous request to continue retrieving results.
-
maxItems
Maximum number of executions to return (1-1000). Default is 100.
- Returns:
- Maximum number of executions to return (1-1000). Default is 100.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListDurableExecutionsByFunctionRequest.Builder,ListDurableExecutionsByFunctionRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
public static Class<? extends ListDurableExecutionsByFunctionRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-