Class ListFunctionEventInvokeConfigsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListFunctionEventInvokeConfigsRequest.Builder,ListFunctionEventInvokeConfigsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringmarker()Specify the pagination token that's returned by a previous request to retrieve the next page of results.final IntegermaxItems()The maximum number of configurations to return.static Class<? extends ListFunctionEventInvokeConfigsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function.
Name formats
-
Function name -
my-function. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN -
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Returns:
- The name or ARN of the Lambda function.
Name formats
-
Function name -
my-function. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN -
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
-
-
marker
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
- Returns:
- Specify the pagination token that's returned by a previous request to retrieve the next page of results.
-
maxItems
The maximum number of configurations to return.
- Returns:
- The maximum number of configurations to return.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListFunctionEventInvokeConfigsRequest.Builder,ListFunctionEventInvokeConfigsRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
public static Class<? extends ListFunctionEventInvokeConfigsRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-