Class ListFunctionsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListFunctionsRequest.Builder,ListFunctionsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ListFunctionsRequest.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final FunctionVersionSet toALLto include entries for all published versions of each function.final StringSet toALLto include entries for all published versions of each function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringmarker()Specify the pagination token that's returned by a previous request to retrieve the next page of results.final StringFor Lambda@Edge functions, the Amazon Web Services Region of the master function.final IntegermaxItems()The maximum number of functions to return in the response.static Class<? extends ListFunctionsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
masterRegion
For Lambda@Edge functions, the Amazon Web Services Region of the master function. For example,
us-east-1filters the list of functions to include only Lambda@Edge functions replicated from a master function in US East (N. Virginia). If specified, you must setFunctionVersiontoALL.- Returns:
- For Lambda@Edge functions, the Amazon Web Services Region of the master function. For example,
us-east-1filters the list of functions to include only Lambda@Edge functions replicated from a master function in US East (N. Virginia). If specified, you must setFunctionVersiontoALL.
-
functionVersion
Set to
ALLto include entries for all published versions of each function.If the service returns an enum value that is not available in the current SDK version,
functionVersionwill returnFunctionVersion.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfunctionVersionAsString().- Returns:
- Set to
ALLto include entries for all published versions of each function. - See Also:
-
functionVersionAsString
Set to
ALLto include entries for all published versions of each function.If the service returns an enum value that is not available in the current SDK version,
functionVersionwill returnFunctionVersion.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfunctionVersionAsString().- Returns:
- Set to
ALLto include entries for all published versions of each function. - See Also:
-
marker
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
- Returns:
- Specify the pagination token that's returned by a previous request to retrieve the next page of results.
-
maxItems
The maximum number of functions to return in the response. Note that
ListFunctionsreturns a maximum of 50 items in each response, even if you set the number higher.- Returns:
- The maximum number of functions to return in the response. Note that
ListFunctionsreturns a maximum of 50 items in each response, even if you set the number higher.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListFunctionsRequest.Builder,ListFunctionsRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-