Class OnSuccess
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<OnSuccess.Builder,OnSuccess>
A destination for events that were processed successfully.
To retain records of successful asynchronous invocations, you can configure an Amazon SNS topic, Amazon SQS queue, Lambda function, or Amazon EventBridge event bus as the destination.
OnSuccess is not supported in CreateEventSourceMapping or
UpdateEventSourceMapping requests.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic OnSuccess.Builderbuilder()final StringThe Amazon Resource Name (ARN) of the destination resource.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends OnSuccess.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
destination
The Amazon Resource Name (ARN) of the destination resource.
Amazon SNS destinations have a message size limit of 256 KB. If the combined size of the function request and response payload exceeds the limit, Lambda will drop the payload when sending
OnFailureevent to the destination. For details on this behavior, refer to Retaining records of asynchronous invocations.- Returns:
- The Amazon Resource Name (ARN) of the destination resource.
Amazon SNS destinations have a message size limit of 256 KB. If the combined size of the function request and response payload exceeds the limit, Lambda will drop the payload when sending
OnFailureevent to the destination. For details on this behavior, refer to Retaining records of asynchronous invocations.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<OnSuccess.Builder,OnSuccess>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-