Interface ProvisionedPollerConfig.Builder
-
- All Superinterfaces:
Buildable,CopyableBuilder<ProvisionedPollerConfig.Builder,ProvisionedPollerConfig>,SdkBuilder<ProvisionedPollerConfig.Builder,ProvisionedPollerConfig>,SdkPojo
- Enclosing class:
- ProvisionedPollerConfig
@Mutable @NotThreadSafe public static interface ProvisionedPollerConfig.Builder extends SdkPojo, CopyableBuilder<ProvisionedPollerConfig.Builder,ProvisionedPollerConfig>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ProvisionedPollerConfig.BuildermaximumPollers(Integer maximumPollers)The maximum number of event pollers this event source can scale up to.ProvisionedPollerConfig.BuilderminimumPollers(Integer minimumPollers)The minimum number of event pollers this event source can scale down to.-
Methods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copy
-
Methods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, build
-
Methods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
-
-
-
Method Detail
-
minimumPollers
ProvisionedPollerConfig.Builder minimumPollers(Integer minimumPollers)
The minimum number of event pollers this event source can scale down to. For Amazon SQS events source mappings, default is 2, and minimum 2 required. For Amazon MSK and self-managed Apache Kafka event source mappings, default is 1.
- Parameters:
minimumPollers- The minimum number of event pollers this event source can scale down to. For Amazon SQS events source mappings, default is 2, and minimum 2 required. For Amazon MSK and self-managed Apache Kafka event source mappings, default is 1.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
maximumPollers
ProvisionedPollerConfig.Builder maximumPollers(Integer maximumPollers)
The maximum number of event pollers this event source can scale up to. For Amazon SQS events source mappings, default is 200, and minimum value allowed is 2. For Amazon MSK and self-managed Apache Kafka event source mappings, default is 200, and minimum value allowed is 1.
- Parameters:
maximumPollers- The maximum number of event pollers this event source can scale up to. For Amazon SQS events source mappings, default is 200, and minimum value allowed is 2. For Amazon MSK and self-managed Apache Kafka event source mappings, default is 200, and minimum value allowed is 1.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-