Class PublishLayerVersionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PublishLayerVersionRequest.Builder,PublishLayerVersionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final List<Architecture>A list of compatible instruction set architectures.A list of compatible instruction set architectures.A list of compatible function runtimes.A list of compatible function runtimes.final LayerVersionContentInputcontent()The function layer archive.final StringThe description of the version.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the CompatibleArchitectures property.final booleanFor responses, this returns true if the service returned a value for the CompatibleRuntimes property.final inthashCode()final StringThe name or Amazon Resource Name (ARN) of the layer.final StringThe layer's software license.static Class<? extends PublishLayerVersionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
layerName
The name or Amazon Resource Name (ARN) of the layer.
- Returns:
- The name or Amazon Resource Name (ARN) of the layer.
-
description
The description of the version.
- Returns:
- The description of the version.
-
content
The function layer archive.
- Returns:
- The function layer archive.
-
compatibleRuntimes
A list of compatible function runtimes. Used for filtering with ListLayers and ListLayerVersions.
The following list includes deprecated runtimes. For more information, see Runtime deprecation policy.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCompatibleRuntimes()method.- Returns:
- A list of compatible function
runtimes. Used for filtering with ListLayers and ListLayerVersions.
The following list includes deprecated runtimes. For more information, see Runtime deprecation policy.
-
hasCompatibleRuntimes
public final boolean hasCompatibleRuntimes()For responses, this returns true if the service returned a value for the CompatibleRuntimes property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
compatibleRuntimesAsStrings
A list of compatible function runtimes. Used for filtering with ListLayers and ListLayerVersions.
The following list includes deprecated runtimes. For more information, see Runtime deprecation policy.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCompatibleRuntimes()method.- Returns:
- A list of compatible function
runtimes. Used for filtering with ListLayers and ListLayerVersions.
The following list includes deprecated runtimes. For more information, see Runtime deprecation policy.
-
licenseInfo
The layer's software license. It can be any of the following:
-
An SPDX license identifier. For example,
MIT. -
The URL of a license hosted on the internet. For example,
https://opensource.org/licenses/MIT. -
The full text of the license.
- Returns:
- The layer's software license. It can be any of the following:
-
An SPDX license identifier. For example,
MIT. -
The URL of a license hosted on the internet. For example,
https://opensource.org/licenses/MIT. -
The full text of the license.
-
-
-
compatibleArchitectures
A list of compatible instruction set architectures.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCompatibleArchitectures()method.- Returns:
- A list of compatible instruction set architectures.
-
hasCompatibleArchitectures
public final boolean hasCompatibleArchitectures()For responses, this returns true if the service returned a value for the CompatibleArchitectures property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
compatibleArchitecturesAsStrings
A list of compatible instruction set architectures.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCompatibleArchitectures()method.- Returns:
- A list of compatible instruction set architectures.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PublishLayerVersionRequest.Builder,PublishLayerVersionRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-