Class PublishLayerVersionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PublishLayerVersionResponse.Builder,PublishLayerVersionResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final List<Architecture>A list of compatible instruction set architectures.A list of compatible instruction set architectures.The layer's compatible runtimes.The layer's compatible runtimes.content()Details about the layer version.final StringThe date that the layer version was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).final StringThe description of the version.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the CompatibleArchitectures property.final booleanFor responses, this returns true if the service returned a value for the CompatibleRuntimes property.final inthashCode()final StringlayerArn()The ARN of the layer.final StringThe ARN of the layer version.final StringThe layer's software license.static Class<? extends PublishLayerVersionResponse.Builder>final StringtoString()Returns a string representation of this object.final Longversion()The version number.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
content
Details about the layer version.
- Returns:
- Details about the layer version.
-
layerArn
The ARN of the layer.
- Returns:
- The ARN of the layer.
-
layerVersionArn
The ARN of the layer version.
- Returns:
- The ARN of the layer version.
-
description
The description of the version.
- Returns:
- The description of the version.
-
createdDate
The date that the layer version was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
- Returns:
- The date that the layer version was created, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
-
version
The version number.
- Returns:
- The version number.
-
compatibleRuntimes
The layer's compatible runtimes.
The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCompatibleRuntimes()method.- Returns:
- The layer's compatible runtimes.
The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
-
hasCompatibleRuntimes
public final boolean hasCompatibleRuntimes()For responses, this returns true if the service returned a value for the CompatibleRuntimes property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
compatibleRuntimesAsStrings
The layer's compatible runtimes.
The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCompatibleRuntimes()method.- Returns:
- The layer's compatible runtimes.
The following list includes deprecated runtimes. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
-
licenseInfo
The layer's software license.
- Returns:
- The layer's software license.
-
compatibleArchitectures
A list of compatible instruction set architectures.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCompatibleArchitectures()method.- Returns:
- A list of compatible instruction set architectures.
-
hasCompatibleArchitectures
public final boolean hasCompatibleArchitectures()For responses, this returns true if the service returned a value for the CompatibleArchitectures property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
compatibleArchitecturesAsStrings
A list of compatible instruction set architectures.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasCompatibleArchitectures()method.- Returns:
- A list of compatible instruction set architectures.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PublishLayerVersionResponse.Builder,PublishLayerVersionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-