Class PublishVersionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PublishVersionRequest.Builder,PublishVersionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringOnly publish a version if the hash value matches the value that's specified.final StringA description for the version to override the description in the function configuration.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()Specifies where to publish the function version or configuration.final StringSpecifies where to publish the function version or configuration.final StringOnly update the function if the revision ID matches the ID that's specified.static Class<? extends PublishVersionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Returns:
- The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
-
-
codeSha256
Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. You can get the hash for the version that you uploaded from the output of UpdateFunctionCode.
- Returns:
- Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. You can get the hash for the version that you uploaded from the output of UpdateFunctionCode.
-
description
A description for the version to override the description in the function configuration.
- Returns:
- A description for the version to override the description in the function configuration.
-
revisionId
Only update the function if the revision ID matches the ID that's specified. Use this option to avoid publishing a version if the function configuration has changed since you last updated it.
- Returns:
- Only update the function if the revision ID matches the ID that's specified. Use this option to avoid publishing a version if the function configuration has changed since you last updated it.
-
publishTo
Specifies where to publish the function version or configuration.
If the service returns an enum value that is not available in the current SDK version,
publishTowill returnFunctionVersionLatestPublished.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frompublishToAsString().- Returns:
- Specifies where to publish the function version or configuration.
- See Also:
-
publishToAsString
Specifies where to publish the function version or configuration.
If the service returns an enum value that is not available in the current SDK version,
publishTowill returnFunctionVersionLatestPublished.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frompublishToAsString().- Returns:
- Specifies where to publish the function version or configuration.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PublishVersionRequest.Builder,PublishVersionRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-