Interface PutFunctionConcurrencyRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CopyableBuilder<PutFunctionConcurrencyRequest.Builder,,PutFunctionConcurrencyRequest> LambdaRequest.Builder,SdkBuilder<PutFunctionConcurrencyRequest.Builder,,PutFunctionConcurrencyRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- PutFunctionConcurrencyRequest
-
Method Summary
Modifier and TypeMethodDescriptionfunctionName(String functionName) The name or ARN of the Lambda function.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) reservedConcurrentExecutions(Integer reservedConcurrentExecutions) The number of simultaneous executions to reserve for the function.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.services.lambda.model.LambdaRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
functionName
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Parameters:
functionName- The name or ARN of the Lambda function.Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-
reservedConcurrentExecutions
PutFunctionConcurrencyRequest.Builder reservedConcurrentExecutions(Integer reservedConcurrentExecutions) The number of simultaneous executions to reserve for the function.
- Parameters:
reservedConcurrentExecutions- The number of simultaneous executions to reserve for the function.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
PutFunctionConcurrencyRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
PutFunctionConcurrencyRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-