Class PutFunctionEventInvokeConfigRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutFunctionEventInvokeConfigRequest.Builder,PutFunctionEventInvokeConfigRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final DestinationConfigA destination for events after they have been sent to a function for processing.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function, version, or alias.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum age of a request that Lambda sends to a function for processing.final IntegerThe maximum number of times to retry when the function returns an error.final StringA version number or alias name.static Class<? extends PutFunctionEventInvokeConfigRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name -
my-function(name-only),my-function:v1(with alias). -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN -
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Returns:
- The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name -
my-function(name-only),my-function:v1(with alias). -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN -
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
-
-
qualifier
A version number or alias name.
- Returns:
- A version number or alias name.
-
maximumRetryAttempts
The maximum number of times to retry when the function returns an error.
- Returns:
- The maximum number of times to retry when the function returns an error.
-
maximumEventAgeInSeconds
The maximum age of a request that Lambda sends to a function for processing.
- Returns:
- The maximum age of a request that Lambda sends to a function for processing.
-
destinationConfig
A destination for events after they have been sent to a function for processing.
Destinations
-
Function - The Amazon Resource Name (ARN) of a Lambda function.
-
Queue - The ARN of a standard SQS queue.
-
Bucket - The ARN of an Amazon S3 bucket.
-
Topic - The ARN of a standard SNS topic.
-
Event Bus - The ARN of an Amazon EventBridge event bus.
S3 buckets are supported only for on-failure destinations. To retain records of successful invocations, use another destination type.
- Returns:
- A destination for events after they have been sent to a function for processing.
Destinations
-
Function - The Amazon Resource Name (ARN) of a Lambda function.
-
Queue - The ARN of a standard SQS queue.
-
Bucket - The ARN of an Amazon S3 bucket.
-
Topic - The ARN of a standard SNS topic.
-
Event Bus - The ARN of an Amazon EventBridge event bus.
S3 buckets are supported only for on-failure destinations. To retain records of successful invocations, use another destination type.
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutFunctionEventInvokeConfigRequest.Builder,PutFunctionEventInvokeConfigRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
public static Class<? extends PutFunctionEventInvokeConfigRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-