Class PutFunctionRecursionConfigRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutFunctionRecursionConfigRequest.Builder,PutFunctionRecursionConfigRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final RecursiveLoopIf you set your function's recursive loop detection configuration toAllow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop.final StringIf you set your function's recursive loop detection configuration toAllow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop.static Class<? extends PutFunctionRecursionConfigRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Returns:
- The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
-
-
recursiveLoop
If you set your function's recursive loop detection configuration to
Allow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop. We recommend that you only use this setting if your design intentionally uses a Lambda function to write data back to the same Amazon Web Services resource that invokes it.If you set your function's recursive loop detection configuration to
Terminate, Lambda stops your function being invoked and notifies you when it detects your function being invoked as part of a recursive loop.By default, Lambda sets your function's configuration to
Terminate.If your design intentionally uses a Lambda function to write data back to the same Amazon Web Services resource that invokes the function, then use caution and implement suitable guard rails to prevent unexpected charges being billed to your Amazon Web Services account. To learn more about best practices for using recursive invocation patterns, see Recursive patterns that cause run-away Lambda functions in Serverless Land.
If the service returns an enum value that is not available in the current SDK version,
recursiveLoopwill returnRecursiveLoop.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromrecursiveLoopAsString().- Returns:
- If you set your function's recursive loop detection configuration to
Allow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop. We recommend that you only use this setting if your design intentionally uses a Lambda function to write data back to the same Amazon Web Services resource that invokes it.If you set your function's recursive loop detection configuration to
Terminate, Lambda stops your function being invoked and notifies you when it detects your function being invoked as part of a recursive loop.By default, Lambda sets your function's configuration to
Terminate.If your design intentionally uses a Lambda function to write data back to the same Amazon Web Services resource that invokes the function, then use caution and implement suitable guard rails to prevent unexpected charges being billed to your Amazon Web Services account. To learn more about best practices for using recursive invocation patterns, see Recursive patterns that cause run-away Lambda functions in Serverless Land.
- See Also:
-
recursiveLoopAsString
If you set your function's recursive loop detection configuration to
Allow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop. We recommend that you only use this setting if your design intentionally uses a Lambda function to write data back to the same Amazon Web Services resource that invokes it.If you set your function's recursive loop detection configuration to
Terminate, Lambda stops your function being invoked and notifies you when it detects your function being invoked as part of a recursive loop.By default, Lambda sets your function's configuration to
Terminate.If your design intentionally uses a Lambda function to write data back to the same Amazon Web Services resource that invokes the function, then use caution and implement suitable guard rails to prevent unexpected charges being billed to your Amazon Web Services account. To learn more about best practices for using recursive invocation patterns, see Recursive patterns that cause run-away Lambda functions in Serverless Land.
If the service returns an enum value that is not available in the current SDK version,
recursiveLoopwill returnRecursiveLoop.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromrecursiveLoopAsString().- Returns:
- If you set your function's recursive loop detection configuration to
Allow, Lambda doesn't take any action when it detects your function being invoked as part of a recursive loop. We recommend that you only use this setting if your design intentionally uses a Lambda function to write data back to the same Amazon Web Services resource that invokes it.If you set your function's recursive loop detection configuration to
Terminate, Lambda stops your function being invoked and notifies you when it detects your function being invoked as part of a recursive loop.By default, Lambda sets your function's configuration to
Terminate.If your design intentionally uses a Lambda function to write data back to the same Amazon Web Services resource that invokes the function, then use caution and implement suitable guard rails to prevent unexpected charges being billed to your Amazon Web Services account. To learn more about best practices for using recursive invocation patterns, see Recursive patterns that cause run-away Lambda functions in Serverless Land.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutFunctionRecursionConfigRequest.Builder,PutFunctionRecursionConfigRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-