Class PutFunctionRecursionConfigResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutFunctionRecursionConfigResponse.Builder,PutFunctionRecursionConfigResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final RecursiveLoopThe status of your function's recursive loop detection configuration.final StringThe status of your function's recursive loop detection configuration.static Class<? extends PutFunctionRecursionConfigResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.lambda.model.LambdaResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
recursiveLoop
The status of your function's recursive loop detection configuration.
When this value is set to
Allowand Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.When this value is set to
Terminateand Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you.If the service returns an enum value that is not available in the current SDK version,
recursiveLoopwill returnRecursiveLoop.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromrecursiveLoopAsString().- Returns:
- The status of your function's recursive loop detection configuration.
When this value is set to
Allowand Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.When this value is set to
Terminateand Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you. - See Also:
-
recursiveLoopAsString
The status of your function's recursive loop detection configuration.
When this value is set to
Allowand Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.When this value is set to
Terminateand Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you.If the service returns an enum value that is not available in the current SDK version,
recursiveLoopwill returnRecursiveLoop.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromrecursiveLoopAsString().- Returns:
- The status of your function's recursive loop detection configuration.
When this value is set to
Allowand Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.When this value is set to
Terminateand Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutFunctionRecursionConfigResponse.Builder,PutFunctionRecursionConfigResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends PutFunctionRecursionConfigResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-