Class PutRuntimeManagementConfigRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutRuntimeManagementConfigRequest.Builder,PutRuntimeManagementConfigRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name or ARN of the Lambda function.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringSpecify a version of the function.final StringThe ARN of the runtime version you want the function to use.static Class<? extends PutRuntimeManagementConfigRequest.Builder>final StringtoString()Returns a string representation of this object.final UpdateRuntimeOnSpecify the runtime update mode.final StringSpecify the runtime update mode.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
functionName
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
- Returns:
- The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
-
-
-
qualifier
Specify a version of the function. This can be
$LATESTor a published version number. If no value is specified, the configuration for the$LATESTversion is returned.- Returns:
- Specify a version of the function. This can be
$LATESTor a published version number. If no value is specified, the configuration for the$LATESTversion is returned.
-
updateRuntimeOn
Specify the runtime update mode.
-
Auto (default) - Automatically update to the most recent and secure runtime version using a Two-phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.
-
Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.
-
Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.
If the service returns an enum value that is not available in the current SDK version,
updateRuntimeOnwill returnUpdateRuntimeOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromupdateRuntimeOnAsString().- Returns:
- Specify the runtime update mode.
-
Auto (default) - Automatically update to the most recent and secure runtime version using a Two- phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.
-
Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.
-
Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.
-
- See Also:
-
-
updateRuntimeOnAsString
Specify the runtime update mode.
-
Auto (default) - Automatically update to the most recent and secure runtime version using a Two-phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.
-
Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.
-
Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.
If the service returns an enum value that is not available in the current SDK version,
updateRuntimeOnwill returnUpdateRuntimeOn.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromupdateRuntimeOnAsString().- Returns:
- Specify the runtime update mode.
-
Auto (default) - Automatically update to the most recent and secure runtime version using a Two- phase runtime version rollout. This is the best choice for most customers to ensure they always benefit from runtime updates.
-
Function update - Lambda updates the runtime of your function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.
-
Manual - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see Roll back a runtime version.
-
- See Also:
-
-
runtimeVersionArn
The ARN of the runtime version you want the function to use.
This is only required if you're using the Manual runtime update mode.
- Returns:
- The ARN of the runtime version you want the function to use.
This is only required if you're using the Manual runtime update mode.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutRuntimeManagementConfigRequest.Builder,PutRuntimeManagementConfigRequest> - Specified by:
toBuilderin classLambdaRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-